@@ -15,13 +15,14 @@ found in the LICENSE file.
 #include <mitkCoreServices.h>
 #include <mitkIPreferencesService.h>
 #include <mitkExceptionMacro.h>
-#include <mitkLogMacros.h>
+#include <mitkLog.h>
 #include <mitkProvisioningInfo.h>
 
 #include <QmitkSafeApplication.h>
 #include <QmitkSingleApplication.h>
 
 #include <Poco/Util/HelpFormatter.h>
+#include <Poco/Util/OptionException.h>
 
 #include <ctkPluginFramework.h>
 #include <ctkPluginFramework_global.h>
@@ -29,6 +30,7 @@ found in the LICENSE file.
 
 #include <usModuleSettings.h>
 
+#include <vtkLogger.h>
 #include <vtkOpenGLRenderWindow.h>
 #include <QVTKOpenGLNativeWidget.h>
 
@@ -40,10 +42,34 @@ found in the LICENSE file.
 #include <QStandardPaths>
 #include <QTime>
 #include <QWebEngineUrlScheme>
+#include <QQuickWindow>
 
 namespace
 {
-  void outputQtMessage(QtMsgType type, const QMessageLogContext&, const QString& msg)
+  void outputImportantQtMessage(QtMsgType type, const QMessageLogContext&, const QString& msg)
+  {
+    auto message = msg.toStdString();
+
+    switch (type)
+    {
+    case QtWarningMsg:
+      MITK_WARN << message;
+      break;
+
+    case QtCriticalMsg:
+      MITK_ERROR << message;
+      break;
+
+    case QtFatalMsg:
+      MITK_ERROR << message;
+      abort();
+
+    default:
+      break;
+    }
+  }
+
+  void outputQtMessage(QtMsgType type, const QMessageLogContext& context, const QString& msg)
   {
     auto message = msg.toStdString();
 
@@ -58,22 +84,68 @@ namespace
         break;
 
       case QtWarningMsg:
-        MITK_WARN << message;
-        break;
+        [[fallthrough]];
 
       case QtCriticalMsg:
-        MITK_ERROR << message;
-        break;
+        [[fallthrough]];
 
       case QtFatalMsg:
-        MITK_ERROR << message;
-        abort();
+        outputImportantQtMessage(type, context, msg);
+        break;
 
       default:
         MITK_INFO << message;
         break;
     }
   }
+
+  void defineQtOptions(Poco::Util::OptionSet& options)
+  {
+    // Manage Qt options as array of pairs, consisting of argument name and argument value requirement.
+    // Qt command-line options: https://doc.qt.io/qt-6/qguiapplication.html#supported-command-line-options
+
+    std::array<std::pair<std::string, bool>, 12> qtOptions {{
+      { "platform", true },
+      { "platformpluginpath", true },
+      { "platformtheme", true },
+      { "plugin", true },
+      { "qmljsdebugger", true },
+      { "qwindowgeometry", true },
+      { "qwindowicon", true },
+      { "qwindowtitle", true },
+      { "reverse", false },
+      { "session", true },
+      { "display", true },
+      { "geometry", true }
+    }};
+
+    for (const auto& qtOption : qtOptions)
+    {
+      // Qt uses short name syntax (-arg), while Poco requires a full name (--arg) in addition.
+      // Hence, set both to the same value. Always set description to "qt" for easy distinction
+      // between regular arguments and Qt arguments.
+
+      Poco::Util::Option option(qtOption.first, qtOption.first, "qt");
+
+      if (qtOption.second)
+        option.argument("<arg>"); // A short generic string as we don't care but Poco requires a non-empty string.
+
+      options.addOption(option);
+    }
+  }
+
+  Poco::Util::OptionSet excludeQtOptions(const Poco::Util::OptionSet& options)
+  {
+    Poco::Util::OptionSet remainingOptions;
+
+    for (const auto& option : options)
+    {
+      if (option.description() != "qt") // All Qt options have "qt" as description (see above).
+        remainingOptions.addOption(option);
+    }
+
+    return remainingOptions;
+  }
 }
 
 namespace mitk
@@ -154,7 +226,8 @@ namespace mitk
     QString m_ProvFile;
 
     Impl(int argc, char **argv)
-      : m_Argc(argc),
+      : m_QApp(nullptr),
+        m_Argc(argc),
         m_Argv(argv),
 #ifdef Q_OS_MAC
         m_Argv_macOS(),
@@ -319,7 +392,7 @@ namespace mitk
 
           auto pluginUrlsToStart = provInfo.getPluginsToStart();
 
-          for (const auto& url : qAsConst(pluginUrlsToStart))
+          for (const auto& url : std::as_const(pluginUrlsToStart))
             pluginsToStart.push_back(url.toString());
         }
       }
@@ -353,7 +426,9 @@ namespace mitk
 
   void BaseApplication::printHelp(const std::string &, const std::string &)
   {
-    Poco::Util::HelpFormatter help(this->options());
+    const auto remainingOptions = excludeQtOptions(this->options());
+
+    Poco::Util::HelpFormatter help(remainingOptions);
     help.setAutoIndent();
     help.setCommand(this->commandName());
     help.format(std::cout);
@@ -482,7 +557,7 @@ namespace mitk
         basePath.cdUp();
         basePath.cdUp();
         basePath.cdUp();
-        provFile = basePath.absoluteFilePath(provFileName);
+        provFile.setFile(basePath.absoluteFilePath(provFileName));
       }
 #endif
 
@@ -511,9 +586,23 @@ namespace mitk
       return;
 
 #ifdef Q_OS_LINUX
-    qputenv("QTWEBENGINE_CHROMIUM_FLAGS", "--single-process"); // See T29332
+    const auto& argv = this->argv();
+
+    if (std::find(argv.cbegin(), argv.cend(), "-platform") == argv.cend())
+    {
+      // If not set explicitly otherwise, prefer xcb as platform on Linux, as we had issues
+      // with wayland in combination with VTK and GLEW. Note that the shell scripts for
+      // excutables in our installers also set the platform to xcb.
+      if (qEnvironmentVariableIsEmpty("QT_QPA_PLATFORM"))
+        qputenv("QT_QPA_PLATFORM", "xcb");
+    }
+
+    // qputenv("QTWEBENGINE_CHROMIUM_FLAGS", "--single-process"); // See T29332
 #endif
 
+    // Prevent conflicts between native OpenGL applications and QWebEngine
+    QQuickWindow::setGraphicsApi(QSGRendererInterface::Software);
+
     // If parameters have been set before, we have to store them to hand them
     // through to the application
     auto appName = this->getApplicationName();
@@ -528,8 +617,9 @@ namespace mitk
     this->setOrganizationName(orgName);
     this->setOrganizationDomain(orgDomain);
 
-    if (d->m_LogQtMessages)
-      qInstallMessageHandler(outputQtMessage);
+    qInstallMessageHandler(!d->m_LogQtMessages
+      ? outputImportantQtMessage
+      : outputQtMessage);
 
     QWebEngineUrlScheme qtHelpScheme("qthelp");
     qtHelpScheme.setFlags(QWebEngineUrlScheme::LocalScheme | QWebEngineUrlScheme::LocalAccessAllowed);
@@ -544,37 +634,36 @@ namespace mitk
     // 2. Initialize the Qt framework (by creating a QCoreApplication)
     this->initializeQt();
 
-    // 3. Seed the random number generator, once at startup.
-    QTime time = QTime::currentTime();
-    qsrand((uint)time.msec());
-
-    // 4. Load the "default" configuration, which involves parsing
+    // 3. Load the "default" configuration, which involves parsing
     //    an optional <executable-name>.ini file and parsing any
     //    command line arguments
     this->loadConfiguration();
 
-    // 5. Add configuration data from the command line and the
+    // 4. Add configuration data from the command line and the
     //    optional <executable-name>.ini file as CTK plugin
     //    framework properties.
     d->initializeCTKPluginFrameworkProperties(this->config());
 
-    // 6. Initialize splash screen if an image path is provided
+    // 5. Initialize splash screen if an image path is provided
     //    in the .ini file
     this->initializeSplashScreen(qApp);
 
-    // 7. Set the custom CTK Plugin Framework storage directory
+    // 6. Set the custom CTK Plugin Framework storage directory
     QString storageDir = this->getCTKFrameworkStorageDir();
 
     if (!storageDir.isEmpty())
     {
       d->m_FWProps[ctkPluginConstants::FRAMEWORK_STORAGE] = storageDir;
 
+      if (!(storageDir.endsWith('/') || storageDir.endsWith('\\')))
+        storageDir.append('/');
+
       // Initialize core service preferences at the exact same location as their predecessor BlueBerry preferences
       mitk::CoreServicePointer preferencesService(mitk::CoreServices::GetPreferencesService());
-      preferencesService->InitializeStorage(storageDir.toStdString() + "/data/3/prefs.xml");
+      preferencesService->InitializeStorage(storageDir.toStdString() + "data/3/prefs.xml");
     }
 
-    // 8. Set the library search paths and the pre-load library property
+    // 7. Set the library search paths and the pre-load library property
     this->initializeLibraryPaths();
 
     auto preloadLibs = this->getPreloadLibraries();
@@ -582,17 +671,17 @@ namespace mitk
     if (!preloadLibs.isEmpty())
       d->m_FWProps[ctkPluginConstants::FRAMEWORK_PRELOAD_LIBRARIES] = preloadLibs;
 
-    // 9. Initialize the CppMicroServices library.
+    // 8. Initialize the CppMicroServices library.
     //    The initializeCppMicroServices() method reuses the
     //    FRAMEWORK_STORAGE property, so we call it after the
     //    getCTKFrameworkStorageDir method.
     this->initializeCppMicroServices();
 
-    // 10. Parse the (optional) provisioning file and set the
+    // 9. Parse the (optional) provisioning file and set the
     //     correct framework properties.
     d->parseProvisioningFile(this->getProvisioningFilePath());
 
-    // 11. Set the CTK Plugin Framework properties
+    // 10. Set the CTK Plugin Framework properties
     ctkPluginFrameworkLauncher::setFrameworkProperties(d->m_FWProps);
   }
 
@@ -663,21 +752,19 @@ namespace mitk
   {
     if (nullptr == qApp)
     {
+      vtkLogger::SetStderrVerbosity(vtkLogger::VERBOSITY_WARNING);
+
       vtkOpenGLRenderWindow::SetGlobalMaximumNumberOfMultiSamples(0);
 
       auto defaultFormat = QVTKOpenGLNativeWidget::defaultFormat();
       defaultFormat.setSamples(0);
       QSurfaceFormat::setDefaultFormat(defaultFormat);
 
-#ifdef Q_OS_OSX
+#ifdef Q_OS_MACOS
       QCoreApplication::setAttribute(Qt::AA_DontCreateNativeWidgetSiblings);
 #endif
 
-      QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
-
-#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
       QGuiApplication::setHighDpiScaleFactorRoundingPolicy(Qt::HighDpiScaleFactorRoundingPolicy::PassThrough);
-#endif
       QCoreApplication::setAttribute(Qt::AA_ShareOpenGLContexts);
 
       d->m_QApp = this->getSingleMode()
@@ -715,7 +802,7 @@ namespace mitk
     // Walk one directory up and add bin and lib sub-dirs; this might be redundant
     appDir.cdUp();
 
-    for (const auto& suffix : qAsConst(suffixes))
+    for (const auto& suffix : std::as_const(suffixes))
       ctkPluginFrameworkLauncher::addSearchPath(appDir.absoluteFilePath(suffix));
   }
 
@@ -796,9 +883,9 @@ namespace mitk
     registryMultiLanguageOption.callback(Poco::Util::OptionCallback<Impl>(d, &Impl::handleBooleanOption));
     options.addOption(registryMultiLanguageOption);
 
-  Poco::Util::Option splashScreenOption(ARG_SPLASH_IMAGE.toStdString(), "", "optional picture to use as a splash screen");
-  splashScreenOption.argument("<filename>").binding(ARG_SPLASH_IMAGE.toStdString());
-  options.addOption(splashScreenOption);
+    Poco::Util::Option splashScreenOption(ARG_SPLASH_IMAGE.toStdString(), "", "optional picture to use as a splash screen");
+    splashScreenOption.argument("<filename>").binding(ARG_SPLASH_IMAGE.toStdString());
+    options.addOption(splashScreenOption);
 
     Poco::Util::Option xargsOption(ARG_XARGS.toStdString(), "", "Extended argument list");
     xargsOption.argument("<args>").binding(ARG_XARGS.toStdString());
@@ -816,6 +903,10 @@ namespace mitk
     labelSuggestionsOption.argument("<filename>").binding(ARG_SEGMENTATION_LABEL_SUGGESTIONS.toStdString());
     options.addOption(labelSuggestionsOption);
 
+    // Make Poco aware of QGuiApplication command-line options, even though they are only parsed by
+    // Qt. Otherwise, Poco would throw exceptions for unknown options.
+    defineQtOptions(options);
+
     Poco::Util::Application::defineOptions(options);
   }
 
@@ -861,7 +952,17 @@ namespace mitk
 
   int BaseApplication::run()
   {
-    this->init(d->m_Argc, d->m_Argv);
+    try
+    {
+      this->setUnixOptions(true);
+      this->init(d->m_Argc, d->m_Argv);
+    }
+    catch (const Poco::Util::OptionException& e)
+    {
+      MITK_ERROR << e.name() << ": " << e.message();
+      return EXIT_FAILURE;
+    }
+
     return Application::run();
   }
 
