@@ -1,30 +1,26 @@
-/*===================================================================
+/*============================================================================
 
 The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
+============================================================================*/
 
-===================================================================*/
-
-#ifndef _mitkContourModelToPointSetFilter_h__
-#define _mitkContourModelToPointSetFilter_h__
+#ifndef mitkContourModelToPointSetFilter_h
+#define mitkContourModelToPointSetFilter_h
 
 #include "mitkCommon.h"
-#include <MitkContourModelExports.h>
+#include "mitkContourModel.h"
 #include "mitkPointSet.h"
 #include "mitkPointSetSource.h"
-#include "mitkContourModel.h"
-
-namespace mitk {
+#include <MitkContourModelExports.h>
 
+namespace mitk
+{
   /**
   *
   * @brief Converts a contour set to a point set.
@@ -35,28 +31,23 @@ namespace mitk {
   */
   class MITKCONTOURMODEL_EXPORT ContourModelToPointSetFilter : public PointSetSource
   {
-
   public:
+    mitkClassMacro(ContourModelToPointSetFilter, PointSetSource);
+    itkFactorylessNewMacro(Self);
+    itkCloneMacro(Self);
 
-    mitkClassMacro(ContourModelToPointSetFilter, PointSetSource)
-    itkFactorylessNewMacro(Self)
-    itkCloneMacro(Self)
-
-    typedef PointSet OutputType;
+      typedef PointSet OutputType;
     typedef OutputType::Pointer OutputTypePointer;
     typedef mitk::ContourModel InputType;
 
   protected:
-
     ContourModelToPointSetFilter();
 
-    virtual ~ContourModelToPointSetFilter();
+    ~ContourModelToPointSetFilter() override;
 
     void GenerateOutputInformation() override {}
-
     void GenerateData() override;
   };
-
 }
 
 #endif
