@@ -235,7 +235,7 @@ void mitk::ContourModelUtils::FillSliceInSlice(
   }
   else
   {
-    if (paintingPixelValue != LabelSetImage::UnlabeledValue)
+    if (paintingPixelValue != LabelSetImage::UNLABELED_VALUE)
     {
       for (std::remove_const_t<decltype(numberOfPoints)> i = 0; i < numberOfPoints; ++i)
       {
@@ -251,7 +251,7 @@ void mitk::ContourModelUtils::FillSliceInSlice(
     }
     else
     {
-      const auto activePixelValue = labelImage->GetActiveLabel(labelImage->GetActiveLayer())->GetValue();
+      const auto activePixelValue = labelImage->GetActiveLabel()->GetValue();
       for (std::remove_const_t<decltype(numberOfPoints)> i = 0; i < numberOfPoints; ++i)
       {
         if (fillForegroundThreshold <= filledImage->GetPointData()->GetScalars()->GetTuple1(i))
@@ -285,7 +285,7 @@ int mitk::ContourModelUtils::GetActivePixelValue(const Image* workingImage)
   int activePixelValue = 1;
   if (nullptr != labelSetImage)
   {
-    activePixelValue = labelSetImage->GetActiveLabel(labelSetImage->GetActiveLayer())->GetValue();
+    activePixelValue = labelSetImage->GetActiveLabel()->GetValue();
   }
 
   return activePixelValue;
