@@ -1,42 +1,38 @@
-/*===================================================================
+/*============================================================================
 
 The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
+============================================================================*/
 
-===================================================================*/
-
-#ifndef BaseGeometry_H_HEADER_INCLUDED
-#define BaseGeometry_H_HEADER_INCLUDED
+#ifndef mitkBaseGeometry_h
+#define mitkBaseGeometry_h
 
+#include "mitkOperationActor.h"
 #include <MitkCoreExports.h>
 #include <mitkCommon.h>
-#include "mitkOperationActor.h"
 
-#include <itkBoundingBox.h>
-#include "mitkNumericTypes.h"
-#include <itkAffineGeometryFrame.h>
-#include <itkQuaternionRigidTransform.h>
 #include "itkScalableAffineTransform.h"
+#include "mitkNumericTypes.h"
+#include <itkBoundingBox.h>
 #include <itkIndex.h>
+#include <itkQuaternionRigidTransform.h>
 #include <mitkAffineTransform3D.h>
 
-#include <vtkTransform.h>
 #include <mitkGeometryTransformHolder.h>
+#include <vtkTransform.h>
 
 class vtkMatrix4x4;
 class vtkMatrixToLinearTransform;
 class vtkLinearTransform;
 
-namespace mitk {
+namespace mitk
+{
   //##Documentation
   //## @brief Standard 3D-BoundingBox typedef
   //##
@@ -45,11 +41,9 @@ namespace mitk {
 
   //##Documentation
   //## @brief Standard typedef for time-bounds
-  typedef itk::FixedArray<ScalarType, 2>  TimeBounds;
+  typedef itk::FixedArray<ScalarType, 2> TimeBounds;
   typedef itk::FixedArray<ScalarType, 3> FixedArrayType;
 
-  typedef itk::AffineGeometryFrame<ScalarType, 3>        AffineGeometryFrame3D;
-
   //##Documentation
   //## @brief BaseGeometry Describes the geometry of a data object
   //##
@@ -72,7 +66,7 @@ namespace mitk {
   //## WorldToIndex, otherwise you will get a continuous index
   //## (floating point values).
   //##
-  //## An important sub-class is SlicedGeometry3D, which descibes
+  //## An important sub-class is SlicedGeometry3D, which describes
   //## data objects consisting of slices, e.g., objects of type Image.
   //## Conversions between world coordinates (in mm) and unit coordinates
   //## (e.g., pixels in the case of an Image) can be performed.
@@ -81,7 +75,7 @@ namespace mitk {
   //##
   //## BaseGeometry instances referring to an Image need a slightly
   //## different definition of corners, see SetImageGeometry. This
-  //## is usualy automatically called by Image.
+  //## is usually automatically called by Image.
   //##
   //## BaseGeometry have to be initialized in the method GenerateOutputInformation()
   //## of BaseProcess (or CopyInformation/ UpdateOutputInformation of BaseData,
@@ -93,7 +87,7 @@ namespace mitk {
   //## At least, it can return the bounding box of the data object.
   //##
   //## The BaseGeometry class is an abstract class. The most simple implementation
-  //## is the sublass Geometry3D.
+  //## is the subclass Geometry3D.
   //##
   //## Rule: everything is in mm (ms) if not stated otherwise.
   //## @ingroup Geometry
@@ -101,14 +95,14 @@ namespace mitk {
   {
   public:
     mitkClassMacroItkParent(BaseGeometry, itk::Object);
-    itkCloneMacro(Self)
+    itkCloneMacro(Self);
 
       // ********************************** TypeDef **********************************
 
-      typedef GeometryTransformHolder::TransformType         TransformType;
+      typedef GeometryTransformHolder::TransformType TransformType;
     typedef itk::BoundingBox<unsigned long, 3, ScalarType> BoundingBoxType;
-    typedef BoundingBoxType::BoundsArrayType               BoundsArrayType;
-    typedef BoundingBoxType::Pointer                       BoundingBoxPointer;
+    typedef BoundingBoxType::BoundsArrayType BoundsArrayType;
+    typedef BoundingBoxType::Pointer BoundingBoxPointer;
 
     // ********************************** Origin, Spacing **********************************
 
@@ -119,7 +113,7 @@ namespace mitk {
     //##Documentation
     //## @brief Set the origin, i.e. the upper-left corner of the plane
     //##
-    void SetOrigin(const Point3D& origin);
+    void SetOrigin(const Point3D &origin);
 
     //##Documentation
     //## @brief Get the spacing (size of a pixel).
@@ -130,7 +124,7 @@ namespace mitk {
     //## @brief Set the spacing (m_Spacing).
     //##
     //##The spacing is also changed in the IndexToWorldTransform.
-    void SetSpacing(const mitk::Vector3D& aSpacing, bool enforceSetSpacing = false);
+    void SetSpacing(const mitk::Vector3D &aSpacing, bool enforceSetSpacing = false);
 
     //##Documentation
     //## @brief Get the origin as VnlVector
@@ -171,48 +165,49 @@ namespace mitk {
     //## @brief Initialize the BaseGeometry
     void Initialize();
 
-    void InitializeGeometry(Self * newGeometry) const;
+    void InitializeGeometry(Self *newGeometry) const;
 
     // ********************************** Transformations Set/Get **********************************
 
     //##Documentation
     //## @brief Get the transformation used to convert from index
     //## to world coordinates
-    mitk::AffineTransform3D* GetIndexToWorldTransform();
+    mitk::AffineTransform3D *GetIndexToWorldTransform();
 
     //##Documentation
     //## @brief Get the transformation used to convert from index
     //## to world coordinates
-    const mitk::AffineTransform3D*   GetIndexToWorldTransform() const;
+    const mitk::AffineTransform3D *GetIndexToWorldTransform() const;
 
     //## @brief Set the transformation used to convert from index
     //## to world coordinates. The spacing of the new transform is
     //## copied to m_spacing.
-    void SetIndexToWorldTransform(mitk::AffineTransform3D* transform);
+    void SetIndexToWorldTransform(mitk::AffineTransform3D *transform);
 
     //##Documentation
     //## @brief Convenience method for setting the ITK transform
     //## (m_IndexToWorldTransform) via an vtkMatrix4x4.The spacing of
     //## the new transform is copied to m_spacing.
     //## \sa SetIndexToWorldTransform
-    void SetIndexToWorldTransformByVtkMatrix(vtkMatrix4x4* vtkmatrix);
+    void SetIndexToWorldTransformByVtkMatrix(vtkMatrix4x4 *vtkmatrix);
 
     //## @brief Set the transformation used to convert from index
     //## to world coordinates.This function keeps the original spacing.
-    void SetIndexToWorldTransformWithoutChangingSpacing(mitk::AffineTransform3D* transform);
+    void SetIndexToWorldTransformWithoutChangingSpacing(mitk::AffineTransform3D *transform);
 
     //##Documentation
     //## @brief Convenience method for setting the ITK transform
     //## (m_IndexToWorldTransform) via an vtkMatrix4x4. This function keeps the original spacing.
     //## \sa SetIndexToWorldTransform
-    void SetIndexToWorldTransformByVtkMatrixWithoutChangingSpacing(vtkMatrix4x4* vtkmatrix);
+    void SetIndexToWorldTransformByVtkMatrixWithoutChangingSpacing(vtkMatrix4x4 *vtkmatrix);
 
     //## Get the Vtk Matrix which describes the transform.
-    vtkMatrix4x4* GetVtkMatrix();
+    vtkMatrix4x4 *GetVtkMatrix();
+    const vtkMatrix4x4* GetVtkMatrix() const;
 
     //##Documentation
     //## @brief Get the m_IndexToWorldTransform as a vtkLinearTransform
-    vtkLinearTransform* GetVtkTransform() const;
+    vtkLinearTransform *GetVtkTransform() const;
 
     //##Documentation
     //## @brief Set the transform to identity, the spacing to 1 and origin to 0
@@ -233,42 +228,42 @@ namespace mitk {
     //## transformation consists of first applying self to the source,
     //## followed by other.
     //## This method also changes m_spacing.
-    void Compose(const TransformType * other, bool pre = 0);
+    void Compose(const TransformType *other, bool pre = false);
 
     //##Documentation
     //## @brief Compose new IndexToWorldTransform with a given vtkMatrix4x4.
     //##
     //## Converts the vtkMatrix4x4 into a itk-transform and calls the previous method.
-    void Compose(const vtkMatrix4x4 * vtkmatrix, bool pre = 0);
+    void Compose(const vtkMatrix4x4 *vtkmatrix, bool pre = false);
 
     //##Documentation
     //## @brief Translate the origin by a vector
     //##
-    void Translate(const Vector3D&  vector);
+    void Translate(const Vector3D &vector);
 
     //##Documentation
     //##@brief executes affine operations (translate, rotate, scale)
-    virtual void ExecuteOperation(Operation* operation) override;
+    void ExecuteOperation(Operation *operation) override;
 
     //##Documentation
     //## @brief Convert world coordinates (in mm) of a \em point to (continuous!) index coordinates
     //## \warning If you need (discrete) integer index coordinates (e.g., for iterating easily over an image),
     //## use WorldToIndex(const mitk::Point3D& pt_mm, itk::Index<VIndexDimension> &index).
     //## For further information about coordinates types, please see the Geometry documentation
-    void WorldToIndex(const mitk::Point3D& pt_mm, mitk::Point3D& pt_units) const;
+    void WorldToIndex(const mitk::Point3D &pt_mm, mitk::Point3D &pt_units) const;
 
     //##Documentation
     //## @brief Convert world coordinates (in mm) of a \em vector
     //## \a vec_mm to (continuous!) index coordinates.
     //## For further information about coordinates types, please see the Geometry documentation
-    void WorldToIndex(const mitk::Vector3D& vec_mm, mitk::Vector3D& vec_units) const;
+    void WorldToIndex(const mitk::Vector3D &vec_mm, mitk::Vector3D &vec_units) const;
 
     //##Documentation
     //## @brief Convert world coordinates (in mm) of a \em point to (discrete!) index coordinates.
     //## This method rounds to integer indices!
     //## For further information about coordinates types, please see the Geometry documentation
     template <unsigned int VIndexDimension>
-    void WorldToIndex(const mitk::Point3D& pt_mm, itk::Index<VIndexDimension> &index) const
+    void WorldToIndex(const mitk::Point3D &pt_mm, itk::Index<VIndexDimension> &index) const
     {
       typedef itk::Index<VIndexDimension> IndexType;
       mitk::Point3D pt_units;
@@ -279,7 +274,8 @@ namespace mitk {
         index.Fill(0);
         dim = 3;
       }
-      for (i = 0; i < dim; ++i){
+      for (i = 0; i < dim; ++i)
+      {
         index[i] = itk::Math::RoundHalfIntegerUp<typename IndexType::IndexValueType>(pt_units[i]);
       }
     }
@@ -288,18 +284,18 @@ namespace mitk {
     //## @brief Convert (continuous or discrete) index coordinates of a \em vector
     //## \a vec_units to world coordinates (in mm)
     //## For further information about coordinates types, please see the Geometry documentation
-    void IndexToWorld(const mitk::Vector3D& vec_units, mitk::Vector3D& vec_mm) const;
+    void IndexToWorld(const mitk::Vector3D &vec_units, mitk::Vector3D &vec_mm) const;
 
     //##Documentation
     //## @brief Convert (continuous or discrete) index coordinates of a \em point to world coordinates (in mm)
     //## For further information about coordinates types, please see the Geometry documentation
-    void IndexToWorld(const mitk::Point3D& pt_units, mitk::Point3D& pt_mm) const;
+    void IndexToWorld(const mitk::Point3D &pt_units, mitk::Point3D &pt_mm) const;
 
     //##Documentation
     //## @brief Convert (discrete) index coordinates of a \em point to world coordinates (in mm)
     //## For further information about coordinates types, please see the Geometry documentation
     template <unsigned int VIndexDimension>
-    void IndexToWorld(const itk::Index<VIndexDimension> &index, mitk::Point3D& pt_mm) const
+    void IndexToWorld(const itk::Index<VIndexDimension> &index, mitk::Point3D &pt_mm) const
     {
       mitk::Point3D pt_units;
       pt_units.Fill(0);
@@ -319,16 +315,18 @@ namespace mitk {
     //##Documentation
     //## @brief Convert (continuous or discrete) index coordinates of a \em vector
     //## \a vec_units to world coordinates (in mm)
-    //## @deprecated First parameter (Point3D) is not used. If possible, please use void IndexToWorld(const mitk::Vector3D& vec_units, mitk::Vector3D& vec_mm) const.
+    //## @deprecated First parameter (Point3D) is not used. If possible, please use void IndexToWorld(const
+    // mitk::Vector3D& vec_units, mitk::Vector3D& vec_mm) const.
     //## For further information about coordinates types, please see the Geometry documentation
-    void IndexToWorld(const mitk::Point3D& atPt3d_units, const mitk::Vector3D& vec_units, mitk::Vector3D& vec_mm) const;
+    void IndexToWorld(const mitk::Point3D &atPt3d_units, const mitk::Vector3D &vec_units, mitk::Vector3D &vec_mm) const;
 
     //##Documentation
     //## @brief Convert world coordinates (in mm) of a \em vector
     //## \a vec_mm to (continuous!) index coordinates.
-    //## @deprecated First parameter (Point3D) is not used. If possible, please use void WorldToIndex(const mitk::Vector3D& vec_mm, mitk::Vector3D& vec_units) const.
+    //## @deprecated First parameter (Point3D) is not used. If possible, please use void WorldToIndex(const
+    // mitk::Vector3D& vec_mm, mitk::Vector3D& vec_units) const.
     //## For further information about coordinates types, please see the Geometry documentation
-    void WorldToIndex(const mitk::Point3D& atPt3d_mm, const mitk::Vector3D& vec_mm, mitk::Vector3D& vec_units) const;
+    void WorldToIndex(const mitk::Point3D &atPt3d_mm, const mitk::Vector3D &vec_mm, mitk::Vector3D &vec_units) const;
 
     //##Documentation
     //## @brief Deprecated for use with ITK version 3.10 or newer.
@@ -336,9 +334,8 @@ namespace mitk {
     //## but without a rotation) into MITK world coordinates (in mm)
     //##
     //## For more information, see WorldToItkPhysicalPoint.
-    template<class TCoordRep>
-    void ItkPhysicalPointToWorld(const itk::Point<TCoordRep, 3>& itkPhysicalPoint,
-      mitk::Point3D& pt_mm) const
+    template <class TCoordRep>
+    void ItkPhysicalPointToWorld(const itk::Point<TCoordRep, 3> &itkPhysicalPoint, mitk::Point3D &pt_mm) const
     {
       mitk::vtk2itk(itkPhysicalPoint, pt_mm);
     }
@@ -359,9 +356,8 @@ namespace mitk {
     //## coordinate (including the rotation) into a coordinate that
     //## can be used with the ITK image as a ITK physical coordinate
     //## (excluding the rotation).
-    template<class TCoordRep>
-    void WorldToItkPhysicalPoint(const mitk::Point3D& pt_mm,
-      itk::Point<TCoordRep, 3>& itkPhysicalPoint) const
+    template <class TCoordRep>
+    void WorldToItkPhysicalPoint(const mitk::Point3D &pt_mm, itk::Point<TCoordRep, 3> &itkPhysicalPoint) const
     {
       mitk::vtk2itk(pt_mm, itkPhysicalPoint);
     }
@@ -371,7 +367,7 @@ namespace mitk {
     /** Get the bounding box */
     itkGetConstObjectMacro(BoundingBox, BoundingBoxType);
 
-    // a bit of a misuse, but we want only doxygen to see the following:
+// a bit of a misuse, but we want only doxygen to see the following:
 #ifdef DOXYGEN_SKIP
     //##Documentation
     //## @brief Get bounding box (in index/unit coordinates)
@@ -387,7 +383,7 @@ namespace mitk {
     //##
     //## Only possible via the BoundsArray to make clear that a
     //## copy of the bounding-box is stored, not a reference to it.
-    void SetBounds(const BoundsArrayType& bounds);
+    void SetBounds(const BoundsArrayType &bounds);
 
     //##Documentation
     //## @brief Set the bounding box (in index/unit coordinates) via a float array
@@ -407,13 +403,13 @@ namespace mitk {
     //## @brief Calculates a bounding-box around the geometry relative
     //## to a coordinate system defined by a transform
     //##
-    mitk::BoundingBox::Pointer CalculateBoundingBoxRelativeToTransform(const mitk::AffineTransform3D* transform) const;
+    mitk::BoundingBox::Pointer CalculateBoundingBoxRelativeToTransform(const mitk::AffineTransform3D *transform) const;
 
-    //##Documentation
-    //## @brief Set the time bounds (in ms)
-    //void SetTimeBounds(const TimeBounds& timebounds);
+//##Documentation
+//## @brief Set the time bounds (in ms)
+// void SetTimeBounds(const TimeBounds& timebounds);
 
-    // ********************************** Geometry **********************************
+// ********************************** Geometry **********************************
 
 #ifdef DOXYGEN_SKIP
     //##Documentation
@@ -483,12 +479,12 @@ namespace mitk {
     //##Documentation
     //## @brief Test whether the point \a p (world coordinates in mm) is
     //## inside the bounding box
-    bool IsInside(const mitk::Point3D& p) const;
+    bool IsInside(const mitk::Point3D &p) const;
 
     //##Documentation
-    //## @brief Test whether the point \a p ((continous!)index coordinates in units) is
+    //## @brief Test whether the point \a p ((continuous!)index coordinates in units) is
     //## inside the bounding box
-    bool IsIndexInside(const mitk::Point3D& index) const;
+    bool IsIndexInside(const mitk::Point3D &index) const;
 
     //##Documentation
     //## @brief Convenience method for working with ITK indices
@@ -507,7 +503,10 @@ namespace mitk {
 
     // ********************************* Image Geometry ********************************
     //##Documentation
-    //## @brief When switching from an Image Geometry to a normal Geometry (and the other way around), you have to change the origin as well (See Geometry Documentation)! This function will change the "isImageGeometry" bool flag and changes the origin respectively.
+    //## @brief When switching from an Image Geometry to a normal Geometry (and the other way around), you have to
+    //change
+    // the origin as well (See Geometry Documentation)! This function will change the "isImageGeometry" bool flag and
+    // changes the origin respectively.
     virtual void ChangeImageGeometryConsideringOriginOffset(const bool isAnImageGeometry);
 
     //##Documentation
@@ -516,7 +515,7 @@ namespace mitk {
     //## For more information, see SetImageGeometry
     itkGetConstMacro(ImageGeometry, bool)
       //##Documentation
-      //## @brief Define that this BaseGeometry is refering to an Image
+      //## @brief Define that this BaseGeometry is referring to an Image
       //##
       //## A geometry referring to an Image needs a slightly different
       //## definition of the position of the corners (see GetCornerPoint).
@@ -528,35 +527,35 @@ namespace mitk {
       //## outside the image (by half of the voxel diameter). Thus, we have
       //## to correct for this and to be able to do that, we need to know
       //## that the BaseGeometry is referring to an Image.
-      itkSetMacro(ImageGeometry, bool)
-      itkBooleanMacro(ImageGeometry)
+      itkSetMacro(ImageGeometry, bool);
+      itkBooleanMacro(ImageGeometry);
 
-      const GeometryTransformHolder* GetGeometryTransformHolder() const;
-
-  protected:
-
-    // ********************************** Constructor **********************************
-    BaseGeometry();
-    BaseGeometry(const BaseGeometry& other);
-    virtual ~BaseGeometry();
+        const GeometryTransformHolder *GetGeometryTransformHolder() const;
 
     //##Documentation
-    //## @brief clones the geometry
+    //## @brief One to one mapping of axes to world orientations.
     //##
-    //## Overwrite in all sub-classes.
-    //## Normally looks like:
-    //## \code
-    //##  Self::Pointer newGeometry = new Self(*this);
-    //##  newGeometry->UnRegister();
-    //##  return newGeometry.GetPointer();
-    //## \endcode
-    virtual itk::LightObject::Pointer InternalClone() const override = 0;
+    //## The result is stored in the output argument that must be an array of three int values.
+    //## The elements of the array will be the axis indices that correspond to the sagittal,
+    //## coronal and axial orientations, in this order. It is guaranteed that each axis will
+    //## be mapped to different orientations.
+    //##
+    //## @param axes Output argument that will store the axis indices for each orientation.
+    void MapAxesToOrientations(int axes[]) const;
 
-    virtual void PrintSelf(std::ostream& os, itk::Indent indent) const override;
+  protected:
+    // ********************************** Constructor **********************************
+    BaseGeometry();
+    BaseGeometry(const BaseGeometry &other);
+    ~BaseGeometry() override;
 
-    static const std::string GetTransformAsString(TransformType* transformType);
+    itk::LightObject::Pointer InternalClone() const override = 0;
 
-    itkGetConstMacro(NDimensions, unsigned int)
+    void PrintSelf(std::ostream &os, itk::Indent indent) const override;
+
+    static const std::string GetTransformAsString(TransformType *transformType);
+
+    itkGetConstMacro(NDimensions, unsigned int);
 
       bool IsBoundingBoxNull() const;
 
@@ -564,7 +563,7 @@ namespace mitk {
 
     void SetVtkMatrixDeepCopy(vtkTransform *vtktransform);
 
-    void _SetSpacing(const mitk::Vector3D& aSpacing, bool enforceSetSpacing = false);
+    void _SetSpacing(const mitk::Vector3D &aSpacing, bool enforceSetSpacing = false);
 
     //##Documentation
     //## @brief PreSetSpacing
@@ -572,7 +571,7 @@ namespace mitk {
     //## These virtual function allows a different beahiour in subclasses.
     //## Do implement them in every subclass of BaseGeometry. If not needed, use
     //## {Superclass::PreSetSpacing();};
-    virtual void PreSetSpacing(const mitk::Vector3D& /*aSpacing*/) {};
+    virtual void PreSetSpacing(const mitk::Vector3D & /*aSpacing*/){};
 
     //##Documentation
     //## @brief CheckBounds
@@ -580,21 +579,22 @@ namespace mitk {
     //## This function is called in SetBounds. Assertions can be implemented in this function (see PlaneGeometry.cpp).
     //## If you implement this function in a subclass, make sure, that all classes were your class inherits from
     //## have an implementation of CheckBounds
-    //## (e.g. inheritance BaseGeometry <- A <- B. Implementation of CheckBounds in class B needs implementation in A as well!)
-    virtual void CheckBounds(const BoundsArrayType& /*bounds*/){};
+    //## (e.g. inheritance BaseGeometry <- A <- B. Implementation of CheckBounds in class B needs implementation in A as
+    // well!)
+    virtual void CheckBounds(const BoundsArrayType & /*bounds*/){};
 
     //##Documentation
     //## @brief CheckIndexToWorldTransform
     //##
-    //## This function is called in SetIndexToWorldTransform. Assertions can be implemented in this function (see PlaneGeometry.cpp).
+    //## This function is called in SetIndexToWorldTransform. Assertions can be implemented in this function (see
+    // PlaneGeometry.cpp).
     //## In Subclasses of BaseGeometry, implement own conditions or call Superclass::CheckBounds(bounds);.
-    virtual void CheckIndexToWorldTransform(mitk::AffineTransform3D* /*transform*/){};
+    virtual void CheckIndexToWorldTransform(mitk::AffineTransform3D * /*transform*/){};
 
   private:
+    GeometryTransformHolder *m_GeometryTransform;
 
-    GeometryTransformHolder* m_GeometryTransform;
-
-    void InitializeGeometryTransformHolder(const BaseGeometry* otherGeometry);
+    void InitializeGeometryTransformHolder(const BaseGeometry *otherGeometry);
 
     //##Documentation
     //## @brief Bounding Box, which is axes-parallel in intrinsic coordinates
@@ -603,7 +603,7 @@ namespace mitk {
 
     unsigned int m_FrameOfReferenceID;
 
-    //mitk::TimeBounds m_TimeBounds;
+    // mitk::TimeBounds m_TimeBounds;
 
     static const unsigned int m_NDimensions = 3;
 
@@ -633,109 +633,132 @@ namespace mitk {
   // Static compare functions mainly for testing
   //
   /**
-  * @brief Equal A function comparing two geometries for beeing identical.
-  * @warning This method is deprecated and will not be available in the future. Use the \a bool mitk::Equal(const mitk::mitk::BaseGeometry& g1, const mitk::BaseGeometry& g2) instead.
+  * @brief Equal A function comparing two geometries for being identical.
   *
   * @ingroup MITKTestingAPI
   *
   * The function compares the spacing, origin, axisvectors, extents, the matrix of the
   * IndexToWorldTransform (elementwise), the bounding (elementwise) and the ImageGeometry flag.
   *
-  * The parameter eps is a tolarence value for all methods which are internally used for comparion.
-  * If you want to use different tolarance values for different parts of the geometry, feel free to use
+  * The parameter eps is a tolarence value for all methods which are internally used for comparison.
+  * If you want to use different tolerance values for different parts of the geometry, feel free to use
   * the other comparison methods and write your own implementation of Equal.
   * @param rightHandSide Compare this against leftHandSide.
   * @param leftHandSide Compare this against rightHandSide.
+  * @param coordinateEps Tolerance for comparison of all spatial aspects (spacing, origin and grid alignment).
+  * You can use mitk::eps in most cases.
+  * @param directionEps Tolerance for comparison of all directional aspects (axis). You can use mitk::eps in most cases.
+  * @param verbose Flag indicating if the user wants detailed console output or not.
+  * @return True, if all comparison are true. False in any other case.
+  */
+  MITKCORE_EXPORT bool Equal(const mitk::BaseGeometry& leftHandSide,
+    const mitk::BaseGeometry& rightHandSide,
+    ScalarType coordinateEps,
+    ScalarType directionEps,
+    bool verbose = false);
+
+  /**
+  * @brief Equal A function comparing two geometries for being identical.
+  *
+  * @ingroup MITKTestingAPI
+  *
+  * This is an overloaded version that uses a single tolerance for spatial and directional aspects. For more details,
+  * see the other overloaded version.
+  *
+  * @param rightHandSide Compare this against leftHandSide.
+  * @param leftHandSide Compare this against rightHandSide.
   * @param eps Tolarence for comparison. You can use mitk::eps in most cases.
   * @param verbose Flag indicating if the user wants detailed console output or not.
   * @return True, if all comparison are true. False in any other case.
   */
-  DEPRECATED(MITKCORE_EXPORT bool Equal(const mitk::BaseGeometry* leftHandSide, const mitk::BaseGeometry* rightHandSide, ScalarType eps, bool verbose));
+  MITKCORE_EXPORT bool Equal(const mitk::BaseGeometry &leftHandSide,
+                             const mitk::BaseGeometry &rightHandSide,
+                             ScalarType eps = mitk::eps,
+                             bool verbose = false);
 
   /**
-  * @brief Equal A function comparing two geometries for beeing identical.
+  * @brief Equal A function comparing two transforms (TransformType) for being identical.
   *
   * @ingroup MITKTestingAPI
   *
-  * The function compares the spacing, origin, axisvectors, extents, the matrix of the
+  * The function compares the IndexToWorldTransform (elementwise).
+  *
+  * The parameter eps is a tolarence value for all methods which are internally used for comparison.
+  * @param rightHandSide Compare this against leftHandSide.
+  * @param leftHandSide Compare this against rightHandSide.
+  * @param eps Tolarence for comparison. You can use mitk::eps in most cases.
+  * @param verbose Flag indicating if the user wants detailed console output or not.
+  * @return True, if all comparison are true. False in any other case.
+  */
+  MITKCORE_EXPORT bool Equal(const mitk::BaseGeometry::TransformType &leftHandSide,
+                             const mitk::BaseGeometry::TransformType &rightHandSide,
+                             ScalarType eps,
+                             bool verbose);
+
+  /**
+  * @brief Equal A function comparing two bounding boxes (BoundingBoxType) for being identical.
+  *
+  * @ingroup MITKTestingAPI
+  *
+  * The function compares the bounds (elementwise).
+  *
+  * The parameter eps is a tolarence value for all methods which are internally used for comparison.
+  * @param rightHandSide Compare this against leftHandSide.
+  * @param leftHandSide Compare this against rightHandSide.
+  * @param eps Tolarence for comparison. You can use mitk::eps in most cases.
+  * @param verbose Flag indicating if the user wants detailed console output or not.
+  * @return True, if all comparison are true. False in any other case.
+  */
+  MITKCORE_EXPORT bool Equal(const mitk::BaseGeometry::BoundingBoxType &leftHandSide,
+                             const mitk::BaseGeometry::BoundingBoxType &rightHandSide,
+                             ScalarType eps,
+                             bool verbose);
+
+  /**
+  * @brief A function checks if a test geometry is a sub geometry of
+  * a given reference geometry.
+  *
+  * Sub geometry means that both geometries have the same voxel grid (same spacing, same axes,
+  * origin is on voxel grid), but the bounding box of the checked geometry is contained or equal
+  * to the bounding box of the reference geometry.\n
+  * By this definition equal geometries are always sub geometries of each other.
+  *
+  * The function checks the spacing, origin, axis vectors, extents, the matrix of the
   * IndexToWorldTransform (elementwise), the bounding (elementwise) and the ImageGeometry flag.
   *
-  * The parameter eps is a tolarence value for all methods which are internally used for comparion.
-  * If you want to use different tolarance values for different parts of the geometry, feel free to use
-  * the other comparison methods and write your own implementation of Equal.
-  * @param rightHandSide Compare this against leftHandSide.
-  * @param leftHandSide Compare this against rightHandSide.
-  * @param eps Tolarence for comparison. You can use mitk::eps in most cases.
+  * The parameter eps is a tolerance value for all methods which are internally used for comparison.
+  * @param testGeo Geometry that should be checked if it is a sub geometry of referenceGeo.
+  * @param referenceGeo Geometry that should contain testedGeometry as sub geometry.
+  * @param coordinateEps Tolerance for comparison of all spatial aspects (spacing, origin and grid alignment).
+  * You can use mitk::eps in most cases.
+  * @param directionEps Tolerance for comparison of all directional aspects (axis). You can use mitk::eps in most cases.
   * @param verbose Flag indicating if the user wants detailed console output or not.
-  * @return True, if all comparison are true. False in any other case.
+  * @return True, if all comparisons are true. False otherwise.
   */
-  MITKCORE_EXPORT bool Equal(const mitk::BaseGeometry& leftHandSide, const mitk::BaseGeometry& rightHandSide, ScalarType eps, bool verbose);
+  MITKCORE_EXPORT bool IsSubGeometry(const mitk::BaseGeometry& testGeo,
+    const mitk::BaseGeometry& referenceGeo,
+    ScalarType coordinateEps,
+    ScalarType directionEps,
+    bool verbose = false);
 
   /**
-  * @brief Equal A function comparing two transforms (TransformType) for beeing identical.
-  * @warning This method is deprecated and will not be available in the future. Use the \a bool mitk::Equal(const mitk::mitk::BaseGeometry::TransformType& t1, const mitk::BaseGeometry::TransformType& t2) instead.
+  * @brief A function checks if a test geometry is a sub geometry of
+  * a given reference geometry.
   *
-  * @ingroup MITKTestingAPI
+  * This is a overloaded version that uses a single tolerance for spatial and directional aspects. For more details,
+  * see the other overloaded version.
   *
-  * The function compares the IndexToWorldTransform (elementwise).
-  *
-  * The parameter eps is a tolarence value for all methods which are internally used for comparion.
-  * @param rightHandSide Compare this against leftHandSide.
-  * @param leftHandSide Compare this against rightHandSide.
-  * @param eps Tolarence for comparison. You can use mitk::eps in most cases.
+  * @param testGeo Geometry that should be checked if it is a sub geometry of referenceGeo.
+  * @param referenceGeo Geometry that should contain testedGeometry as sub geometry.
+  * @param eps Tolarence for comparison (both spatial and directional). You can use mitk::eps in most cases.
   * @param verbose Flag indicating if the user wants detailed console output or not.
-  * @return True, if all comparison are true. False in any other case.
+  * @return True, if all comparison are true. False otherwise.
   */
-  DEPRECATED(MITKCORE_EXPORT bool Equal(const mitk::BaseGeometry::TransformType *leftHandSide, const mitk::BaseGeometry::TransformType *rightHandSide, ScalarType eps, bool verbose));
+  MITKCORE_EXPORT bool IsSubGeometry(const mitk::BaseGeometry& testGeo,
+    const mitk::BaseGeometry& referenceGeo,
+    ScalarType eps = mitk::eps,
+    bool verbose = false);
 
-  /**
-  * @brief Equal A function comparing two transforms (TransformType) for beeing identical.
-  *
-  * @ingroup MITKTestingAPI
-  *
-  * The function compares the IndexToWorldTransform (elementwise).
-  *
-  * The parameter eps is a tolarence value for all methods which are internally used for comparion.
-  * @param rightHandSide Compare this against leftHandSide.
-  * @param leftHandSide Compare this against rightHandSide.
-  * @param eps Tolarence for comparison. You can use mitk::eps in most cases.
-  * @param verbose Flag indicating if the user wants detailed console output or not.
-  * @return True, if all comparison are true. False in any other case.
-  */
-  MITKCORE_EXPORT bool Equal(const mitk::BaseGeometry::TransformType& leftHandSide, const mitk::BaseGeometry::TransformType& rightHandSide, ScalarType eps, bool verbose);
-
-  /**
-  * @brief Equal A function comparing two bounding boxes (BoundingBoxType) for beeing identical.
-  * @warning This method is deprecated and will not be available in the future. Use the \a bool mitk::Equal(const mitk::mitk::BaseGeometry::BoundingBoxType& b1, const mitk::BaseGeometry::BoundingBoxType& b2) instead.
-  *
-  * @ingroup MITKTestingAPI
-  *
-  * The function compares the bounds (elementwise).
-  *
-  * The parameter eps is a tolarence value for all methods which are internally used for comparion.
-  * @param rightHandSide Compare this against leftHandSide.
-  * @param leftHandSide Compare this against rightHandSide.
-  * @param eps Tolarence for comparison. You can use mitk::eps in most cases.
-  * @param verbose Flag indicating if the user wants detailed console output or not.
-  * @return True, if all comparison are true. False in any other case.
-  */
-  DEPRECATED(MITKCORE_EXPORT bool Equal(const mitk::BaseGeometry::BoundingBoxType *leftHandSide, const mitk::BaseGeometry::BoundingBoxType *rightHandSide, ScalarType eps, bool verbose));
-
-  /**
-  * @brief Equal A function comparing two bounding boxes (BoundingBoxType) for beeing identical.
-  *
-  * @ingroup MITKTestingAPI
-  *
-  * The function compares the bounds (elementwise).
-  *
-  * The parameter eps is a tolarence value for all methods which are internally used for comparion.
-  * @param rightHandSide Compare this against leftHandSide.
-  * @param leftHandSide Compare this against rightHandSide.
-  * @param eps Tolarence for comparison. You can use mitk::eps in most cases.
-  * @param verbose Flag indicating if the user wants detailed console output or not.
-  * @return True, if all comparison are true. False in any other case.
-  */
-  MITKCORE_EXPORT bool Equal(const  mitk::BaseGeometry::BoundingBoxType& leftHandSide, const mitk::BaseGeometry::BoundingBoxType& rightHandSide, ScalarType eps, bool verbose);
 } // namespace mitk
 
-#endif /* BaseGeometry_H_HEADER_INCLUDED */
+#endif
