@@ -1,40 +1,28 @@
-/*===================================================================
+/*============================================================================
 
 The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
+============================================================================*/
 
-===================================================================*/
+#ifndef mitkNumericTypes_h
+#define mitkNumericTypes_h
 
-
-#ifndef MITKNUMERICTYPES_H_
-#define MITKNUMERICTYPES_H_
-
-
-#include "mitkNumericConstants.h"
-#include "mitkQuaternion.h"
 #include "mitkAffineTransform3D.h"
-#include "mitkPoint.h"
-#include "mitkVector.h"
-#include "mitkMatrix.h"
 #include "mitkEqual.h"
-
+#include "mitkMatrix.h"
+#include "mitkNumericConstants.h"
+#include "mitkPoint.h"
+#include "mitkQuaternion.h"
+#include "mitkVector.h"
 
 // this include hold the old deprecated ways to convert from itk 2 vtk and the likes.
 // calls to these functions shall be removed in future bugsquashings so that this include can be removed.
 #include "mitkVectorDeprecated.h"
 
-
-
-
-
-
-#endif /* MITKNUMERICTYPES_H_ */
+#endif
