@@ -32,7 +32,7 @@ namespace mitk
 {
   class RenderingManagerFactory;
   class BaseGeometry;
-  class SliceNavigationController;
+  class TimeNavigationController;
   class BaseRenderer;
   class DataStorage;
 
@@ -147,7 +147,7 @@ namespace mitk
     * @brief Initialize the given render window by the aggregated geometry of all objects that are held in
     *        the data storage.
     *
-    * @param renderWindow     The specifid render window to update
+    * @param renderWindow     The specified render window to update
     * @param dataStorage      The data storage from which the bounding object can be retrieved
     * @param resetCamera      If this parameter is set to true, the camera controller will be
     *                         set / fit to the center of the rendered image. If set to false, only the
@@ -261,13 +261,13 @@ namespace mitk
     */
     virtual bool InitializeView(vtkRenderWindow *renderWindow);
 
-    /** Gets the (global) SliceNavigationController responsible for
+    /** Gets the (global) TimeNavigationController responsible for
      * time-slicing. */
-    const SliceNavigationController *GetTimeNavigationController() const;
+    const TimeNavigationController* GetTimeNavigationController() const;
 
-    /** Gets the (global) SliceNavigationController responsible for
+    /** Gets the (global) TimeNavigationController responsible for
      * time-slicing. */
-    SliceNavigationController *GetTimeNavigationController();
+    TimeNavigationController* GetTimeNavigationController();
 
     ~RenderingManager() override;
 
@@ -420,7 +420,7 @@ namespace mitk
 
     RenderWindowCallbacksList m_RenderWindowCallbacksList;
 
-    itk::SmartPointer<SliceNavigationController> m_TimeNavigationController;
+    itk::SmartPointer<TimeNavigationController> m_TimeNavigationController;
 
     static RenderingManager::Pointer s_Instance;
     static RenderingManagerFactory *s_RenderingManagerFactory;
