@@ -67,6 +67,16 @@ void mitk::WeakPointerProperty::SetValue(const ValueType &value)
   SetWeakPointer(value.GetPointer());
 }
 
+bool mitk::WeakPointerProperty::ToJSON(nlohmann::json&) const
+{
+  return false;
+}
+
+bool mitk::WeakPointerProperty::FromJSON(const nlohmann::json&)
+{
+  return false;
+}
+
 itk::LightObject::Pointer mitk::WeakPointerProperty::InternalClone() const
 {
   itk::LightObject::Pointer result(new Self(*this));
