@@ -1,15 +1,15 @@
-/*=============================================================================
+/*============================================================================
 
   Library: CppMicroServices
 
-  Copyright (c) German Cancer Research Center,
-    Division of Medical and Biological Informatics
+  Copyright (c) German Cancer Research Center (DKFZ)
+  All rights reserved.
 
   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at
 
-    http://www.apache.org/licenses/LICENSE-2.0
+    https://www.apache.org/licenses/LICENSE-2.0
 
   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
@@ -17,7 +17,7 @@
   See the License for the specific language governing permissions and
   limitations under the License.
 
-=============================================================================*/
+============================================================================*/
 
 #include <usTestingMacros.h>
 #include <usTestingConfig.h>
@@ -176,7 +176,7 @@ public:
       catch (const std::exception& e)
       {
         teststatus = false;
-        US_TEST_OUTPUT( << "*** Unexpected excpetion when trying to lookup a"
+        US_TEST_OUTPUT( << "*** Unexpected exception when trying to lookup a"
                           " service while it is in state UNREGISTERING: "
                           << e.what() );
       }
@@ -398,7 +398,7 @@ void frameSL25a()
     throw;
   }
 
-  // Start libModuleTestSL4 that will require the serivce interface and publish
+  // Start libModuleTestSL4 that will require the service interface and publish
   // us::FooService
   try
   {
@@ -411,7 +411,7 @@ void frameSL25a()
     throw;
   }
 
-  // Start libModuleTestSL3 that will require the serivce interface and get the service
+  // Start libModuleTestSL3 that will require the service interface and get the service
   try
   {
     US_TEST_OUTPUT( << "Starting libModuleTestSL3: " << libSL3.GetFilePath() );
