@@ -1,15 +1,15 @@
-/*=============================================================================
+/*============================================================================
 
   Library: CppMicroServices
 
-  Copyright (c) German Cancer Research Center,
-    Division of Medical and Biological Informatics
+  Copyright (c) German Cancer Research Center (DKFZ)
+  All rights reserved.
 
   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at
 
-    http://www.apache.org/licenses/LICENSE-2.0
+    https://www.apache.org/licenses/LICENSE-2.0
 
   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
@@ -17,7 +17,7 @@
   See the License for the specific language governing permissions and
   limitations under the License.
 
-=============================================================================*/
+============================================================================*/
 
 #include "miniz.h"
 
@@ -210,7 +210,7 @@ void* malloc_or_abort(size_t size)
   if (!p)
   {
     // try to print an error message; this might very well fail
-    fprintf(stderr, "Could not allocate enough memory (%ld bytes)\n", size);
+    fprintf(stderr, "Could not allocate enough memory (%lld bytes)\n", size);
     abort();
   }
   return p;
@@ -277,7 +277,7 @@ static int us_archived_names_append(us_archived_names* archivedNames, const char
     archivedNames->names = realloc(archivedNames->names, newCapacity * sizeof(char*));
     if (archivedNames->names == NULL)
     {
-      fprintf(stderr, "Could not realloc enough memory (%ld bytes)\n", newCapacity);
+      fprintf(stderr, "Could not realloc enough memory (%lld bytes)\n", newCapacity);
       abort();
     }
     memset(archivedNames->names + archivedNames->capacity, 0, sizeof(char*) * (newCapacity - archivedNames->capacity));
@@ -308,7 +308,7 @@ static int us_zip_writer_add_dir_entries(mz_zip_archive* pZip, const char* pArch
   if (sizeof dirName < length - 1)
   {
     // This should be impossible
-    fprintf(stderr, "Archive file name '%s' too long (%ld > %ld)", pArchive_name, length-1, sizeof dirName);
+    fprintf(stderr, "Archive file name '%s' too long (%lld > %lld)", pArchive_name, length-1, sizeof dirName);
     exit(EXIT_FAILURE);
   }
 
