@@ -67,7 +67,7 @@ mitk::Label::Label(PixelType value, const std::string& name) : Label()
 }
 
 mitk::Label::Label(const Label &other) : PropertyList(other)
-// copyconstructer of property List handles the coping action
+// copy constructor of property List handles the coping action
 {
   auto *map = this->GetMap();
   auto it = map->begin();
@@ -160,6 +160,11 @@ std::string mitk::Label::GetName() const
   return name;
 }
 
+std::string mitk::Label::GetTrackingID() const
+{
+  return std::to_string(this->GetValue());
+}
+
 void mitk::Label::SetValue(PixelType pixelValue)
 {
   mitk::UShortProperty *property = dynamic_cast<mitk::UShortProperty *>(GetProperty("value"));
