@@ -16,6 +16,7 @@ found in the LICENSE file.
 #include "MitkMultilabelExports.h"
 #include <mitkColorProperty.h>
 #include <mitkPropertyList.h>
+#include <mitkPoint.h>
 #include <mitkVector.h>
 
 namespace mitk
@@ -38,6 +39,9 @@ namespace mitk
     /// The maximum value a label can get: Since the value is of type unsigned short MAX_LABEL_VALUE = 65535
     static const PixelType MAX_LABEL_VALUE;
 
+    //** Value indicating pixels that are not labeled at all.*/
+    static constexpr PixelType UNLABELED_VALUE = 0;
+
     void SetLocked(bool locked);
     bool GetLocked() const;
 
@@ -50,6 +54,8 @@ namespace mitk
     void SetName(const std::string &name);
     std::string GetName() const;
 
+    std::string GetTrackingID() const;
+
     void SetCenterOfMassIndex(const mitk::Point3D &center);
     mitk::Point3D GetCenterOfMassIndex() const;
 
@@ -82,8 +88,11 @@ namespace mitk
     itk::LightObject::Pointer InternalClone() const override;
   };
 
+  using LabelVector = std::vector<Label::Pointer>;
+  using ConstLabelVector = std::vector<Label::ConstPointer>;
+
   /**
-  * @brief Equal A function comparing two labels for beeing equal in data
+  * @brief Equal A function comparing two labels for being equal in data
   *
   * @ingroup MITKTestingAPI
   *
