@@ -1,18 +1,14 @@
-/*===================================================================
+/*============================================================================
 
 The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
-
-===================================================================*/
+============================================================================*/
 
 #ifndef CUSTOMVIEWER_H_
 #define CUSTOMVIEWER_H_
@@ -38,17 +34,16 @@ class CustomViewer : public QObject, public berry::IApplication
   Q_INTERFACES(berry::IApplication)
 
 public:
-
-/** Standard constructor.*/
+  /** Standard constructor.*/
   CustomViewer();
 
-/** Standard destructor.*/
-  ~CustomViewer();
+  /** Standard destructor.*/
+  ~CustomViewer() override;
 
-/** Starts the application.*/
-  QVariant Start(berry::IApplicationContext* context) override;
+  /** Starts the application.*/
+  QVariant Start(berry::IApplicationContext *context) override;
 
-/** Exits the application.*/
+  /** Exits the application.*/
   void Stop() override;
 };
 
