@@ -1,18 +1,14 @@
-/*===================================================================
+/*============================================================================
 
 The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
-
-===================================================================*/
+============================================================================*/
 
 #ifndef EXTENSIONPOINTDEFINITION_H_
 #define EXTENSIONPOINTDEFINITION_H_
@@ -32,15 +28,13 @@ class ExtensionPointDefinition : public QObject, public berry::IApplication
   Q_INTERFACES(berry::IApplication)
 
 public:
-
   ExtensionPointDefinition();
-  ~ExtensionPointDefinition();
+  ~ExtensionPointDefinition() override;
 
-  QVariant Start(berry::IApplicationContext* context) override;
+  QVariant Start(berry::IApplicationContext *context) override;
   void Stop() override;
 
 private:
-
   QScopedPointer<MinimalWorkbenchAdvisor> wbAdvisor;
 };
 
