@@ -23,7 +23,7 @@ class MITKQTWIDGETSEXT_EXPORT QmitkColorTransferFunctionCanvas : public QmitkTra
   Q_OBJECT
 
 public:
-  QmitkColorTransferFunctionCanvas(QWidget *parent = nullptr, Qt::WindowFlags f = nullptr);
+  QmitkColorTransferFunctionCanvas(QWidget *parent = nullptr, Qt::WindowFlags f = {});
   void paintEvent(QPaintEvent *e) override;
   int GetNearHandle(int x, int y, unsigned int maxSquaredDistance = 32) override;
   void SetTitle(const QString &title);
