@@ -29,7 +29,7 @@ class MITKQTWIDGETSEXT_EXPORT QmitkEditPointDialog : public QDialog
   Q_OBJECT
 
 public:
-  QmitkEditPointDialog(QWidget *parent = nullptr, Qt::WindowFlags f = nullptr);
+  QmitkEditPointDialog(QWidget *parent = nullptr, Qt::WindowFlags f = {});
   ~QmitkEditPointDialog() override;
 
   void SetPoint(mitk::PointSet *_PointSet, mitk::PointSet::PointIdentifier _PointId, int timestep = 0);
