@@ -16,7 +16,7 @@ found in the LICENSE file.
 QmitkColorPropertyView::QmitkColorPropertyView(const mitk::ColorProperty *property, QWidget *parent)
   : QLabel(parent), PropertyView(property), m_ColorProperty(property)
 {
-  setText("  "); // two spaces for some minimun height
+  setText("  "); // two spaces for some minimum height
   setMinimumSize(15, 15);
   PropertyChanged();
 
@@ -47,5 +47,5 @@ void QmitkColorPropertyView::DisplayColor()
 
   QColor color(ROUND_P(tmp_col[0] * 255.0), ROUND_P(tmp_col[1] * 255.0), ROUND_P(tmp_col[2] * 255.0));
 
-  m_WidgetPalette.setColor(QPalette::Background, color);
+  m_WidgetPalette.setColor(QPalette::Window, color);
 }
