@@ -20,7 +20,7 @@ QmitkStringPropertyOnDemandEdit::QmitkStringPropertyOnDemandEdit(mitk::StringPro
 
   // create HBoxLayout with two buttons
   m_layout = new QHBoxLayout(this);
-  m_layout->setMargin(0);
+  m_layout->setContentsMargins({});
 
   m_label = new QLabel(this);
   m_layout->addWidget(m_label);
