@@ -30,7 +30,8 @@ QmitkTransferFunctionWidget::QmitkTransferFunctionWidget(QWidget *parent, Qt::Wi
 
   m_RangeSlider->setMinimum(-2048);
   m_RangeSlider->setMaximum(2048);
-  connect(m_RangeSlider, SIGNAL(valuesChanged(int, int)), this, SLOT(OnSpanChanged(int, int)));
+  UpdateStepSize();
+  connect(m_RangeSlider, SIGNAL(valuesChanged(double, double)), this, SLOT(OnSpanChanged(double, double)));
 
   // reset button
   connect(m_RangeSliderReset, SIGNAL(pressed()), this, SLOT(OnResetSlider()));
@@ -128,14 +129,15 @@ void QmitkTransferFunctionWidget::SetDataNode(mitk::DataNode *node, mitk::TimeSt
         h = histogramCache[data];
       }
 
-      m_RangeSliderMin = h->GetMin();
-      m_RangeSliderMax = h->GetMax();
+      auto rangeSliderMin = h->GetMin();
+      auto rangeSliderMax = h->GetMax();
+      UpdateStepSize();
 
       m_RangeSlider->blockSignals(true);
-      m_RangeSlider->setMinimum(m_RangeSliderMin);
-      m_RangeSlider->setMaximum(m_RangeSliderMax);
-      m_RangeSlider->setMinimumValue(m_RangeSliderMin);
-      m_RangeSlider->setMaximumValue(m_RangeSliderMax);
+      m_RangeSlider->setMinimum(rangeSliderMin);
+      m_RangeSlider->setMaximum(rangeSliderMax);
+      m_RangeSlider->setMinimumValue(rangeSliderMin);
+      m_RangeSlider->setMaximumValue(rangeSliderMax);
       m_RangeSlider->blockSignals(false);
 
       m_ScalarOpacityFunctionCanvas->SetHistogram(h);
@@ -227,8 +229,8 @@ void QmitkTransferFunctionWidget::SetXValueColor(const QString text)
 
 void QmitkTransferFunctionWidget::UpdateRanges()
 {
-  int lower = m_RangeSlider->minimumValue();
-  int upper = m_RangeSlider->maximumValue();
+  double lower = m_RangeSlider->minimumValue();
+  double upper = m_RangeSlider->maximumValue();
 
   m_ScalarOpacityFunctionCanvas->SetMin(lower);
   m_ScalarOpacityFunctionCanvas->SetMax(upper);
@@ -240,7 +242,13 @@ void QmitkTransferFunctionWidget::UpdateRanges()
   m_ColorTransferFunctionCanvas->SetMax(upper);
 }
 
-void QmitkTransferFunctionWidget::OnSpanChanged(int, int)
+void QmitkTransferFunctionWidget::UpdateStepSize()
+{
+  double step = (m_RangeSlider->maximum() - m_RangeSlider->minimum()) / 1000.;
+  m_RangeSlider->setSingleStep(step);
+}
+
+void QmitkTransferFunctionWidget::OnSpanChanged(double, double)
 {
   UpdateRanges();
 
@@ -252,8 +260,8 @@ void QmitkTransferFunctionWidget::OnSpanChanged(int, int)
 void QmitkTransferFunctionWidget::OnResetSlider()
 {
   m_RangeSlider->blockSignals(true);
-  m_RangeSlider->setMaximumValue(m_RangeSliderMax);
-  m_RangeSlider->setMinimumValue(m_RangeSliderMin);
+  m_RangeSlider->setMaximumValue(m_RangeSlider->maximum());
+  m_RangeSlider->setMinimumValue(m_RangeSlider->minimum());
   m_RangeSlider->blockSignals(false);
 
   UpdateRanges();
