@@ -30,12 +30,19 @@ namespace mitk
     mitkClassMacro(ContourModelSetToImageFilter, ImageSource);
     itkFactorylessNewMacro(Self);
     itkCloneMacro(Self);
-    itkSetMacro(MakeOutputBinary, bool);
-    itkGetMacro(MakeOutputBinary, bool);
-    itkBooleanMacro(MakeOutputBinary);
 
+    virtual void SetMakeOutputBinary(bool makeOutputBinary);
+    virtual void SetMakeOutputLabelPixelType(bool makeOutputLabelPixelType);
+    itkSetMacro(PaintingPixelValue, int);
     itkSetMacro(TimeStep, unsigned int);
 
+    itkGetMacro(MakeOutputBinary, bool);
+    itkGetMacro(MakeOutputLabelPixelType, bool);
+    itkGetMacro(PaintingPixelValue, int);
+
+    itkBooleanMacro(MakeOutputBinary);
+    itkBooleanMacro(MakeOutputLabelPixelType);
+
     /**
        * Allocates a new output object and returns it. Currently the
        * index idx is not evaluated.
@@ -46,7 +53,7 @@ namespace mitk
 
     /**
        * This is a default implementation to make sure we have something.
-       * Once all the subclasses of ProcessObject provide an appopriate
+       * Once all the subclasses of ProcessObject provide an appropriate
        * MakeOutput(), then ProcessObject::MakeOutput() can be made pure
        * virtual.
        */
@@ -82,6 +89,8 @@ namespace mitk
     void InitializeOutputEmpty();
 
     bool m_MakeOutputBinary;
+    bool m_MakeOutputLabelPixelType;
+    int m_PaintingPixelValue;
 
     unsigned int m_TimeStep;
 
