@@ -37,7 +37,7 @@ void mitk::DiffSliceOperationApplier::ExecuteOperation(Operation *operation)
   if (!imageOperation)
     return;
 
-  // chak if the operation is valid
+  // check if the operation is valid
   if (imageOperation->IsValid())
   {
     // the actual overwrite filter (vtk)
@@ -66,19 +66,8 @@ void mitk::DiffSliceOperationApplier::ExecuteOperation(Operation *operation)
     RenderingManager::GetInstance()->RequestUpdateAll();
     imageOperation->GetImage()->Modified();
 
-    mitk::ExtractSliceFilter::Pointer extractor2 = mitk::ExtractSliceFilter::New();
-    extractor2->SetInput(imageOperation->GetImage());
-    extractor2->SetTimeStep(imageOperation->GetTimeStep());
-    extractor2->SetWorldGeometry(dynamic_cast<const PlaneGeometry *>(imageOperation->GetWorldGeometry()));
-    extractor2->SetResliceTransformByGeometry(imageOperation->GetImage()->GetGeometry(imageOperation->GetTimeStep()));
-    extractor2->Modified();
-    extractor2->Update();
-
-    // TODO Move this code to SurfaceInterpolationController!
-    mitk::Image::Pointer slice2 = extractor2->GetOutput();
-    mitk::PlaneGeometry::ConstPointer plane = dynamic_cast<const PlaneGeometry *>(imageOperation->GetWorldGeometry());
-    slice2->DisconnectPipeline();
-    mitk::SegTool2D::UpdateSurfaceInterpolation(slice2, imageOperation->GetImage(), plane, true);
+    PlaneGeometry::ConstPointer plane = dynamic_cast<const PlaneGeometry *>(imageOperation->GetWorldGeometry());
+    SegTool2D::UpdateAllSurfaceInterpolations(dynamic_cast<LabelSetImage*>(imageOperation->GetImage()), imageOperation->GetTimeStep(), plane, true);
   }
 }
 
