@@ -1,24 +1,20 @@
-/*===================================================================
+/*============================================================================
 
 The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
+============================================================================*/
 
-===================================================================*/
+#ifndef mitkShowSegmentationAsSmoothedSurface_h
+#define mitkShowSegmentationAsSmoothedSurface_h
 
-#ifndef MITK_SHOW_SEGMENTATION_AS_SMOOTHED_SURFACE_H
-#define MITK_SHOW_SEGMENTATION_AS_SMOOTHED_SURFACE_H
-
-#include <MitkSegmentationExports.h>
 #include "mitkSegmentationSink.h"
+#include <MitkSegmentationExports.h>
 #include <mitkSurface.h>
 
 namespace mitk
@@ -37,7 +33,7 @@ namespace mitk
 
   private:
     ShowSegmentationAsSmoothedSurface();
-    ~ShowSegmentationAsSmoothedSurface();
+    ~ShowSegmentationAsSmoothedSurface() override;
 
     Surface::Pointer m_Surface;
   };
