@@ -16,13 +16,13 @@ found in the LICENSE file.
 #include <MitkSegmentationExports.h>
 #include <vtkImageReslice.h>
 
-/** \brief A vtk Filter based on vtkImageReslice with the aditional feature to write a slice into the given input
+/** \brief A vtk Filter based on vtkImageReslice with the additional feature to write a slice into the given input
 volume.
   All optimizations for e.g. the plane directions or interpolation are stripped away, the algorithm only interpolates
 nearest
   neighbor and uses the non optimized execute function of vtkImageReslice. Note that any interpolation doesn't make
 sense
-for round trip use extract->edit->overwrite, because it is nearly impossible to invert the interolation.
+for round trip use extract->edit->overwrite, because it is nearly impossible to invert the interpolation.
   There are two use cases for the Filter which are specified by the overwritemode property:
 
   1)Extract slices from a 3D volume.
@@ -46,7 +46,7 @@ for round trip use extract->edit->overwrite, because it is nearly impossible to
     After calling Update() there is no need to retrieve the output as the input volume is modified.
 
     \sa vtkImageReslice
-    (Note that the execute and interpolation functions are no members and thus can not be overriden)
+    (Note that the execute and interpolation functions are no members and thus can not be overridden)
  */
 class MITKSEGMENTATION_EXPORT mitkVtkImageOverwrite : public vtkImageReslice
 {
