@@ -40,15 +40,13 @@ namespace mitk
     \ingroup Interaction
     \ingroup ToolManagerEtAl
 
-    There is a separate page describing the general design of QmitkSegmentationView: \ref QmitkSegmentationTechnicalPage
-
     This class creates and manages several instances of mitk::Tool.
 
     \li ToolManager creates instances of mitk::Tool by asking the itk::ObjectFactory to list all known implementations
     of mitk::Tool.
         As a result, one has to implement both a subclass of mitk::Tool and a matching subclass of
     itk::ObjectFactoryBase that is registered
-        to the top-level itk::ObjectFactory. For an example, see mitkContourToolFactory.h. (this limitiation of
+        to the top-level itk::ObjectFactory. For an example, see mitkContourToolFactory.h. (this limitation of
     one-class-one-factory is due
         to the implementation of itk::ObjectFactory).
         In MITK, the right place to register the factories to itk::ObjectFactory is the mitk::QMCoreObjectFactory or
@@ -70,7 +68,7 @@ namespace mitk
     ask for the active Tool using
           GetActiveTool or GetActiveToolID (where nullptr or -1 indicate that NO tool is active at the moment).
 
-    Design descisions:
+    Design decisions:
 
     \li Not a singleton, because there could be two functionalities using tools, each one with different
     reference/working data.
@@ -118,7 +116,7 @@ namespace mitk
     /**
       \param id The tool to activate. Provide -1 for disabling any tools.
       Counting starts with 0.
-      Registeres a listner for NodeRemoved event at DataStorage (see mitk::ToolManager::OnNodeRemoved).
+      Registers a listener for NodeRemoved event at DataStorage (see mitk::ToolManager::OnNodeRemoved).
     */
     bool ActivateTool(int id);
 
@@ -294,7 +292,7 @@ namespace mitk
     /** Tag of the observer that listens to time changes*/
     unsigned long m_TimePointObserverTag = 0;
     /** Pointer to the observed time stepper*/
-    WeakPointer<SliceNavigationController> m_CurrentTimeNavigationController;
+    WeakPointer<TimeNavigationController> m_CurrentTimeNavigationController;
   };
 
 } // namespace
