@@ -53,7 +53,7 @@ void mitk::FillRegionTool::PrepareFilling(const Image* /*workingSlice*/, Point3D
 
   if (nullptr == labelSetImage) mitkThrow() << "Invalid state of FillRegionTool. Working image is not of correct type.";
 
-  m_FillLabelValue = labelSetImage->GetActiveLabel(labelSetImage->GetActiveLayer())->GetValue();
+  m_FillLabelValue = labelSetImage->GetActiveLabel()->GetValue();
   m_MergeStyle = MultiLabelSegmentation::MergeStyle::Merge;
 };
 
