@@ -19,6 +19,7 @@ found in the LICENSE file.
 
 #include "mitkDataStorage.h"
 #include "mitkRenderingManager.h"
+#include <mitkTimeNavigationController.h>
 
 #include "mitkImageAccessByItk.h"
 #include "mitkImageCast.h"
@@ -131,6 +132,7 @@ void mitk::SegWithPreviewTool::Activated()
   {
     this->GetToolManager()->ActivateTool(-1);
   }
+  m_IsPreviewGenerated = false;
 }
 
 void mitk::SegWithPreviewTool::Deactivated()
@@ -183,6 +185,7 @@ void mitk::SegWithPreviewTool::ConfirmSegmentation()
   {
     this->GetToolManager()->ActivateTool(-1);
   }
+  this->ConfirmCleanUp();
 }
 
 void  mitk::SegWithPreviewTool::InitiateToolByInput()
@@ -248,6 +251,7 @@ void mitk::SegWithPreviewTool::ResetPreviewContentAtTimeStep(unsigned int timeSt
   if (nullptr != previewImage)
   {
     AccessByItk(previewImage, ClearBufferProcessing);
+    previewImage->Modified();
   }
 }
 
@@ -297,26 +301,25 @@ void mitk::SegWithPreviewTool::ResetPreviewNode()
 
       m_PreviewSegmentationNode->SetData(newPreviewImage);
 
-      auto* activeLabelSet = newPreviewImage->GetActiveLabelSet();
-      if (nullptr == activeLabelSet)
+      if (newPreviewImage->GetNumberOfLayers() == 0)
       {
         newPreviewImage->AddLayer();
-        activeLabelSet = newPreviewImage->GetActiveLabelSet();
+        newPreviewImage->SetActiveLayer(0);
       }
 
-      auto* activeLabel = activeLabelSet->GetActiveLabel();
+      auto* activeLabel = newPreviewImage->GetActiveLabel();
       if (nullptr == activeLabel)
       {
-        activeLabel = activeLabelSet->AddLabel("toolresult", previewColor);
-        activeLabelSet = newPreviewImage->GetActiveLabelSet();
-        activeLabelSet->UpdateLookupTable(activeLabel->GetValue());
+        activeLabel = newPreviewImage->AddLabel("toolresult", previewColor, newPreviewImage->GetActiveLayer());
+        newPreviewImage->UpdateLookupTable(activeLabel->GetValue());
       }
       else if (m_UseSpecialPreviewColor)
       {
         // Let's paint the feedback node green...
         activeLabel->SetColor(previewColor);
-        activeLabelSet->UpdateLookupTable(activeLabel->GetValue());
+        newPreviewImage->UpdateLookupTable(activeLabel->GetValue());
       }
+      newPreviewImage->GetLookupTable()->Modified();
       activeLabel->SetVisible(true);
     }
     else
@@ -399,10 +402,10 @@ mitk::SegWithPreviewTool::LabelMappingType mitk::SegWithPreviewTool::GetLabelMap
       break;
     case LabelTransferScope::AllLabels:
       {
-        const auto labelSet = this->GetPreviewSegmentation()->GetActiveLabelSet();
-        for (auto labelIter = labelSet->IteratorConstBegin(); labelIter != labelSet->IteratorConstEnd(); ++labelIter)
+        const auto labelValues = this->GetPreviewSegmentation()->GetLabelValuesByGroup(this->GetPreviewSegmentation()->GetActiveLayer());
+        for (auto labelValue : labelValues)
         {
-        labelMapping.push_back({labelIter->second->GetValue(), labelIter->second->GetValue() + offset});
+        labelMapping.push_back({ labelValue, labelValue + offset});
         }
       }
       break;
@@ -445,7 +448,23 @@ void mitk::SegWithPreviewTool::TransferImageAtTimeStep(const Image* sourceImage,
     if (nullptr != this->GetWorkingPlaneGeometry())
     {
       auto sourceSlice = SegTool2D::GetAffectedImageSliceAs2DImage(this->GetWorkingPlaneGeometry(), sourceImage, timeStep);
-      SegTool2D::WriteBackSegmentationResult(this->GetTargetSegmentationNode(), m_WorkingPlaneGeometry, sourceSlice, timeStep);
+      auto resultSlice =
+        SegTool2D::GetAffectedImageSliceAs2DImage(this->GetWorkingPlaneGeometry(), destinationImage, timeStep)->Clone();
+      auto destLSImage = dynamic_cast<LabelSetImage *>(destinationImage);
+      //We need to transfer explictly to a copy of the current working image to ensure that labelMapping is done and things
+      //like merge style, overwrite style and locks are regarded.
+      TransferLabelContentAtTimeStep(sourceSlice,
+                                     resultSlice,
+                                     destLSImage->GetConstLabelsByValue(destLSImage->GetLabelValuesByGroup(destLSImage->GetActiveLayer())),
+                                     timeStep,
+                                     0,
+                                     0,
+                                     destLSImage->GetUnlabeledLabelLock(),
+                                     labelMapping,
+                                     m_MergeStyle,
+                                     m_OverwriteStyle);
+      //We use WriteBackSegmentationResult to ensure undo/redo is supported also by derived tools of this class.
+      SegTool2D::WriteBackSegmentationResult(this->GetTargetSegmentationNode(), m_WorkingPlaneGeometry, resultSlice, timeStep);
     }
     else
     { //take care of the full segmentation volume
@@ -472,7 +491,7 @@ void mitk::SegWithPreviewTool::CreateResultSegmentationFromPreview()
 
     if (resultSegmentationNode.IsNotNull())
     {
-      const auto timePoint = RenderingManager::GetInstance()->GetTimeNavigationController()->GetSelectedTimePoint();
+      const TimePointType timePoint = RenderingManager::GetInstance()->GetTimeNavigationController()->GetSelectedTimePoint();
       auto resultSegmentation = dynamic_cast<Image*>(resultSegmentationNode->GetData());
 
       // REMARK: the following code in this scope assumes that previewImage and resultSegmentation
@@ -551,7 +570,7 @@ void mitk::SegWithPreviewTool::OnTimePointChanged()
 {
   if (m_IsTimePointChangeAware && m_PreviewSegmentationNode.IsNotNull() && m_SegmentationInputNode.IsNotNull())
   {
-    const auto timePoint = RenderingManager::GetInstance()->GetTimeNavigationController()->GetSelectedTimePoint();
+    const TimePointType timePoint = RenderingManager::GetInstance()->GetTimeNavigationController()->GetSelectedTimePoint();
 
     const bool isStaticSegOnDynamicImage = m_PreviewSegmentationNode->GetData()->GetTimeSteps() == 1 && m_SegmentationInputNode->GetData()->GetTimeSteps() > 1;
     if (timePoint!=m_LastTimePointOfUpdate && (isStaticSegOnDynamicImage || m_LazyDynamicPreviews))
@@ -570,7 +589,7 @@ bool mitk::SegWithPreviewTool::EnsureUpToDateUserDefinedActiveLabel()
   if (const auto& labelSetImage = dynamic_cast<const LabelSetImage*>(workingImage))
   {
     // this is a fix for T28131 / T28986, which should be refactored if T28524 is being worked on
-    auto newLabel = labelSetImage->GetActiveLabel(labelSetImage->GetActiveLayer())->GetValue();
+    auto newLabel = labelSetImage->GetActiveLabel()->GetValue();
     labelChanged = newLabel != m_UserDefinedActiveLabel;
     m_UserDefinedActiveLabel = newLabel;
   }
@@ -593,10 +612,10 @@ void mitk::SegWithPreviewTool::UpdatePreview(bool ignoreLazyPreviewSetting)
 
   this->CurrentlyBusy.Send(true);
   m_IsUpdating = true;
-
+  m_IsPreviewGenerated = false;
   this->UpdatePrepare();
 
-  const auto timePoint = RenderingManager::GetInstance()->GetTimeNavigationController()->GetSelectedTimePoint();
+  const TimePointType timePoint = RenderingManager::GetInstance()->GetTimeNavigationController()->GetSelectedTimePoint();
 
   try
   {
@@ -649,6 +668,10 @@ void mitk::SegWithPreviewTool::UpdatePreview(bool ignoreLazyPreviewSetting)
         this->DoUpdatePreview(feedBackImage, currentSegImage, previewImage, timeStep);
       }
       RenderingManager::GetInstance()->RequestUpdateAll();
+      if (!previewImage->GetAllLabelValues().empty())
+      { // check if labels exits for the preview
+        m_IsPreviewGenerated = true;
+      }
     }
   }
   catch (itk::ExceptionObject & excep)
@@ -692,13 +715,19 @@ void mitk::SegWithPreviewTool::UpdateCleanUp()
   //reimplement in derived classes for special behavior
 }
 
+void mitk::SegWithPreviewTool::ConfirmCleanUp()
+{
+  // default implementation does nothing
+  // reimplement in derived classes for special behavior
+}
+
 void mitk::SegWithPreviewTool::TransferLabelInformation(const LabelMappingType& labelMapping,
   const mitk::LabelSetImage* source, mitk::LabelSetImage* target)
 {
   for (const auto& [sourceLabel, targetLabel] : labelMapping)
   {
-    if (LabelSetImage::UnlabeledValue != sourceLabel &&
-        LabelSetImage::UnlabeledValue != targetLabel &&
+    if (LabelSetImage::UNLABELED_VALUE != sourceLabel &&
+        LabelSetImage::UNLABELED_VALUE != targetLabel &&
         !target->ExistLabel(targetLabel, target->GetActiveLayer()))
     {
       if (!source->ExistLabel(sourceLabel, source->GetActiveLayer()))
@@ -708,7 +737,7 @@ void mitk::SegWithPreviewTool::TransferLabelInformation(const LabelMappingType&
 
       auto clonedLabel = source->GetLabel(sourceLabel)->Clone();
       clonedLabel->SetValue(targetLabel);
-      target->GetActiveLabelSet()->AddLabel(clonedLabel);
+      target->AddLabel(clonedLabel,target->GetActiveLayer(), false, false);
     }
   }
 }
@@ -739,7 +768,7 @@ mitk::TimePointType mitk::SegWithPreviewTool::GetLastTimePointOfUpdate() const
 mitk::LabelSetImage::LabelValueType mitk::SegWithPreviewTool::GetActiveLabelValueOfPreview() const
 {
   const auto previewImage = this->GetPreviewSegmentation();
-  const auto activeLabel = previewImage->GetActiveLabel(previewImage->GetActiveLayer());
+  const auto activeLabel = previewImage->GetActiveLabel();
   if (nullptr == activeLabel)
     mitkThrow() << this->GetNameOfClass() <<" is in an invalid state, as "
                    "preview has no active label indicated. Check "
@@ -807,12 +836,17 @@ void mitk::SegWithPreviewTool::TransferLabelSetImageContent(const LabelSetImage*
   mitk::ImageReadAccessor newMitkImgAcc(source);
 
   LabelMappingType labelMapping;
-  const auto labelSet = source->GetActiveLabelSet();
-  for (auto labelIter = labelSet->IteratorConstBegin(); labelIter != labelSet->IteratorConstEnd(); ++labelIter)
+  const auto labelValues = source->GetLabelValuesByGroup(source->GetActiveLayer());
+  for (const auto& labelValue : labelValues)
   {
-    labelMapping.push_back({ labelIter->second->GetValue(),labelIter->second->GetValue() });
+    labelMapping.push_back({ labelValue,labelValue });
   }
   TransferLabelInformation(labelMapping, source, target);
 
   target->SetVolume(newMitkImgAcc.GetData(), timeStep);
 }
+
+bool mitk::SegWithPreviewTool::ConfirmBeforeDeactivation()
+{
+  return m_IsPreviewGenerated && m_RequestDeactivationConfirmation;
+}
