@@ -13,6 +13,7 @@ found in the LICENSE file.
 #include <QmitkMultiLabelTreeView.h>
 
 #include <QmitkMultiLabelTreeModel.h>
+#include <QMouseEvent>
 
 QmitkMultiLabelTreeView::QmitkMultiLabelTreeView(QWidget* parent) : QTreeView(parent)
 {
@@ -29,3 +30,22 @@ QItemSelectionModel::SelectionFlags QmitkMultiLabelTreeView::selectionCommand(co
   return   QAbstractItemView::selectionCommand(index, event);
 }
 
+void QmitkMultiLabelTreeView::leaveEvent(QEvent* event)
+{
+  QTreeView::leaveEvent(event);
+  emit MouseLeave();
+}
+
+void QmitkMultiLabelTreeView::mouseMoveEvent(QMouseEvent* event)
+{
+  QModelIndex index = this->indexAt(event->pos());
+  if (!index.isValid())
+  {
+    if (viewport()->rect().contains(event->pos()))
+    {
+      emit MouseLeave();
+    }
+  }
+
+  QTreeView::mouseMoveEvent(event);
+}
