@@ -26,18 +26,17 @@ found in the LICENSE file.
 #include <mitkSegmentationHelper.h>
 #include <mitkToolManagerProvider.h>
 
+#include <QmitkFindSegmentationTaskDialog.h>
 #include <QmitkStaticDynamicSegmentationDialog.h>
 #include <QmitkStyleManager.h>
 
-#include <QmitkStyleManager.h>
-
 #include <ui_QmitkSegmentationTaskListWidget.h>
 
 #include <QFileSystemWatcher>
 #include <QMessageBox>
 #include <QShortcut>
 
-#include <filesystem>
+#include <mitkFileSystem.h>
 
 namespace
 {
@@ -46,7 +45,7 @@ namespace
     return mitk::CoreServices::GetPreferencesService()->GetSystemPreferences()->Node("/org.mitk.views.segmentation");
   }
 
-  std::filesystem::path GetInputLocation(const mitk::BaseData* data)
+  fs::path GetInputLocation(const mitk::BaseData* data)
   {
     std::string result;
 
@@ -114,6 +113,7 @@ QmitkSegmentationTaskListWidget::QmitkSegmentationTaskListWidget(QWidget* parent
 
   m_Ui->progressBar->setStyleSheet(QString("QProgressBar::chunk { background-color: %1; }").arg(QmitkStyleManager::GetIconAccentColor()));
 
+  m_Ui->findButton->setIcon(QmitkStyleManager::ThemeIcon(QStringLiteral(":/Qmitk/icon_find.svg")));
   m_Ui->storeButton->setIcon(QmitkStyleManager::ThemeIcon(QStringLiteral(":/org_mitk_icons/icons/awesome/scalable/actions/document-save.svg")));
 
   using Self = QmitkSegmentationTaskListWidget;
@@ -121,6 +121,7 @@ QmitkSegmentationTaskListWidget::QmitkSegmentationTaskListWidget(QWidget* parent
   connect(m_Ui->selectionWidget, &QmitkSingleNodeSelectionWidget::CurrentSelectionChanged, this, &Self::OnSelectionChanged);
   connect(m_Ui->previousButton, &QToolButton::clicked, this, &Self::OnPreviousButtonClicked);
   connect(m_Ui->nextButton, &QToolButton::clicked, this, &Self::OnNextButtonClicked);
+  connect(m_Ui->findButton, &QToolButton::clicked, this, &Self::OnFindButtonClicked);
   connect(m_Ui->loadButton, &QPushButton::clicked, this, &Self::OnLoadButtonClicked);
   connect(m_Ui->storeButton, &QPushButton::clicked, this, &Self::OnStoreButtonClicked);
   connect(m_Ui->acceptButton, &QPushButton::clicked, this, &Self::OnAcceptButtonClicked);
@@ -139,6 +140,9 @@ QmitkSegmentationTaskListWidget::QmitkSegmentationTaskListWidget(QWidget* parent
   auto* nextUndoneShortcut = new QShortcut(QKeySequence(Qt::CTRL | Qt::SHIFT | Qt::Key::Key_N), this);
   connect(nextUndoneShortcut, &QShortcut::activated, this, &Self::OnNextTaskShortcutActivated);
 
+  auto *findTaskShortcut = new QShortcut(QKeySequence(Qt::CTRL | Qt::Key::Key_F), this);
+  connect(findTaskShortcut, &QShortcut::activated, this, &Self::OnFindTaskShortcutActivated);
+
   auto* loadShortcut = new QShortcut(QKeySequence(Qt::CTRL | Qt::ALT | Qt::Key::Key_L), this);
   connect(loadShortcut, &QShortcut::activated, this, &Self::OnLoadTaskShortcutActivated);
 
@@ -312,19 +316,19 @@ void QmitkSegmentationTaskListWidget::ResetFileSystemWatcher()
     {
       auto resultPath = m_TaskList->GetAbsolutePath(task.GetResult()).remove_filename();
 
-      if (!std::filesystem::exists(resultPath))
+      if (!fs::exists(resultPath))
       {
         try
         {
-          std::filesystem::create_directories(resultPath);
+          fs::create_directories(resultPath);
         }
-        catch (const std::filesystem::filesystem_error& e)
+        catch (const fs::filesystem_error& e)
         {
           MITK_ERROR << e.what();
         }
       }
 
-      if (std::filesystem::exists(resultPath))
+      if (fs::exists(resultPath))
         m_FileSystemWatcher->addPath(QString::fromStdString(resultPath.string()));
     }
   }
@@ -437,6 +441,29 @@ void QmitkSegmentationTaskListWidget::OnNextButtonClicked()
   this->UpdateNavigationButtons();
 }
 
+void QmitkSegmentationTaskListWidget::OnFindButtonClicked()
+{
+  if (m_TaskList.IsNull())
+    return;
+
+  QmitkFindSegmentationTaskDialog dialog;
+  dialog.SetTaskList(m_TaskList);
+
+  if (dialog.exec() != QDialog::Accepted)
+    return;
+
+  if (!dialog.GetSelectedTask().has_value())
+    return;
+
+  this->SetCurrentTaskIndex(dialog.GetSelectedTask());
+
+  if (dialog.LoadSelectedTask())
+  {
+    if (!m_ActiveTaskIndex.has_value() || m_ActiveTaskIndex.value() != dialog.GetSelectedTask().value())
+      this->OnLoadButtonClicked();
+  }
+}
+
 void QmitkSegmentationTaskListWidget::UpdateNavigationButtons()
 {
   if (m_TaskList.IsNull() || m_TaskList->GetNumberOfTasks() == 0)
@@ -676,11 +703,11 @@ void QmitkSegmentationTaskListWidget::LoadTask(mitk::DataNode::Pointer imageNode
     const auto path = m_TaskList->GetAbsolutePath(m_TaskList->GetResult(current));
     const auto interimPath = m_TaskList->GetInterimPath(path);
 
-    if (std::filesystem::exists(path))
+    if (fs::exists(path))
     {
       segmentation = mitk::IOUtil::Load<mitk::LabelSetImage>(path.string());
     }
-    else if (std::filesystem::exists(interimPath))
+    else if (fs::exists(interimPath))
     {
       segmentation = mitk::IOUtil::Load<mitk::LabelSetImage>(interimPath.string());
     }
@@ -748,7 +775,7 @@ void QmitkSegmentationTaskListWidget::LoadTask(mitk::DataNode::Pointer imageNode
       if (m_TaskList->HasLabelName(current))
         label->SetName(m_TaskList->GetLabelName(current));
 
-      segmentation->GetActiveLabelSet()->AddLabel(label);
+      segmentation->AddLabel(label, segmentation->GetActiveLayer());
     }
 
     m_DataStorage->Add(segmentationNode, imageNode);
@@ -853,7 +880,6 @@ void QmitkSegmentationTaskListWidget::SetCurrentTaskIndex(const std::optional<si
   {
     m_CurrentTaskIndex = index;
     this->OnCurrentTaskChanged();
-
   }
 }
 
@@ -894,7 +920,7 @@ bool QmitkSegmentationTaskListWidget::HandleUnsavedChanges(const QString& altern
     switch (reply)
     {
     case QMessageBox::Save:
-      this->SaveActiveTask(!std::filesystem::exists(m_TaskList->GetResult(active)));
+      this->SaveActiveTask(!fs::exists(m_TaskList->GetResult(active)));
       break;
 
     case QMessageBox::Discard:
@@ -945,6 +971,11 @@ void QmitkSegmentationTaskListWidget::OnNextTaskShortcutActivated()
   m_Ui->nextButton->click();
 }
 
+void QmitkSegmentationTaskListWidget::OnFindTaskShortcutActivated()
+{
+  m_Ui->findButton->click();
+}
+
 void QmitkSegmentationTaskListWidget::OnLoadTaskShortcutActivated()
 {
   m_Ui->loadButton->click();
