@@ -16,14 +16,10 @@ found in the LICENSE file.
 #include "mitkDataNode.h"
 #include "mitkDataStorage.h"
 #include "mitkSegmentationInterpolationController.h"
-#include "mitkSliceNavigationController.h"
 #include "mitkSurfaceInterpolationController.h"
 #include "mitkToolManager.h"
 #include <MitkSegmentationUIExports.h>
 
-#include "mitkFeatureBasedEdgeDetectionFilter.h"
-#include "mitkPointCloudScoringFilter.h"
-
 #include <QWidget>
 #include <map>
 
@@ -46,18 +42,12 @@ namespace mitk
 {
   class PlaneGeometry;
   class SliceNavigationController;
+  class TimeNavigationController;
 }
 
 class QPushButton;
 class QmitkRenderWindow;
 
-enum ModifyLabelActionTrigerred
-{
-  Null,
-  Erase,
-  Merge
-};
-
 /**
   \brief GUI for slices interpolation.
 
@@ -72,10 +62,6 @@ enum ModifyLabelActionTrigerred
   QmitkSlicesInterpolator is responsible to watch the GUI, to notice, which slice is currently
   visible. It triggers generation of interpolation suggestions and also triggers acception of
   suggestions.
-
-  \todo show/hide feedback on demand
-
-  Last contributor: $Author: maleike $
 */
 class MITKSEGMENTATIONUI_EXPORT QmitkSlicesInterpolator : public QWidget
 {
@@ -111,6 +97,7 @@ public:
    */
   mitk::DataStorage *GetDataStorage();
 
+  void SetActiveLabelValue(mitk::LabelSetImage::LabelValueType labelValue);
 
   /**
     Just public because it is called by itk::Commands. You should not need to call this.
@@ -167,61 +154,6 @@ private:
    */
   void OnActiveLabelChanged(mitk::Label::PixelType);
 
-  /**
-   * @brief Function that reacts to a change in the layer.
-   *
-   */
-  void OnLayerChanged();
-
-  /**
-   * @brief Function that handles label removal from the segmentation image.
-   *
-   */
-  void OnRemoveLabel(mitk::Label::PixelType removedLabelValue);
-
-  /**
-   * @brief Function that to changes in the segmentation image. It handles the layer removal, addition, label erasure,
-   *
-   */
-  void OnModifyLabelChanged(const itk::Object *caller,
-                              const itk::EventObject & /*event*/);
-
-  /**
-   * @brief Add the necessary subscribers to the label set image, for UI responsiveness.
-   *        It deals with remove label, change active label, layer changes and change in the label.
-   *
-   */
-  void OnAddLabelSetConnection();
-
-  /**
-   * @brief Add the necessary subscribers to the current LabelSetImage at the layer input, for UI responsiveness.
-   *        It deals with remove label, change active label, layer changes and change in the label.
-   *
-   * @param layerID
-   */
-  void OnAddLabelSetConnection(unsigned int layerID);
-
-  /**
-   * @brief Remove the subscribers for the different events to the segmentation image.
-   *
-   */
-  void OnRemoveLabelSetConnection();
-
-  /**
-   * @brief Merge contours for the current layerID and current timeStep.
-   *
-   * @param timeStep
-   * @param layerID
-   */
-  void MergeContours(unsigned int timeStep, unsigned int layerID);
-
-
-  /**
-   * @brief Prepare Inputs for 3D Interpolation.
-   *
-   */
-  void PrepareInputsFor3DInterpolation();
-
 signals:
 
   void SignalRememberContourPositions(bool);
@@ -303,18 +235,11 @@ protected slots:
 
   void ChangeSurfaceColor();
 
-  /**
-   * @brief Removes all observers to the labelSetImage at the layerID specified.
-   *        Is used when changing the segmentation image.
-   *
-   * @param labelSetImage
-   * @param layerID
-   */
-  void OnRemoveLabelSetConnection(mitk::LabelSetImage* labelSetImage, unsigned int layerID);
-
 protected:
-  const std::map<QAction *, mitk::SliceNavigationController *> createActionToSlicer(const QList<QmitkRenderWindow*>& windows);
-  std::map<QAction *, mitk::SliceNavigationController *> m_ActionToSlicer;
+
+  typedef std::map<QAction*, mitk::SliceNavigationController*> ActionToSliceDimensionMapType;
+  const ActionToSliceDimensionMapType CreateActionToSlicer(const QList<QmitkRenderWindow*>& windows);
+  ActionToSliceDimensionMapType m_ActionToSlicerMap;
 
   void AcceptAllInterpolations(mitk::SliceNavigationController *slicer);
 
@@ -324,18 +249,18 @@ protected:
     and calls Interpolate to further process this PlaneGeometry into an interpolation.
 
     \param e is a actually a mitk::SliceNavigationController::GeometrySliceEvent, sent by a SliceNavigationController
-    \param slicer the SliceNavigationController
+    \param sliceNavigationController the SliceNavigationController
         */
-  bool TranslateAndInterpolateChangedSlice(const itk::EventObject &e, mitk::SliceNavigationController *slicer);
+  bool TranslateAndInterpolateChangedSlice(const itk::EventObject &e,
+                                           mitk::SliceNavigationController *sliceNavigationController);
 
+  bool TranslateAndInterpolateChangedSlice(const mitk::TimeGeometry* timeGeometry);
   /**
     Given a PlaneGeometry, this method figures out which slice of the first working image (of the associated
     ToolManager)
     should be interpolated. The actual work is then done by our SegmentationInterpolation object.
    */
-  void Interpolate(mitk::PlaneGeometry *plane, mitk::TimePointType timePoint, mitk::SliceNavigationController *slicer);
-
-  // void InterpolateSurface();
+  void Interpolate(mitk::PlaneGeometry *plane);
 
   /**
     Called internally to update the interpolation suggestion. Finds out about the focused render window and requests an
@@ -353,23 +278,17 @@ private:
   void CheckSupportedImageDimension();
   void WaitForFutures();
   void NodeRemoved(const mitk::DataNode* node);
-  void ClearSegmentationObservers();
 
   mitk::SegmentationInterpolationController::Pointer m_Interpolator;
   mitk::SurfaceInterpolationController::Pointer m_SurfaceInterpolator;
 
-  mitk::FeatureBasedEdgeDetectionFilter::Pointer m_EdgeDetector;
-  mitk::PointCloudScoringFilter::Pointer m_PointScorer;
-
   mitk::ToolManager::Pointer m_ToolManager;
   bool m_Initialized;
 
-  QHash<mitk::SliceNavigationController *, int> m_ControllerToTimeObserverTag;
+  unsigned int m_ControllerToTimeObserverTag;
   QHash<mitk::SliceNavigationController *, int> m_ControllerToSliceObserverTag;
   QHash<mitk::SliceNavigationController *, int> m_ControllerToDeleteObserverTag;
 
-  std::map<mitk::LabelSetImage *, unsigned long> m_SegmentationObserverTags;
-
   unsigned int InterpolationInfoChangedObserverTag;
   unsigned int SurfaceInterpolationInfoChangedObserverTag;
   unsigned int InterpolationAbortedObserverTag;
@@ -380,22 +299,18 @@ private:
   QPushButton *m_BtnApplyForAllSlices2D;
   QPushButton *m_BtnApply3D;
 
-  // T28261
-  // QPushButton *m_BtnSuggestPlane;
-
   QCheckBox *m_ChkShowPositionNodes;
   QPushButton *m_BtnReinit3DInterpolation;
 
   mitk::DataNode::Pointer m_FeedbackNode;
   mitk::DataNode::Pointer m_InterpolatedSurfaceNode;
-  mitk::DataNode::Pointer m_3DContourNode;
 
   mitk::Image *m_Segmentation;
 
   mitk::SliceNavigationController *m_LastSNC;
   unsigned int m_LastSliceIndex;
 
-  QHash<mitk::SliceNavigationController *, mitk::TimePointType> m_TimePoints;
+  mitk::TimePointType m_TimePoint;
 
   bool m_2DInterpolationEnabled;
   bool m_3DInterpolationEnabled;
@@ -415,11 +330,8 @@ private:
   QFuture<void> m_PlaneFuture;
   QFutureWatcher<void> m_PlaneWatcher;
 
-  mitk::Label::PixelType m_PreviousActiveLabelValue;
   mitk::Label::PixelType m_CurrentActiveLabelValue;
 
-  unsigned int m_PreviousLayerIndex;
-  unsigned int m_CurrentLayerIndex;
   bool m_FirstRun;
 };
 
