@@ -18,11 +18,12 @@ found in the LICENSE file.
 #include "mitkBaseRenderer.h"
 
 #include <QList>
-#include <qapplication.h>
-#include <qlayout.h>
-#include <qmessagebox.h>
-#include <qtoolbutton.h>
-#include <qtooltip.h>
+#include <QApplication>
+#include <QLayout>
+#include <QMessageBox>
+#include <QToolButton>
+#include <QToolTip>
+#include <QRegularExpression>
 
 #include <queue>
 
@@ -63,7 +64,7 @@ QmitkToolSelectionBox::QmitkToolSelectionBox(QWidget *parent, mitk::DataStorage
   }
 
   // reactions to signals
-  connect(m_ToolButtonGroup, SIGNAL(buttonClicked(int)), this, SLOT(toolButtonClicked(int)));
+  connect(m_ToolButtonGroup, &QButtonGroup::idClicked, this, &QmitkToolSelectionBox::toolButtonClicked);
 
   // reactions to ToolManager events
 
@@ -139,6 +140,20 @@ void QmitkToolSelectionBox::toolButtonClicked(int id)
   MITK_DEBUG << "toolButtonClicked(" << id << "): id translates to tool ID " << m_ToolIDForButtonID[id];
 
   QToolButton *toolButton = dynamic_cast<QToolButton *>(m_ToolButtonGroup->buttons().at(id));
+  mitk::Tool *tool = m_ToolManager->GetActiveTool();
+  if (tool && tool->ConfirmBeforeDeactivation() &&
+      QMessageBox::No == QMessageBox::question(nullptr,
+                                               tool->GetName(),
+                                               QStringLiteral("The %1 tool currently has unconfirmed results. "
+                                                              "Do you really want to discard the results by "
+                                                              "exiting the tool now?").arg(tool->GetName()),
+                                               QMessageBox::Yes | QMessageBox::No,
+                                               QMessageBox::No))
+  {
+    toolButton->setChecked(false);
+    return;
+  }
+
   if (toolButton)
   {
     if ((m_ButtonIDForToolID.find(m_ToolManager->GetActiveToolID()) !=
@@ -214,7 +229,7 @@ void QmitkToolSelectionBox::SetOrUnsetButtonForActiveTool()
     // mmueller
     // uncheck all other buttons
     QAbstractButton *tmpBtn = nullptr;
-    QList<QAbstractButton *>::iterator it;
+
     for (int i = 0; i < m_ToolButtonGroup->buttons().size(); ++i)
     {
       tmpBtn = m_ToolButtonGroup->buttons().at(i);
@@ -329,7 +344,7 @@ void QmitkToolSelectionBox::UpdateButtonsEnabledState()
     workingData = workingDataNode->GetData();
   }
 
-  for (const auto& button : qAsConst(buttons))
+  for (const auto& button : std::as_const(buttons))
   {
     const auto buttonID = m_ToolButtonGroup->id(button);
     const auto toolID = m_ToolIDForButtonID[buttonID];
@@ -562,13 +577,13 @@ void QmitkToolSelectionBox::OnToolGUIProcessEventsMessage()
 void QmitkToolSelectionBox::OnToolErrorMessage(std::string s)
 {
   QMessageBox::critical(
-    this, "MITK", QString(s.c_str()), QMessageBox::Ok, QMessageBox::NoButton, QMessageBox::NoButton);
+    this, "MITK", QString(s.c_str()), QMessageBox::Ok | QMessageBox::NoButton, QMessageBox::NoButton);
 }
 
 void QmitkToolSelectionBox::OnGeneralToolMessage(std::string s)
 {
   QMessageBox::information(
-    this, "MITK", QString(s.c_str()), QMessageBox::Ok, QMessageBox::NoButton, QMessageBox::NoButton);
+    this, "MITK", QString(s.c_str()), QMessageBox::Ok | QMessageBox::NoButton, QMessageBox::NoButton);
 }
 
 void QmitkToolSelectionBox::SetDisplayedToolGroups(const std::string &toolGroups)
@@ -577,7 +592,7 @@ void QmitkToolSelectionBox::SetDisplayedToolGroups(const std::string &toolGroups
   {
     QString q_DisplayedGroups = toolGroups.c_str();
     // quote all unquoted single words
-    q_DisplayedGroups = q_DisplayedGroups.replace(QRegExp("\\b(\\w+)\\b|'([^']+)'"), "'\\1\\2'");
+    q_DisplayedGroups = q_DisplayedGroups.replace(QRegularExpression("\\b(\\w+)\\b|'([^']+)'"), "'\\1\\2'");
     MITK_DEBUG << "m_DisplayedGroups was \"" << toolGroups << "\"";
 
     m_DisplayedGroups = q_DisplayedGroups.toLocal8Bit().constData();
