@@ -80,16 +80,18 @@ public:
   void PopulateSegmentation(mitk::LabelSetImage* seg)
   {
     seg->SetActiveLayer(0);
-    seg->GetActiveLabelSet()->AddLabel(CreateLabel("A", 1));
-    seg->GetActiveLabelSet()->AddLabel(CreateLabel("A", 5));
-    seg->GetActiveLabelSet()->AddLabel(CreateLabel("B", 4));
+
+    seg->AddLabel(CreateLabel("A", 1),0);
+    seg->AddLabel(CreateLabel("A", 5),0);
+    seg->AddLabel(CreateLabel("B", 4),0);
+
     seg->AddLayer();
     seg->AddLayer();
-    seg->SetActiveLayer(2);
-    seg->GetActiveLabelSet()->AddLabel(CreateLabel("B", 9));
-    seg->SetActiveLayer(0);
-    seg->GetActiveLabelSet()->AddLabel(CreateLabel("D", 2));
-    seg->GetActiveLabelSet()->AddLabel(CreateLabel("A", 10));
+
+    seg->AddLabel(CreateLabel("B", 9),2);
+
+    seg->AddLabel(CreateLabel("D", 2),0);
+    seg->AddLabel(CreateLabel("A", 10),0);
   }
 
   void setUp() override
@@ -155,7 +157,7 @@ public:
 
   void CheckModelGroup0Default(const QmitkMultiLabelTreeModel& model)
   {
-    CPPUNIT_ASSERT(CheckModelRow(model, { 0 }, { QString("Group 0"), QVariant(), QVariant(), QVariant() }));
+    CPPUNIT_ASSERT(CheckModelRow(model, { 0 }, { QString("Group 1"), QVariant(), QVariant(), QVariant() }));
     CPPUNIT_ASSERT_EQUAL(3, model.rowCount(GetIndex(model, { 0 })));
     CPPUNIT_ASSERT(CheckModelRow(model, { 0,0 }, { QString("A (3 instances)"), QVariant(), QVariant(), QVariant() }));
     CPPUNIT_ASSERT_EQUAL(3, model.rowCount(GetIndex(model, { 0,0 })));
@@ -171,13 +173,13 @@ public:
 
   void CheckModelGroup1Default(const QmitkMultiLabelTreeModel& model)
   {
-    CPPUNIT_ASSERT(CheckModelRow(model, { 1 }, { QString("Group 1"), QVariant(), QVariant(), QVariant() }));
+    CPPUNIT_ASSERT(CheckModelRow(model, { 1 }, { QString("Group 2"), QVariant(), QVariant(), QVariant() }));
     CPPUNIT_ASSERT_EQUAL(0, model.rowCount(GetIndex(model, { 1 })));
   }
 
   void CheckModelGroup2Default(const QmitkMultiLabelTreeModel& model)
   {
-    CPPUNIT_ASSERT(CheckModelRow(model, { 2 }, { QString("Group 2"), QVariant(), QVariant(), QVariant() }));
+    CPPUNIT_ASSERT(CheckModelRow(model, { 2 }, { QString("Group 3"), QVariant(), QVariant(), QVariant() }));
     CPPUNIT_ASSERT_EQUAL(1, model.rowCount(GetIndex(model, { 2 })));
     CPPUNIT_ASSERT(CheckModelRow(model, { 2,0 }, { QString("B"), QVariant(true), QVariant(QColor(9,9,9)), QVariant(true) }));
     CPPUNIT_ASSERT_EQUAL(0, model.rowCount(GetIndex(model, { 2,0 })));
@@ -219,10 +221,10 @@ public:
     m_Segmentation->SetActiveLayer(0);
     auto newLabel = CreateLabel("A", 100);
     newLabel->SetVisible(false);
-    m_Segmentation->GetActiveLabelSet()->AddLabel(newLabel);
+    m_Segmentation->AddLabel(newLabel,0);
 
     CPPUNIT_ASSERT_EQUAL(3, model.rowCount(QModelIndex()));
-    CPPUNIT_ASSERT(CheckModelRow(model, { 0 }, { QString("Group 0"), QVariant(), QVariant(), QVariant() }));
+    CPPUNIT_ASSERT(CheckModelRow(model, { 0 }, { QString("Group 1"), QVariant(), QVariant(), QVariant() }));
     CPPUNIT_ASSERT_EQUAL(3, model.rowCount(GetIndex(model, { 0 })));
     CPPUNIT_ASSERT(CheckModelRow(model, { 0,0 }, { QString("A (4 instances)"), QVariant(), QVariant(), QVariant() }));
     CPPUNIT_ASSERT_EQUAL(4, model.rowCount(GetIndex(model, { 0,0 })));
@@ -243,10 +245,10 @@ public:
     m_Segmentation->SetActiveLayer(0);
     newLabel = CreateLabel("A", 7);
     newLabel->SetLocked(false);
-    m_Segmentation->GetActiveLabelSet()->AddLabel(newLabel);
+    m_Segmentation->AddLabel(newLabel,0);
 
     CPPUNIT_ASSERT_EQUAL(3, model.rowCount(QModelIndex()));
-    CPPUNIT_ASSERT(CheckModelRow(model, { 0 }, { QString("Group 0"), QVariant(), QVariant(), QVariant() }));
+    CPPUNIT_ASSERT(CheckModelRow(model, { 0 }, { QString("Group 1"), QVariant(), QVariant(), QVariant() }));
     CPPUNIT_ASSERT_EQUAL(3, model.rowCount(GetIndex(model, { 0 })));
     CPPUNIT_ASSERT(CheckModelRow(model, { 0,0 }, { QString("A (5 instances)"), QVariant(), QVariant(), QVariant() }));
     CPPUNIT_ASSERT_EQUAL(5, model.rowCount(GetIndex(model, { 0,0 })));
@@ -272,11 +274,11 @@ public:
     //Add label instance to an empty group
     m_Segmentation->SetActiveLayer(1);
     newLabel = CreateLabel("A", 3);
-    m_Segmentation->GetActiveLabelSet()->AddLabel(newLabel);
+    m_Segmentation->AddLabel(newLabel,1);
 
     CPPUNIT_ASSERT_EQUAL(3, model.rowCount(QModelIndex()));
     CheckModelGroup0Default(model);
-    CPPUNIT_ASSERT(CheckModelRow(model, { 1 }, { QString("Group 1"), QVariant(), QVariant(), QVariant() }));
+    CPPUNIT_ASSERT(CheckModelRow(model, { 1 }, { QString("Group 2"), QVariant(), QVariant(), QVariant() }));
     CPPUNIT_ASSERT_EQUAL(1, model.rowCount(GetIndex(model, { 1 })));
     CPPUNIT_ASSERT(CheckModelRow(model, { 1,0 }, { QString("A"), QVariant(true), QVariant(QColor(3,3,3)), QVariant(true) }));
     CPPUNIT_ASSERT_EQUAL(0, model.rowCount(GetIndex(model, { 1,0 })));
@@ -295,10 +297,38 @@ public:
     CheckModelGroup0Default(model);
     CheckModelGroup1Default(model);
     CheckModelGroup2Default(model);
-    CPPUNIT_ASSERT(CheckModelRow(model, { 3 }, { QString("Group 3"), QVariant(), QVariant(), QVariant() }));
+    CPPUNIT_ASSERT(CheckModelRow(model, { 3 }, { QString("Group 4"), QVariant(), QVariant(), QVariant() }));
     CPPUNIT_ASSERT_EQUAL(0, model.rowCount(GetIndex(model, { 3 })));
   }
 
+  void RenameGroupTest()
+  {
+    QmitkMultiLabelTreeModel model(nullptr);
+    model.SetSegmentation(m_Segmentation);
+
+    CPPUNIT_ASSERT_EQUAL(3, model.rowCount(QModelIndex()));
+    CheckModelGroup0Default(model);
+    CheckModelGroup1Default(model);
+    CheckModelGroup2Default(model);
+
+    m_Segmentation->SetGroupName(0, "First group");
+    m_Segmentation->SetGroupName(2, "3rd group");
+
+    CPPUNIT_ASSERT(CheckModelRow(model, { 0 }, { QString("First group"), QVariant(), QVariant(), QVariant() }));
+    CPPUNIT_ASSERT(CheckModelRow(model, { 1 }, { QString("Group 2"), QVariant(), QVariant(), QVariant() }));
+    CPPUNIT_ASSERT(CheckModelRow(model, { 2 }, { QString("3rd group"), QVariant(), QVariant(), QVariant() }));
+
+    m_Segmentation->SetGroupName(0, "");
+    m_Segmentation->SetGroupName(1, "cool name");
+    m_Segmentation->SetGroupName(2, "");
+
+    CPPUNIT_ASSERT(CheckModelRow(model, { 0 }, { QString("Group 1"), QVariant(), QVariant(), QVariant() }));
+    CPPUNIT_ASSERT(CheckModelRow(model, { 1 }, { QString("cool name"), QVariant(), QVariant(), QVariant() }));
+    CPPUNIT_ASSERT(CheckModelRow(model, { 2 }, { QString("Group 3"), QVariant(), QVariant(), QVariant() }));
+
+    CPPUNIT_ASSERT_THROW(m_Segmentation->SetGroupName(4, "invalid group"), mitk::Exception);
+  }
+
   void RemovingLabelTest()
   {
     QmitkMultiLabelTreeModel model(nullptr);
@@ -306,7 +336,7 @@ public:
     //remove label instance from label with multiple instances (middel)
     m_Segmentation->RemoveLabel(5);
     CPPUNIT_ASSERT_EQUAL(3, model.rowCount(QModelIndex()));
-    CPPUNIT_ASSERT(CheckModelRow(model, { 0 }, { QString("Group 0"), QVariant(), QVariant(), QVariant() }));
+    CPPUNIT_ASSERT(CheckModelRow(model, { 0 }, { QString("Group 1"), QVariant(), QVariant(), QVariant() }));
     CPPUNIT_ASSERT_EQUAL(3, model.rowCount(GetIndex(model, { 0 })));
     CPPUNIT_ASSERT(CheckModelRow(model, { 0,0 }, { QString("A (2 instances)"), QVariant(), QVariant(), QVariant() }));
     CPPUNIT_ASSERT_EQUAL(2, model.rowCount(GetIndex(model, { 0,0 })));
@@ -322,7 +352,7 @@ public:
     //remove label instance from label with multiple instances (first)
     m_Segmentation->RemoveLabel(1);
     CPPUNIT_ASSERT_EQUAL(3, model.rowCount(QModelIndex()));
-    CPPUNIT_ASSERT(CheckModelRow(model, { 0 }, { QString("Group 0"), QVariant(), QVariant(), QVariant() }));
+    CPPUNIT_ASSERT(CheckModelRow(model, { 0 }, { QString("Group 1"), QVariant(), QVariant(), QVariant() }));
     CPPUNIT_ASSERT_EQUAL(3, model.rowCount(GetIndex(model, { 0 })));
     CPPUNIT_ASSERT(CheckModelRow(model, { 0,0 }, { QString("A"), QVariant(true), QVariant(QColor(10,10,10)), QVariant(true) }));
     CPPUNIT_ASSERT_EQUAL(0, model.rowCount(GetIndex(model, { 0,0 })));
@@ -342,7 +372,7 @@ public:
     //remove label instance from label with multiple instances (at the end)
     m_Segmentation->RemoveLabel(10);
     CPPUNIT_ASSERT_EQUAL(3, model.rowCount(QModelIndex()));
-    CPPUNIT_ASSERT(CheckModelRow(model, { 0 }, { QString("Group 0"), QVariant(), QVariant(), QVariant() }));
+    CPPUNIT_ASSERT(CheckModelRow(model, { 0 }, { QString("Group 1"), QVariant(), QVariant(), QVariant() }));
     CPPUNIT_ASSERT_EQUAL(3, model.rowCount(GetIndex(model, { 0 })));
     CPPUNIT_ASSERT(CheckModelRow(model, { 0,0 }, { QString("A (2 instances)"), QVariant(), QVariant(), QVariant() }));
     CPPUNIT_ASSERT_EQUAL(2, model.rowCount(GetIndex(model, { 0,0 })));
@@ -365,7 +395,7 @@ public:
     CPPUNIT_ASSERT_EQUAL(3, model.rowCount(QModelIndex()));
     CheckModelGroup0Default(model);
     CheckModelGroup1Default(model);
-    CPPUNIT_ASSERT(CheckModelRow(model, { 2 }, { QString("Group 2"), QVariant(), QVariant(), QVariant() }));
+    CPPUNIT_ASSERT(CheckModelRow(model, { 2 }, { QString("Group 3"), QVariant(), QVariant(), QVariant() }));
     CPPUNIT_ASSERT_EQUAL(0, model.rowCount(GetIndex(model, { 2 })));
   }
 
@@ -374,24 +404,21 @@ public:
     QmitkMultiLabelTreeModel model(nullptr);
     model.SetSegmentation(m_Segmentation);
     //remove group in the middle
-    m_Segmentation->SetActiveLayer(1);
-    m_Segmentation->RemoveLayer();
+    m_Segmentation->RemoveGroup(1);
     CPPUNIT_ASSERT_EQUAL(2, model.rowCount(QModelIndex()));
     CheckModelGroup0Default(model);
-    CPPUNIT_ASSERT(CheckModelRow(model, { 1 }, { QString("Group 1"), QVariant(), QVariant(), QVariant() }));
+    CPPUNIT_ASSERT(CheckModelRow(model, { 1 }, { QString("Group 2"), QVariant(), QVariant(), QVariant() }));
     CPPUNIT_ASSERT_EQUAL(1, model.rowCount(GetIndex(model, { 1 })));
     CPPUNIT_ASSERT(CheckModelRow(model, { 1,0 }, { QString("B"), QVariant(true), QVariant(QColor(9,9,9)), QVariant(true) }));
     CPPUNIT_ASSERT_EQUAL(0, model.rowCount(GetIndex(model, { 1,0 })));
 
     //remove groups in the end
-    m_Segmentation->SetActiveLayer(1);
-    m_Segmentation->RemoveLayer();
+    m_Segmentation->RemoveGroup(1);
     CPPUNIT_ASSERT_EQUAL(1, model.rowCount(QModelIndex()));
     CheckModelGroup0Default(model);
 
     //remove all groups
-    m_Segmentation->SetActiveLayer(0);
-    m_Segmentation->RemoveLayer();
+    m_Segmentation->RemoveGroup(0);
     CPPUNIT_ASSERT_EQUAL(0, model.rowCount(QModelIndex()));
 
     //reset everything
@@ -400,12 +427,11 @@ public:
     model.SetSegmentation(m_Segmentation);
 
     //remove first group
-    m_Segmentation->SetActiveLayer(0);
-    m_Segmentation->RemoveLayer();
+    m_Segmentation->RemoveGroup(0);
     CPPUNIT_ASSERT_EQUAL(2, model.rowCount(QModelIndex()));
-    CPPUNIT_ASSERT(CheckModelRow(model, { 0 }, { QString("Group 0"), QVariant(), QVariant(), QVariant() }));
+    CPPUNIT_ASSERT(CheckModelRow(model, { 0 }, { QString("Group 1"), QVariant(), QVariant(), QVariant() }));
     CPPUNIT_ASSERT_EQUAL(0, model.rowCount(GetIndex(model, { 0 })));
-    CPPUNIT_ASSERT(CheckModelRow(model, { 1 }, { QString("Group 1"), QVariant(), QVariant(), QVariant() }));
+    CPPUNIT_ASSERT(CheckModelRow(model, { 1 }, { QString("Group 2"), QVariant(), QVariant(), QVariant() }));
     CPPUNIT_ASSERT_EQUAL(1, model.rowCount(GetIndex(model, { 1 })));
     CPPUNIT_ASSERT(CheckModelRow(model, { 1,0 }, { QString("B"), QVariant(true), QVariant(QColor(9,9,9)), QVariant(true) }));
     CPPUNIT_ASSERT_EQUAL(0, model.rowCount(GetIndex(model, { 1,0 })));
@@ -417,11 +443,11 @@ public:
     QmitkMultiLabelTreeModel model(nullptr);
     model.SetSegmentation(m_Segmentation);
     //move from multiple instance to new label in the middle
-    auto label = m_Segmentation->GetLabel(5,0);
+    auto label = m_Segmentation->GetLabel(5);
     label->SetName("C");
 
     CPPUNIT_ASSERT_EQUAL(3, model.rowCount(QModelIndex()));
-    CPPUNIT_ASSERT(CheckModelRow(model, { 0 }, { QString("Group 0"), QVariant(), QVariant(), QVariant() }));
+    CPPUNIT_ASSERT(CheckModelRow(model, { 0 }, { QString("Group 1"), QVariant(), QVariant(), QVariant() }));
     CPPUNIT_ASSERT_EQUAL(4, model.rowCount(GetIndex(model, { 0 })));
     CPPUNIT_ASSERT(CheckModelRow(model, { 0,0 }, { QString("A (2 instances)"), QVariant(), QVariant(), QVariant() }));
     CPPUNIT_ASSERT_EQUAL(2, model.rowCount(GetIndex(model, { 0,0 })));
@@ -437,11 +463,11 @@ public:
     CheckModelGroup2Default(model);
 
     //move from multiple instance to new label at the end
-    label = m_Segmentation->GetLabel(10, 0);
+    label = m_Segmentation->GetLabel(10);
     label->SetName("E");
 
     CPPUNIT_ASSERT_EQUAL(3, model.rowCount(QModelIndex()));
-    CPPUNIT_ASSERT(CheckModelRow(model, { 0 }, { QString("Group 0"), QVariant(), QVariant(), QVariant() }));
+    CPPUNIT_ASSERT(CheckModelRow(model, { 0 }, { QString("Group 1"), QVariant(), QVariant(), QVariant() }));
     CPPUNIT_ASSERT_EQUAL(5, model.rowCount(GetIndex(model, { 0 })));
     CPPUNIT_ASSERT(CheckModelRow(model, { 0,0 }, { QString("A"), QVariant(true), QVariant(QColor(1,1,1)), QVariant(true) }));
     CPPUNIT_ASSERT_EQUAL(0, model.rowCount(GetIndex(model, { 0,0 })));
@@ -457,11 +483,11 @@ public:
     CheckModelGroup2Default(model);
 
     //move last instance to new label
-    label = m_Segmentation->GetLabel(10, 0);
+    label = m_Segmentation->GetLabel(10);
     label->SetName("F");
 
     CPPUNIT_ASSERT_EQUAL(3, model.rowCount(QModelIndex()));
-    CPPUNIT_ASSERT(CheckModelRow(model, { 0 }, { QString("Group 0"), QVariant(), QVariant(), QVariant() }));
+    CPPUNIT_ASSERT(CheckModelRow(model, { 0 }, { QString("Group 1"), QVariant(), QVariant(), QVariant() }));
     CPPUNIT_ASSERT_EQUAL(5, model.rowCount(GetIndex(model, { 0 })));
     CPPUNIT_ASSERT(CheckModelRow(model, { 0,0 }, { QString("A"), QVariant(true), QVariant(QColor(1,1,1)), QVariant(true) }));
     CPPUNIT_ASSERT_EQUAL(0, model.rowCount(GetIndex(model, { 0,0 })));
@@ -480,7 +506,7 @@ public:
     label->SetName("B");
 
     CPPUNIT_ASSERT_EQUAL(3, model.rowCount(QModelIndex()));
-    CPPUNIT_ASSERT(CheckModelRow(model, { 0 }, { QString("Group 0"), QVariant(), QVariant(), QVariant() }));
+    CPPUNIT_ASSERT(CheckModelRow(model, { 0 }, { QString("Group 1"), QVariant(), QVariant(), QVariant() }));
     CPPUNIT_ASSERT_EQUAL(4, model.rowCount(GetIndex(model, { 0 })));
     CPPUNIT_ASSERT(CheckModelRow(model, { 0,0 }, { QString("A"), QVariant(true), QVariant(QColor(1,1,1)), QVariant(true) }));
     CPPUNIT_ASSERT_EQUAL(0, model.rowCount(GetIndex(model, { 0,0 })));
@@ -501,14 +527,14 @@ public:
     QmitkMultiLabelTreeModel model(nullptr);
     model.SetSegmentation(m_Segmentation);
 
-    auto label = m_Segmentation->GetLabel(9, 2);
+    auto label = m_Segmentation->GetLabel(9);
 
     //check single instance modifications
     label->SetVisible(false);
     CPPUNIT_ASSERT_EQUAL(3, model.rowCount(QModelIndex()));
     CheckModelGroup0Default(model);
     CheckModelGroup1Default(model);
-    CPPUNIT_ASSERT(CheckModelRow(model, { 2 }, { QString("Group 2"), QVariant(), QVariant(), QVariant() }));
+    CPPUNIT_ASSERT(CheckModelRow(model, { 2 }, { QString("Group 3"), QVariant(), QVariant(), QVariant() }));
     CPPUNIT_ASSERT_EQUAL(1, model.rowCount(GetIndex(model, { 2 })));
     CPPUNIT_ASSERT(CheckModelRow(model, { 2,0 }, { QString("B"), QVariant(true), QVariant(QColor(9,9,9)), QVariant(false) }));
     CPPUNIT_ASSERT_EQUAL(0, model.rowCount(GetIndex(model, { 2,0 })));
@@ -518,19 +544,19 @@ public:
     CPPUNIT_ASSERT_EQUAL(3, model.rowCount(QModelIndex()));
     CheckModelGroup0Default(model);
     CheckModelGroup1Default(model);
-    CPPUNIT_ASSERT(CheckModelRow(model, { 2 }, { QString("Group 2"), QVariant(), QVariant(), QVariant() }));
+    CPPUNIT_ASSERT(CheckModelRow(model, { 2 }, { QString("Group 3"), QVariant(), QVariant(), QVariant() }));
     CPPUNIT_ASSERT_EQUAL(1, model.rowCount(GetIndex(model, { 2 })));
     CPPUNIT_ASSERT(CheckModelRow(model, { 2,0 }, { QString("B"), QVariant(false), QVariant(QColor(22,22,22)), QVariant(false) }));
     CPPUNIT_ASSERT_EQUAL(0, model.rowCount(GetIndex(model, { 2,0 })));
 
     //check instance modifications with multi instance label
     m_Segmentation->SetActiveLayer(2);
-    m_Segmentation->GetActiveLabelSet()->AddLabel(CreateLabel("B", 33));
+    m_Segmentation->AddLabel(CreateLabel("B", 33),2);
     label->SetVisible(true);
     CPPUNIT_ASSERT_EQUAL(3, model.rowCount(QModelIndex()));
     CheckModelGroup0Default(model);
     CheckModelGroup1Default(model);
-    CPPUNIT_ASSERT(CheckModelRow(model, { 2 }, { QString("Group 2"), QVariant(), QVariant(), QVariant() }));
+    CPPUNIT_ASSERT(CheckModelRow(model, { 2 }, { QString("Group 3"), QVariant(), QVariant(), QVariant() }));
     CPPUNIT_ASSERT_EQUAL(1, model.rowCount(GetIndex(model, { 2 })));
     CPPUNIT_ASSERT(CheckModelRow(model, { 2,0 }, { QString("B (2 instances)"), QVariant(), QVariant(), QVariant() }));
     CPPUNIT_ASSERT_EQUAL(2, model.rowCount(GetIndex(model, { 2,0 })));
