@@ -1,18 +1,14 @@
-/*===================================================================
+/*============================================================================
 
-BlueBerry Platform
+The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
-
-===================================================================*/
+============================================================================*/
 
 #ifndef BERRYIITERABLE_H_
 #define BERRYIITERABLE_H_
@@ -34,12 +30,12 @@ namespace berry {
 struct BERRY_EXPRESSIONS IIterable : public Object
 {
 
-  berryObjectMacro(berry::IIterable)
+  berryObjectMacro(berry::IIterable);
 
   typedef QList<Object::Pointer>::iterator iterator;
   typedef QList<Object::Pointer>::const_iterator const_iterator;
 
-  virtual ~IIterable();
+  ~IIterable() override;
 
   /**
    * Returns an iterator to iterate over the elements.
