@@ -1,18 +1,14 @@
-/*===================================================================
+/*============================================================================
 
-BlueBerry Platform
+The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
-
-===================================================================*/
+============================================================================*/
 
 #ifndef _BERRYJOBSTATUS_H
 #define _BERRYJOBSTATUS_H
@@ -33,8 +29,9 @@ public:
   /**
    * Creates a new job status with no interesting error code or exception.
    * @param severity
-   * @param job
+   * @param sptr_job
    * @param message
+   * @param sl
    */
   JobStatus(const Severity& severity, Job::Pointer sptr_job, const QString& message,
             const Status::SourceLocation& sl);
