@@ -1,19 +1,14 @@
-/*===================================================================
+/*============================================================================
 
-BlueBerry Platform
+The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
-
-See LICENSE.txt or http://www.mitk.org for details.
-
-===================================================================*/
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
+============================================================================*/
 
 #ifndef BERRYPLUGINACTIVATOR_H
 #define BERRYPLUGINACTIVATOR_H
@@ -26,9 +21,7 @@ class org_blueberry_core_jobs_Activator :
   public QObject, public ctkPluginActivator
 {
   Q_OBJECT
-#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
   Q_PLUGIN_METADATA(IID "org_blueberry_core_jobs")
-#endif
   Q_INTERFACES(ctkPluginActivator)
 
 public:
