@@ -1,18 +1,14 @@
-/*===================================================================
+/*============================================================================
 
 The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
-
-===================================================================*/
+============================================================================*/
 
 #include "berryApplicationContainer.h"
 
@@ -139,7 +135,7 @@ IBranding* ApplicationContainer::GetBranding() const
     return branding.data();
   }
   QList<IConfigurationElement::Pointer> elements = extensionRegistry->GetConfigurationElementsFor(PI_RUNTIME, PT_PRODUCTS);
-  for (auto element : elements)
+  for (const auto &element : std::as_const(elements))
   {
     if (element->GetName().compare("provider", Qt::CaseInsensitive) == 0)
     {
@@ -147,7 +143,7 @@ IBranding* ApplicationContainer::GetBranding() const
       {
         IProductProvider* provider = element->CreateExecutableExtension<IProductProvider>("run");
         QList<IProduct::Pointer> products = provider->GetProducts();
-        for (auto product : products)
+        for (const auto &product : std::as_const(products))
         {
           if (productId.compare(product->GetId(), Qt::CaseInsensitive) == 0)
           {
@@ -180,7 +176,7 @@ ApplicationDescriptor* ApplicationContainer::GetAppDescriptor(const QString& app
 {
   ApplicationDescriptor* result = nullptr;
   {
-    QMutexLocker l(&lock);
+    QMutexLocker l(&appDescLock);
     auto iter = apps.find(applicationId);
     result = iter == apps.end() ? nullptr : iter.value();
   }
@@ -189,7 +185,7 @@ ApplicationDescriptor* ApplicationContainer::GetAppDescriptor(const QString& app
   {
     RegisterAppDescriptor(applicationId); // try again just in case we are waiting for an event
     {
-      QMutexLocker l(&lock);
+      QMutexLocker l(&appDescLock);
       auto iter = apps.find(applicationId);
       result = iter == apps.end() ? nullptr : iter.value();
     }
@@ -205,7 +201,7 @@ ApplicationDescriptor* ApplicationContainer::CreateAppDescriptor(const SmartPoin
   }
   QString iconPath;
   {
-    QMutexLocker l(&lock);
+    QMutexLocker l(&appDescLock);
     auto iter = apps.find(appExtension->GetUniqueIdentifier());
     ApplicationDescriptor* appDescriptor = iter == apps.end() ? nullptr : iter.value();
     if (appDescriptor != nullptr)
@@ -290,7 +286,7 @@ ApplicationDescriptor*ApplicationContainer::RemoveAppDescriptor(const QString& a
   }
 
   {
-    QMutexLocker l(&lock);
+    QMutexLocker l(&appDescLock);
     ApplicationDescriptor* appDescriptor = apps.take(applicationId);
     if (appDescriptor == nullptr)
     {
@@ -379,7 +375,7 @@ QString ApplicationContainer::GetAvailableAppsMsg() const
   if (!availableApps.isEmpty())
   {
     availableAppsMsg = availableApps.front()->GetUniqueIdentifier();
-    for (auto availableApp : availableApps)
+    for (const auto &availableApp : std::as_const(availableApps))
     {
       availableAppsMsg = availableAppsMsg + ", " + availableApp->GetUniqueIdentifier();
     }
@@ -488,7 +484,7 @@ void ApplicationContainer::StopAllApps()
 {
   // get a stapshot of running applications
   QList<ctkServiceReference> runningRefs = context->getServiceReferences<ctkApplicationHandle>("(!(application.state=STOPPING))");
-  for (auto runningRef : runningRefs)
+  for (const auto &runningRef : std::as_const(runningRefs))
   {
     ctkApplicationHandle* handle = context->getService<ctkApplicationHandle>(runningRef);
     try
@@ -533,7 +529,7 @@ void ApplicationContainer::Lock(ApplicationHandle* /*appHandle*/)
   /*
   ApplicationDescriptor eclipseApp = (ApplicationDescriptor) appHandle.getApplicationDescriptor();
   {
-    QMutexLocker l(&lock);
+    QMutexLocker l(&appDescLock);
     switch (isLocked(eclipseApp))
     {
     case NOT_LOCKED :
@@ -590,7 +586,7 @@ void ApplicationContainer::Lock(ApplicationHandle* /*appHandle*/)
 void ApplicationContainer::Unlock(ApplicationHandle* /*appHandle*/)
 {
   /*
-  QMutexLocker l(&lock);
+  QMutexLocker l(&appDescLock);
   if (activeGlobalSingleton == appHandle)
     activeGlobalSingleton = null;
   else if (activeScopedSingleton == appHandle)
@@ -613,7 +609,7 @@ int ApplicationContainer::IsLocked(const ApplicationDescriptor* /*eclipseApp*/)
 {
   /*
   {
-    QMutexLocker l(&lock);
+    QMutexLocker l(&appDescLock);
     if (activeGlobalSingleton != null)
       return LOCKED_SINGLETON_GLOBAL_RUNNING;
     switch (eclipseApp.getCardinalityType()) {
@@ -684,7 +680,7 @@ void ApplicationContainer::removedService(const ctkServiceReference& /*reference
 
 void ApplicationContainer::Added(const QList<SmartPointer<IExtension> >& extensions)
 {
-  for (IExtension::Pointer extension : extensions)
+  for (const IExtension::Pointer &extension : extensions)
   {
     CreateAppDescriptor(extension);
   }
@@ -697,7 +693,7 @@ void ApplicationContainer::Added(const QList<SmartPointer<IExtensionPoint> >& /*
 
 void ApplicationContainer::Removed(const QList<SmartPointer<IExtension> >& extensions)
 {
-  for (IExtension::Pointer extension : extensions)
+  for (const IExtension::Pointer &extension : extensions)
   {
     RemoveAppDescriptor(extension->GetUniqueIdentifier());
   }
@@ -710,7 +706,7 @@ void ApplicationContainer::Removed(const QList<SmartPointer<IExtensionPoint> >&
 
 void ApplicationContainer::RefreshAppDescriptors()
 {
-  QMutexLocker l(&lock);
+  QMutexLocker l(&appDescLock);
   for (ApplicationDescriptor* app : apps.values())
   {
     app->RefreshProperties();
