@@ -178,7 +178,7 @@ QSharedPointer<ctkPlugin> org_blueberry_core_runtime_Activator::GetPlugin(const
   auto plugins = context->getPlugins();
 
   //Return the first plugin that is not installed or uninstalled
-  for (auto plugin : qAsConst(plugins))
+  for (auto plugin : std::as_const(plugins))
   {
     if (!(plugin->getState() == ctkPlugin::INSTALLED ||
           plugin->getState() == ctkPlugin::UNINSTALLED))
