@@ -1,18 +1,14 @@
-/*===================================================================
+/*============================================================================
 
-BlueBerry Platform
+The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
-
-===================================================================*/
+============================================================================*/
 
 
 #include "berryExtensionRegistry.h"
@@ -31,7 +27,6 @@ See LICENSE.txt or http://www.mitk.org for details.
 #include "berryIExtensionPoint.h"
 #include "berrySimpleExtensionPointFilter.h"
 #include "berryMultiStatus.h"
-#include "berryPlatform.h"
 #include "berryRegistryConstants.h"
 #include "berryRegistryContribution.h"
 #include "berryRegistryContributor.h"
@@ -43,7 +38,7 @@ See LICENSE.txt or http://www.mitk.org for details.
 #include "berryStatus.h"
 
 #include <QThread>
-#include <QTime>
+#include <QElapsedTimer>
 
 namespace berry {
 
@@ -454,7 +449,7 @@ bool ExtensionRegistry::RemoveObject(const SmartPointer<RegistryObject>& registr
 
 void ExtensionRegistry::SetFileManager(const QString& /*cacheBase*/, bool /*isCacheReadOnly*/)
 {
-//  if (cacheStorageManager != NULL)
+//  if (cacheStorageManager != nullptr)
 //    cacheStorageManager->Close(); // close existing file manager first
 
 //  if (cacheBase != null) {
@@ -799,7 +794,7 @@ ExtensionRegistry::ExtensionRegistry(RegistryStrategy* registryStrategy, QObject
   if (strategy->CacheUse())
   {
     // Try to read the registry from the cache first. If that fails, create a new registry
-    QTime timer;
+    QElapsedTimer timer;
     if (Debug())
       timer.start();
 
@@ -908,8 +903,8 @@ ExtensionRegistry::~ExtensionRegistry()
 
 void ExtensionRegistry::Stop(QObject* /*key*/)
 {
-  // If the registry creator specified a key token, check that the key mathches it
-  // (it is assumed that registry owner keeps the key to prevent unautorized accesss).
+  // If the registry creator specified a key token, check that the key matches it
+  // (it is assumed that registry owner keeps the key to prevent unautorized access).
   if (masterToken != nullptr && masterToken != nullptr)
   {
     throw ctkInvalidArgumentException("Unauthorized access to the ExtensionRegistry.stop() method. Check if proper access token is supplied."); //$NON-NLS-1$
@@ -920,7 +915,7 @@ void ExtensionRegistry::Stop(QObject* /*key*/)
 
   StopChangeEventScheduler();
 
-//  if (cacheStorageManager == NULL)
+//  if (cacheStorageManager == nullptr)
 //    return;
 
 //  if (!registryObjects.isDirty() || cacheStorageManager.isReadOnly()) {
