@@ -1,18 +1,14 @@
-/*===================================================================
+/*============================================================================
 
-BlueBerry Platform
+The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
-
-===================================================================*/
+============================================================================*/
 
 #include "berryRegistryConstants.h"
 
@@ -25,7 +21,7 @@ const QString RegistryConstants::PROP_NO_LAZY_REGISTRY_CACHE_LOADING = "BlueBerr
 const QString RegistryConstants::PROP_CHECK_CONFIG = "osgi.checkConfiguration";
 const QString RegistryConstants::PROP_NO_REGISTRY_CACHE = "BlueBerry.noRegistryCache";
 const QString RegistryConstants::PROP_DEFAULT_REGISTRY = "BlueBerry.createRegistry";
-const QString RegistryConstants::PROP_REGISTRY_NULL_USER_TOKEN = "BlueBerry.registry.nulltoken";
+const QString RegistryConstants::PROP_REGISTRY_nullptr_USER_TOKEN = "BlueBerry.registry.nulltoken";
 const QString RegistryConstants::PROP_REGISTRY_MULTI_LANGUAGE = "BlueBerry.registry.MultiLanguage";
 
 const int RegistryConstants::PLUGIN_ERROR = 1;
