@@ -1,18 +1,14 @@
-/*===================================================================
+/*============================================================================
 
-BlueBerry Platform
+The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
-
-===================================================================*/
+============================================================================*/
 
 #include "berryHelpPerspective.h"
 
@@ -34,8 +30,8 @@ void HelpPerspective::CreateInitialLayout(berry::IPageLayout::Pointer layout)
 
   berry::IFolderLayout::Pointer leftFolder =
       layout->CreateFolder("lefttop", berry::IPageLayout::TOP, 0.65f, "org.blueberry.views.helpsearch");
-  leftFolder->AddView("org.blueberry.views.helpcontents");
   leftFolder->AddView("org.blueberry.views.helpindex");
+  leftFolder->AddView("org.blueberry.views.helpcontents");
 
   // Make every help related view unclosable
   IViewLayout::Pointer lo = layout->GetViewLayout("org.blueberry.views.helpsearch");
