@@ -1,18 +1,14 @@
-/*===================================================================
+/*============================================================================
 
-BlueBerry Platform
+The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
-
-===================================================================*/
+============================================================================*/
 
 
 #ifndef BERRYSHELLEVENT_H_
@@ -32,7 +28,6 @@ class Shell;
  * operations being performed on shells.
  *
  * @see ShellListener
- * @see <a href="http://www.blueberry.org/swt/">Sample code and further information</a>
  */
 
 class BERRY_UI_QT ShellEvent : public Object {
@@ -51,7 +46,7 @@ public:
    * Constructs a new instance of this class based on the
    * information in the given untyped event.
    *
-   * @param e the untyped event containing the information
+   * @param source the untyped event containing the information
    */
   ShellEvent(SmartPointer<Shell> source) ;
 
