@@ -1,18 +1,14 @@
-/*===================================================================
+/*============================================================================
 
-BlueBerry Platform
+The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
-
-===================================================================*/
+============================================================================*/
 
 #include "berryLayoutTreeNode.h"
 
@@ -184,7 +180,7 @@ void LayoutTreeNode::FindSashes(LayoutTree::Pointer child, PartPane::Sashes sash
   {
     LayoutPartSash::Pointer partSash = this->GetSash();
     //If the child is in the left, the sash
-    //is in the rigth and so on.
+    //is in the right and so on.
     if (leftOrTop)
     {
       if (partSash->IsVertical())
