@@ -1,21 +1,17 @@
-/*===================================================================
+/*============================================================================
 
-BlueBerry Platform
+The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
+============================================================================*/
 
-===================================================================*/
-
-#ifndef BERRYNULLEDITORINPUT_H_
-#define BERRYNULLEDITORINPUT_H_
+#ifndef BERRYnullptrEDITORINPUT_H_
+#define BERRYnullptrEDITORINPUT_H_
 
 #include "berryIEditorInput.h"
 #include "berryEditorReference.h"
@@ -32,7 +28,7 @@ private: EditorReference::Pointer editorReference;
 
 public:
 
-  berryObjectMacro(NullEditorInput)
+  berryObjectMacro(NullEditorInput);
 
   NullEditorInput();
 
@@ -62,4 +58,4 @@ public:
 
 }
 
-#endif /*BERRYNULLEDITORINPUT_H_*/
+#endif /*BERRYnullptrEDITORINPUT_H_*/
