@@ -1,18 +1,14 @@
-/*===================================================================
+/*============================================================================
 
-BlueBerry Platform
+The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
-
-===================================================================*/
+============================================================================*/
 
 #include "tweaklets/berryGuiWidgetsTweaklet.h"
 
@@ -26,8 +22,6 @@ See LICENSE.txt or http://www.mitk.org for details.
 #include "berryPerspectiveHelper.h"
 #include "berryDragUtil.h"
 #include "berryWorkbenchPlugin.h"
-#include "berryIPreferencesService.h"
-#include "berryIPreferences.h"
 
 #include "berryWorkbenchPreferenceConstants.h"
 #include "berryGeometry.h"
@@ -37,6 +31,7 @@ See LICENSE.txt or http://www.mitk.org for details.
 
 #include "berryConstants.h"
 
+#include <mitkIPreferences.h>
 
 namespace berry
 {
@@ -221,9 +216,9 @@ PartSashContainer::PartSashContainer(const QString& id,
 {
   resizeListener = new ControlListener(this);
 
-  QString layout = WorkbenchPlugin::GetDefault()->GetPreferencesService()->
-      GetSystemPreferences()->Get(WorkbenchPreferenceConstants::PREFERRED_SASH_LAYOUT,
-          WorkbenchPreferenceConstants::LEFT);
+  auto layout = WorkbenchPlugin::GetDefault()->GetPreferences()->Get(
+    WorkbenchPreferenceConstants::PREFERRED_SASH_LAYOUT, WorkbenchPreferenceConstants::LEFT);
+
   if (layout == WorkbenchPreferenceConstants::RIGHT)
   {
     leftToRight = false;
