@@ -1,18 +1,14 @@
-/*===================================================================
+/*============================================================================
 
-BlueBerry Platform
+The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
-
-===================================================================*/
+============================================================================*/
 
 #include "berrySaveablesList.h"
 #include "berryWorkbenchPlugin.h"
@@ -609,7 +605,7 @@ QList<Object::Pointer> SaveablesList::TestGetSourcesForModel(
 
 QList<ISaveablesSource::Pointer> SaveablesList::GetNonPartSources()
 {
-  return nonPartSources.toList();
+  return nonPartSources.values();
 }
 
 QList<IWorkbenchPart::Pointer> SaveablesList::GetPartsForSaveable(
