@@ -1,18 +1,14 @@
-/*===================================================================
+/*============================================================================
 
-BlueBerry Platform
+The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
-
-===================================================================*/
+============================================================================*/
 
 #include "berryLog.h"
 
@@ -56,8 +52,6 @@ See LICENSE.txt or http://www.mitk.org for details.
 #include <berryIElementFactory.h>
 #include <berryIHandler.h>
 #include <berryIHandlerService.h>
-#include <berryIPreferencesService.h>
-#include <berryIPreferences.h>
 #include <berryIProduct.h>
 #include <berryISourceProvider.h>
 #include <berryIServiceScopes.h>
@@ -68,6 +62,8 @@ See LICENSE.txt or http://www.mitk.org for details.
 
 #include <Poco/FileStream.h>
 
+#include <mitkIPreferences.h>
+
 namespace berry
 {
 
@@ -482,10 +478,10 @@ bool Workbench::RestoreState(IMemento::Pointer memento)
 
       // If we don't know how many plug-ins were loaded last time,
       // assume we are loading half of the installed plug-ins.
-      /*const std::size_t expectedProgressCount =*/
+      /*const std::size_t expectedProgressCount =
       std::max<std::size_t>(1,
           lastProgressCount == -1 ? WorkbenchPlugin::GetDefault()->GetBundleCount() / 2
-          : lastProgressCount);
+          : lastProgressCount);*/
 
       //TODO restore state progress
       //        RunStartupWithProgress(expectedProgressCount, new Runnable() {
@@ -748,7 +744,7 @@ void Workbench::InitializeDefaultServices()
    * of wrappers for legacy APIs. By the time this phase completes, any
    * code trying to access commands through legacy APIs should work.
    */
-  //IHandlerService* handlerService = NULL;
+  //IHandlerService* handlerService = nullptr;
 //      StartupThreading.runWithoutExceptions(new StartupRunnable() {
 
 //        public void runWithException() {
@@ -1198,7 +1194,7 @@ IWorkbenchPage::Pointer Workbench::ShowPerspective(
 
   // If another window that has the workspace root as input and the
   // requested
-  // perpective open and active, then the window is given focus.
+  // perspective open and active, then the window is given focus.
   IAdaptable* input = GetDefaultPageInput();
   QList<IWorkbenchWindow::Pointer> windows(GetWorkbenchWindows());
   for (int i = 0; i < windows.size(); i++)
@@ -1251,9 +1247,8 @@ IWorkbenchPage::Pointer Workbench::ShowPerspective(
   win = window.Cast<WorkbenchWindow>();
   if (win)
   {
-    IPreferencesService* store = WorkbenchPlugin::GetDefault()->GetPreferencesService();
-    int mode = store->GetSystemPreferences()->GetInt(PreferenceConstants::OPEN_PERSP_MODE,
-                                                     PreferenceConstants::OPM_ACTIVE_PAGE);
+    auto* prefs = WorkbenchPlugin::GetDefault()->GetPreferences();
+    int mode = prefs->GetInt(PreferenceConstants::OPEN_PERSP_MODE, PreferenceConstants::OPM_ACTIVE_PAGE);
     IWorkbenchPage::Pointer page = win->GetActivePage();
     IPerspectiveDescriptor::Pointer persp;
     if (page)
@@ -1331,7 +1326,7 @@ IWorkbenchPage::Pointer Workbench::ShowPerspective(
   //    }
   //
   //    // If another window has the requested input and the requested
-  //    // perpective open and active, then that window is given focus.
+  //    // perspective open and active, then that window is given focus.
   //    IWorkbenchWindow[] windows = getWorkbenchWindows();
   //    for (int i = 0; i < windows.length; i++) {
   //      win = (WorkbenchWindow) windows[i];
