@@ -1,18 +1,14 @@
-/*===================================================================
+/*============================================================================
 
-BlueBerry Platform
+The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
-
-===================================================================*/
+============================================================================*/
 
 #ifndef BERRYWORKBENCH_H_
 #define BERRYWORKBENCH_H_
@@ -71,7 +67,7 @@ class BERRY_UI_QT Workbench : public IWorkbench, private IWindowListener
 
 public:
 
-  berryObjectMacro(Workbench)
+  berryObjectMacro(Workbench);
 
   friend class RestoreStateRunnable;
 
@@ -116,7 +112,7 @@ public:
    */
   static Workbench* GetInstance();
 
-  virtual ~Workbench();
+  ~Workbench() override;
 
   /*
    * (non-Javadoc)
