@@ -1,18 +1,14 @@
-/*===================================================================
+/*============================================================================
 
-BlueBerry Platform
+The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
-
-===================================================================*/
+============================================================================*/
 
 
 #include "berryWorkbenchMenuService.h"
@@ -37,9 +33,7 @@ See LICENSE.txt or http://www.mitk.org for details.
 #include "berryWorkbenchPlugin.h"
 #include "berryWorkbenchWindow.h"
 
-#if (QT_VERSION >= QT_VERSION_CHECK(5,0,0))
 #include <QUrlQuery>
-#endif
 
 namespace berry {
 
@@ -103,7 +97,7 @@ public:
   /**
    * Dispose of this updater
    */
-  ~ContributionItemUpdater()
+  ~ContributionItemUpdater() override
   {
 //    if (identifier.IsNotNull())
 //      identifier->RemoveIdentifierListener(this);
@@ -273,7 +267,7 @@ void WorkbenchMenuService::RemoveSourceProvider(const SmartPointer<ISourceProvid
 
 void WorkbenchMenuService::UpdateManagers()
 {
-  QList<IContributionManager*> managers = managersAwaitingUpdates.toList();
+  QList<IContributionManager*> managers = managersAwaitingUpdates.values();
   managersAwaitingUpdates.clear();
   foreach (IContributionManager* mgr, managers)
   {
@@ -946,15 +940,9 @@ void WorkbenchMenuService::ReleaseCache(ContributionRoot* items)
 int WorkbenchMenuService::GetInsertionIndex(ContributionManager* mgr, const QString& location)
 {
   QUrl uri(location);
-#if (QT_VERSION < QT_VERSION_CHECK(5,0,0))
-  QList<QPair<QString,QString> > queryParts = uri.queryItems();
-  bool indexAfterAdditions = uri.queryItemValue(INDEX_AFTER_ADDITIONS_QK) == INDEX_AFTER_ADDITIONS_QV;
-#else
   QUrlQuery query(uri);
   QList<QPair<QString,QString> > queryParts = query.queryItems();
   bool indexAfterAdditions = query.queryItemValue(INDEX_AFTER_ADDITIONS_QK) == INDEX_AFTER_ADDITIONS_QV;
-#endif
-
   int additionsIndex = -1;
 
   // No Query means 'after=additions' (if there) or
