@@ -1,18 +1,14 @@
-/*===================================================================
+/*============================================================================
 
-BlueBerry Platform
+The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
-
-===================================================================*/
+============================================================================*/
 
 #ifndef BERRYWORKBENCHPAGE_H_
 #define BERRYWORKBENCHPAGE_H_
@@ -62,7 +58,7 @@ class BERRY_UI_QT WorkbenchPage: public IWorkbenchPage
 {
 
 public:
-  berryObjectMacro(WorkbenchPage)
+  berryObjectMacro(WorkbenchPage);
 
 protected:
 
@@ -197,7 +193,7 @@ private:
     SmartPointer<IWorkbenchPartReference> GetActiveReference(bool editorsOnly);
 
     /*
-     * Retuns the index of the part within the activation list. The higher
+     * Returns the index of the part within the activation list. The higher
      * the index, the more recently it was used.
      */
     PartListIter IndexOf(SmartPointer<IWorkbenchPart> part);
@@ -435,7 +431,7 @@ public:
 
   /**
    * Constructs a page. <code>restoreState(IMemento)</code> should be
-   * called to restore this page from data stored in a persistance file.
+   * called to restore this page from data stored in a persistence file.
    *
    * @param w
    *            the parent window
@@ -445,7 +441,7 @@ public:
    */
   WorkbenchPage(WorkbenchWindow* w, IAdaptable* input);
 
-  ~WorkbenchPage();
+  ~WorkbenchPage() override;
 
   /**
    * Activates a part. The part will be brought to the front and given focus.
@@ -495,7 +491,7 @@ public:
 private:
 
   /**
-   * Activates a part. The part is given focus, the pane is hilighted.
+   * Activates a part. The part is given focus, the pane is highlighted.
    */
   void ActivatePart(const IWorkbenchPart::Pointer part);
 
@@ -703,7 +699,7 @@ private:
   void DisposePart(WorkbenchPartReference::Pointer ref);
 
   /**
-   * Deactivates a part. The pane is unhilighted.
+   * Deactivates a part. The pane is unhighlighted.
    */
   void DeactivatePart(IWorkbenchPart::Pointer part);
 
@@ -830,7 +826,7 @@ public:
 
   /**
    * Allow access to the part service for this page ... used internally to
-   * propogate certain types of events to the page part listeners.
+   * propagate certain types of events to the page part listeners.
    * @return the part service for this page.
    */
   PartService* GetPartService();
@@ -1252,8 +1248,8 @@ protected:
   QList<SmartPointer<Perspective> > GetOpenInternalPerspectives();
 
   /**
-   * Checks perspectives in the order they were activiated
-   * for the specfied part.  The first sorted perspective
+   * Checks perspectives in the order they were activated
+   * for the specified part.  The first sorted perspective
    * that contains the specified part is returned.
    *
    * @param part specified part to search for
@@ -1309,7 +1305,7 @@ public:
   void ResizeView(IViewPart::Pointer part, int width, int height);
 
   /**
-   * Sanity-checks the objects in this page. Throws an Assertation exception
+   * Sanity-checks the objects in this page. Throws an Assertion exception
    * if an object's internal state is invalid. ONLY INTENDED FOR USE IN THE
    * UI TEST SUITES.
    */
@@ -1373,8 +1369,7 @@ private:
   QList<IViewReference::Pointer> GetViewReferenceStack(
       IViewPart::Pointer part);
 
-  struct ActivationOrderPred : std::binary_function<IViewReference::Pointer,
-  IViewReference::Pointer, bool>
+  struct ActivationOrderPred
   {
     ActivationOrderPred(ActivationList* partList);
 
