@@ -1,18 +1,14 @@
-/*===================================================================
+/*============================================================================
 
-BlueBerry Platform
+The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
-
-===================================================================*/
+============================================================================*/
 
 #include "berryWorkbenchPartReference.h"
 
@@ -418,12 +414,6 @@ IWorkbenchPart::Pointer WorkbenchPartReference::GetPart(bool restore)
 
     if (state == STATE_CREATION_IN_PROGRESS)
     {
-      //                IStatus result = WorkbenchPlugin.getStatus(
-      //                        new PartInitException(NLS.bind("Warning: Detected recursive attempt by part {0} to create itself (this is probably, but not necessarily, a bug)",  //$NON-NLS-1$
-      //                                getId())));
-      WorkbenchPlugin::Log("Warning: Detected recursive attempt by part "
-          + GetId()
-          + " to create itself (this is probably, but not necessarily, a bug)");
       return IWorkbenchPart::Pointer(nullptr);
     }
 
