@@ -1,18 +1,14 @@
-/*===================================================================
+/*============================================================================
 
-BlueBerry Platform
+The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
-
-===================================================================*/
+============================================================================*/
 
 
 #ifndef BERRYISAFERUNNABLERUNNER_H_
@@ -43,9 +39,9 @@ struct BERRY_UI_QT ISafeRunnableRunner : public Object
 
 public:
 
-  berryObjectMacro(berry::ISafeRunnableRunner)
+  berryObjectMacro(berry::ISafeRunnableRunner);
 
-  ~ISafeRunnableRunner();
+  ~ISafeRunnableRunner() override;
 
   /**
    * Runs the runnable.  All <code>ISafeRunnableRunners</code> must catch any exception
