@@ -1,22 +1,18 @@
-/*===================================================================
+/*============================================================================
 
 The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
-
-===================================================================*/
+============================================================================*/
 
 
-#ifndef MITKDATATREENODEOBJECT_H_
-#define MITKDATATREENODEOBJECT_H_
+#ifndef mitkDataNodeObject_h
+#define mitkDataNodeObject_h
 
 #include <berryObject.h>
 #include <berryMacros.h>
@@ -54,4 +50,4 @@ private:
 
 }
 
-#endif /* MITKDATATREENODEOBJECT_H_ */
+#endif
