@@ -1,21 +1,17 @@
-/*===================================================================
+/*============================================================================
 
 The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
+============================================================================*/
 
-===================================================================*/
-
-#ifndef MITKWORKBENCHCOMMANDCONSTANTS_H
-#define MITKWORKBENCHCOMMANDCONSTANTS_H
+#ifndef mitkWorkbenchCommandConstants_h
+#define mitkWorkbenchCommandConstants_h
 
 #include <org_mitk_gui_common_Export.h>
 
@@ -46,4 +42,4 @@ public:
 }
 
 
-#endif // MITKWORKBENCHCOMMANDCONSTANTS_H
+#endif
