@@ -1,28 +1,17 @@
-/*===================================================================
+/*============================================================================
 
 The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
+============================================================================*/
 
-===================================================================*/
-
-#ifndef QmitkCloseProjectAction_H_
-#define QmitkCloseProjectAction_H_
-
-#ifdef __MINGW32__
-// We need to include winbase.h here in order to declare
-// atomic intrinsics like InterlockedIncrement correctly.
-// Otherwhise, they would be declared wrong within qatomic_windows.h .
-#include <windows.h>
-#endif
+#ifndef QmitkCloseProjectAction_h
+#define QmitkCloseProjectAction_h
 
 #include <berrySmartPointer.h>
 
@@ -53,4 +42,4 @@ private:
   void init(berry::IWorkbenchWindow* window);
   berry::IWorkbenchWindow* m_Window;
 };
-#endif /*QmitkCloseProjectAction_H_*/
+#endif
