@@ -1,30 +1,27 @@
-/*===================================================================
+/*============================================================================
 
 The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
-
-===================================================================*/
+============================================================================*/
 
 
-#ifndef QMITKCOMMONACTIVATOR_H_
-#define QMITKCOMMONACTIVATOR_H_
+#ifndef QmitkCommonActivator_h
+#define QmitkCommonActivator_h
 
 #include <ctkPluginActivator.h>
-#include <ctkServiceTracker.h>
-
-#include <berryIPreferencesService.h>
-
 #include "QmitkViewCoordinator.h"
 
+namespace mitk
+{
+  class IPreferencesService;
+}
+
 /**
  * \ingroup org_mitk_gui_qt_common_internal
  *
@@ -36,9 +33,7 @@ See LICENSE.txt or http://www.mitk.org for details.
 class QmitkCommonActivator : public QObject, public ctkPluginActivator
 {
   Q_OBJECT
-#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
   Q_PLUGIN_METADATA(IID "org_mitk_gui_qt_common")
-#endif
   Q_INTERFACES(ctkPluginActivator)
 
 public:
@@ -46,7 +41,7 @@ public:
   static ctkPluginContext* GetContext();
   static QmitkCommonActivator* GetInstance();
 
-  berry::IPreferencesService* GetPreferencesService();
+  mitk::IPreferencesService* GetPreferencesService();
 
   /**
    * Sets default StateMachine to EventMapper.
@@ -60,9 +55,6 @@ private:
   static ctkPluginContext* m_Context;
 
   QScopedPointer<QmitkViewCoordinator> m_ViewCoordinator;
-  QScopedPointer<ctkServiceTracker<berry::IPreferencesService*> > m_PrefServiceTracker;
-
 };
 
-#endif /* QMITKCOMMONACTIVATOR_H_ */
-
+#endif
