@@ -1,26 +1,21 @@
-/*===================================================================
+/*============================================================================
 
 The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
-
-===================================================================*/
+============================================================================*/
 
 
-#ifndef QMITKDATAMANAGERPREFERENCEPAGE_H_
-#define QMITKDATAMANAGERPREFERENCEPAGE_H_
+#ifndef QmitkDataManagerPreferencePage_h
+#define QmitkDataManagerPreferencePage_h
 
 #include "berryIQtPreferencePage.h"
 #include <org_mitk_gui_qt_datamanager_Export.h>
-#include <berryIPreferences.h>
 
 class QWidget;
 class QCheckBox;
@@ -42,17 +37,17 @@ public:
   ///
   /// \see IPreferencePage::PerformOk()
   ///
-  virtual bool PerformOk() override;
+  bool PerformOk() override;
 
   ///
   /// \see IPreferencePage::PerformCancel()
   ///
-  virtual void PerformCancel() override;
+  void PerformCancel() override;
 
   ///
   /// \see IPreferencePage::Update()
   ///
-  virtual void Update() override;
+  void Update() override;
 
 protected:
   QWidget* m_MainControl;
@@ -60,10 +55,7 @@ protected:
   QCheckBox* m_PlaceNewNodesOnTop;
   QCheckBox* m_ShowHelperObjects;
   QCheckBox* m_ShowNodesContainingNoData;
-  QCheckBox* m_GlobalReinitOnNodeDelete;
-  QCheckBox* m_GlobalReinitOnNodeAdded;
-  QCheckBox* m_UseSurfaceDecimation;
-  berry::IPreferences::Pointer m_DataManagerPreferencesNode;
+  QCheckBox* m_AllowParentChange;
 };
 
-#endif /* QMITKDATAMANAGERPREFERENCEPAGE_H_ */
+#endif
