@@ -18,9 +18,16 @@ found in the LICENSE file.
 #include <mitkLinearModelParameterizer.h>
 #include <mitkGenericParamModelFactory.h>
 #include <mitkGenericParamModelParameterizer.h>
-#include <mitkT2DecayModelFactory.h>
-#include <mitkT2DecayModelParameterizer.h>
-
+#include <mitkExponentialDecayModelFactory.h>
+#include <mitkExponentialDecayModelParameterizer.h>
+#include <mitkExponentialSaturationModel.h>
+#include <mitkExponentialSaturationModelFactory.h>
+#include <mitkExponentialSaturationModelParameterizer.h>
+#include "mitkTwoStepLinearModelFactory.h"
+#include "mitkTwoStepLinearModelParameterizer.h"
+#include "mitkThreeStepLinearModelFactory.h"
+#include "mitkThreeStepLinearModelParameterizer.h"
+#include <mitkLabelSetImageConverter.h>
 
 #include <mitkValueBasedParameterizationDelegate.h>
 
@@ -29,6 +36,8 @@ found in the LICENSE file.
 #include <mitkNodePredicateProperty.h>
 #include <mitkNodePredicateDataType.h>
 #include <mitkNodePredicateOr.h>
+#include "mitkNodePredicateFunction.h"
+#include <mitkMultiLabelPredicateHelper.h>
 #include <mitkPixelBasedParameterFitImageGenerator.h>
 #include <mitkROIBasedParameterFitImageGenerator.h>
 #include <mitkLevenbergMarquardtModelFitFunctor.h>
@@ -67,13 +76,29 @@ void GenericDataFittingView::CreateQtPartControl(QWidget* parent)
   m_Controls.btnModelling->setEnabled(false);
 
   this->InitModelComboBox();
+  m_Controls.labelMaskInfo->hide();
+
+  m_Controls.timeSeriesNodeSelector->SetNodePredicate(this->m_isValidTimeSeriesImagePredicate);
+  m_Controls.timeSeriesNodeSelector->SetDataStorage(this->GetDataStorage());
+  m_Controls.timeSeriesNodeSelector->SetSelectionIsOptional(false);
+  m_Controls.timeSeriesNodeSelector->SetInvalidInfo("Please select time series.");
+  m_Controls.timeSeriesNodeSelector->SetAutoSelectNewNodes(true);
+
+  m_Controls.maskNodeSelector->SetNodePredicate(mitk::GetMultiLabelSegmentationPredicate());
+  m_Controls.maskNodeSelector->SetDataStorage(this->GetDataStorage());
+  m_Controls.maskNodeSelector->SetSelectionIsOptional(true);
+  m_Controls.maskNodeSelector->SetEmptyInfo("Please select (optional) mask.");
 
   connect(m_Controls.btnModelling, SIGNAL(clicked()), this, SLOT(OnModellingButtonClicked()));
 
+
   connect(m_Controls.comboModel, SIGNAL(currentIndexChanged(int)), this, SLOT(OnModellSet(int)));
   connect(m_Controls.radioPixelBased, SIGNAL(toggled(bool)), this, SLOT(UpdateGUIControls()));
 
-  //Gerneric setting
+  connect(m_Controls.timeSeriesNodeSelector, &QmitkAbstractNodeSelectionWidget::CurrentSelectionChanged, this, &GenericDataFittingView::OnImageNodeSelectionChanged);
+  connect(m_Controls.maskNodeSelector, &QmitkAbstractNodeSelectionWidget::CurrentSelectionChanged, this, &GenericDataFittingView::OnMaskNodeSelectionChanged);
+
+  //Generic setting
   m_Controls.groupGeneric->hide();
   m_Controls.labelFormulaInfo->hide();
   connect(m_Controls.editFormula, SIGNAL(textChanged(const QString&)), this,
@@ -82,6 +107,8 @@ void GenericDataFittingView::CreateQtPartControl(QWidget* parent)
           SLOT(setVisible(bool)));
   connect(m_Controls.nrOfParams, SIGNAL(valueChanged(int)), this, SLOT(OnNrOfParamsChanged()));
 
+  connect(m_Controls.checkMaskInfo, SIGNAL(toggled(bool)), m_Controls.labelMaskInfo,
+    SLOT(setVisible(bool)));
 
   //Model fit configuration
   m_Controls.groupBox_FitConfiguration->hide();
@@ -89,15 +116,17 @@ void GenericDataFittingView::CreateQtPartControl(QWidget* parent)
   m_Controls.checkBox_Constraints->setEnabled(false);
   m_Controls.constraintManager->setEnabled(false);
   m_Controls.initialValuesManager->setEnabled(false);
+  m_Controls.initialValuesManager->setDataStorage(this->GetDataStorage());
+
+  connect(m_Controls.radioButton_StartParameters, SIGNAL(toggled(bool)), this, SLOT(UpdateGUIControls()));
+  connect(m_Controls.initialValuesManager, SIGNAL(initialValuesChanged(void)), this, SLOT(UpdateGUIControls()));
 
-  connect(m_Controls.radioButton_StartParameters, SIGNAL(toggled(bool)), this,
-          SLOT(UpdateGUIControls()));
   connect(m_Controls.checkBox_Constraints, SIGNAL(toggled(bool)), this,
           SLOT(UpdateGUIControls()));
-
   connect(m_Controls.radioButton_StartParameters, SIGNAL(toggled(bool)),
           m_Controls.initialValuesManager,
           SLOT(setEnabled(bool)));
+
   connect(m_Controls.checkBox_Constraints, SIGNAL(toggled(bool)), m_Controls.constraintManager,
           SLOT(setEnabled(bool)));
   connect(m_Controls.checkBox_Constraints, SIGNAL(toggled(bool)), m_Controls.constraintManager,
@@ -185,6 +214,23 @@ void GenericDataFittingView::OnModellSet(int index)
         MITK_WARN << "Invalid model index. Index outside of the factory stack. Factory stack size: "<< m_FactoryStack.size() << "; invalid index: "<< index;
     }
   }
+  if (m_selectedModelFactory)
+  {
+    this->m_modelConstraints = dynamic_cast<mitk::SimpleBarrierConstraintChecker*>
+      (m_selectedModelFactory->CreateDefaultConstraints().GetPointer());
+
+    if (this->m_modelConstraints.IsNull())
+    {
+      this->m_modelConstraints = mitk::SimpleBarrierConstraintChecker::New();
+    }
+
+    m_Controls.initialValuesManager->setInitialValues(m_selectedModelFactory->GetParameterNames(),
+      m_selectedModelFactory->GetDefaultInitialParameterization());
+
+    m_Controls.constraintManager->setChecker(this->m_modelConstraints,
+      this->m_selectedModelFactory->GetParameterNames());
+
+  }
 
   UpdateGUIControls();
 }
@@ -243,7 +289,14 @@ void GenericDataFittingView::OnModellingButtonClicked()
                            (m_selectedModelFactory.GetPointer()) != nullptr;
     bool isGenericFactory = dynamic_cast<mitk::GenericParamModelFactory*>
                             (m_selectedModelFactory.GetPointer()) != nullptr;
-    bool isT2DecayFactory = dynamic_cast<mitk::T2DecayModelFactory*>
+    bool isExponentialDecayFactory = dynamic_cast<mitk::ExponentialDecayModelFactory*>
+      (m_selectedModelFactory.GetPointer()) != nullptr;
+    bool isTwoStepLinearFactory = dynamic_cast<mitk::TwoStepLinearModelFactory*>
+      (m_selectedModelFactory.GetPointer()) != nullptr;
+    bool isThreeStepLinearFactory = dynamic_cast<mitk::ThreeStepLinearModelFactory*>
+      (m_selectedModelFactory.GetPointer()) != nullptr;
+
+    bool isExponentialSaturationFactory = dynamic_cast<mitk::ExponentialSaturationModelFactory*>
       (m_selectedModelFactory.GetPointer()) != nullptr;
 
     if (isLinearFactory)
@@ -268,15 +321,48 @@ void GenericDataFittingView::OnModellingButtonClicked()
         GenerateModelFit_ROIBased<mitk::GenericParamModelParameterizer>(fitSession, generator);
       }
     }
-    else if (isT2DecayFactory)
+    else if (isExponentialDecayFactory)
     {
       if (this->m_Controls.radioPixelBased->isChecked())
       {
-        GenerateModelFit_PixelBased<mitk::T2DecayModelParameterizer>(fitSession, generator);
+        GenerateModelFit_PixelBased<mitk::ExponentialDecayModelParameterizer>(fitSession, generator);
       }
       else
       {
-        GenerateModelFit_ROIBased<mitk::T2DecayModelParameterizer>(fitSession, generator);
+        GenerateModelFit_ROIBased<mitk::ExponentialDecayModelParameterizer>(fitSession, generator);
+      }
+    }
+    else if (isTwoStepLinearFactory)
+    {
+      if (this->m_Controls.radioPixelBased->isChecked())
+      {
+        GenerateModelFit_PixelBased<mitk::TwoStepLinearModelParameterizer>(fitSession, generator);
+      }
+      else
+      {
+        GenerateModelFit_ROIBased<mitk::TwoStepLinearModelParameterizer>(fitSession, generator);
+      }
+    }
+    else if (isThreeStepLinearFactory)
+    {
+      if (this->m_Controls.radioPixelBased->isChecked())
+      {
+        GenerateModelFit_PixelBased<mitk::ThreeStepLinearModelParameterizer>(fitSession, generator);
+      }
+      else
+      {
+        GenerateModelFit_ROIBased<mitk::ThreeStepLinearModelParameterizer>(fitSession, generator);
+      }
+    }
+    else if (isExponentialSaturationFactory)
+    {
+      if (this->m_Controls.radioPixelBased->isChecked())
+      {
+        GenerateModelFit_PixelBased<mitk::ExponentialSaturationModelParameterizer>(fitSession, generator);
+      }
+      else
+      {
+        GenerateModelFit_ROIBased<mitk::ExponentialSaturationModelParameterizer>(fitSession, generator);
       }
     }
     //add other models with else if
@@ -312,52 +398,63 @@ void GenericDataFittingView::OnModellingButtonClicked()
 }
 
 
-void GenericDataFittingView::OnSelectionChanged(berry::IWorkbenchPart::Pointer /*source*/,
-    const QList<mitk::DataNode::Pointer>& selectedNodes)
+void GenericDataFittingView::OnImageNodeSelectionChanged(QList<mitk::DataNode::Pointer>/*nodes*/)
+{
+
+  if (m_Controls.timeSeriesNodeSelector->GetSelectedNode().IsNotNull())
+  {
+    this->m_selectedNode = m_Controls.timeSeriesNodeSelector->GetSelectedNode();
+    m_selectedImage = dynamic_cast<mitk::Image*>(m_selectedNode->GetData());
+
+    if (m_selectedImage)
+    {
+      this->m_Controls.initialValuesManager->setReferenceImageGeometry(m_selectedImage->GetGeometry());
+      m_Controls.maskNodeSelector->SetNodePredicate(mitk::GetMultiLabelSegmentationPredicate(m_selectedImage->GetGeometry()));
+    }
+    else
+    {
+      this->m_Controls.initialValuesManager->setReferenceImageGeometry(nullptr);
+      m_Controls.maskNodeSelector->SetNodePredicate(mitk::GetMultiLabelSegmentationPredicate(nullptr));
+    }
+  }
+  else
+  {
+    this->m_selectedNode = nullptr;
+    this->m_selectedImage = nullptr;
+    this->m_Controls.initialValuesManager->setReferenceImageGeometry(nullptr);
+  }
+
+  UpdateGUIControls();
+}
+
+void GenericDataFittingView::OnMaskNodeSelectionChanged(QList<mitk::DataNode::Pointer>/*nodes*/)
 {
-  m_selectedNode = nullptr;
-  m_selectedImage = nullptr;
   m_selectedMaskNode = nullptr;
   m_selectedMask = nullptr;
 
-  m_Controls.masklabel->setText("No (valid) mask selected.");
-  m_Controls.timeserieslabel->setText("No (valid) series selected.");
-
-  QList<mitk::DataNode::Pointer> nodes = selectedNodes;
-
-  mitk::NodePredicateDataType::Pointer isLabelSet = mitk::NodePredicateDataType::New("LabelSetImage");
-  mitk::NodePredicateDataType::Pointer isImage = mitk::NodePredicateDataType::New("Image");
-  mitk::NodePredicateProperty::Pointer isBinary = mitk::NodePredicateProperty::New("binary", mitk::BoolProperty::New(true));
-  mitk::NodePredicateAnd::Pointer isLegacyMask = mitk::NodePredicateAnd::New(isImage, isBinary);
-
-  mitk::NodePredicateOr::Pointer maskPredicate = mitk::NodePredicateOr::New(isLegacyMask, isLabelSet);
-
-  if (nodes.size() > 0 && isImage->CheckNode(nodes.front()))
+  if (m_Controls.maskNodeSelector->GetSelectedNode().IsNotNull())
   {
-    this->m_selectedNode = nodes.front();
-    this->m_selectedImage = dynamic_cast<mitk::Image*>(this->m_selectedNode->GetData());
-    m_Controls.timeserieslabel->setText((this->m_selectedNode->GetName()).c_str());
-    nodes.pop_front();
-  }
+    this->m_selectedMaskNode = m_Controls.maskNodeSelector->GetSelectedNode();
+    auto selectedLabelSetMask = dynamic_cast<mitk::LabelSetImage*>(m_selectedMaskNode->GetData());
 
-  if (nodes.size() > 0 && maskPredicate->CheckNode(nodes.front()))
-  {
-      this->m_selectedMaskNode = nodes.front();
-      this->m_selectedMask = dynamic_cast<mitk::Image*>(this->m_selectedMaskNode->GetData());
-
-      if (this->m_selectedMask->GetTimeSteps() > 1)
+    if (selectedLabelSetMask != nullptr)
+    {
+      if (selectedLabelSetMask->GetAllLabelValues().size() > 1)
       {
-        MITK_INFO <<
-                  "Selected mask has multiple timesteps. Only use first timestep to mask model fit. Mask name: " <<
-                  m_selectedMaskNode->GetName();
-        mitk::ImageTimeSelector::Pointer maskedImageTimeSelector = mitk::ImageTimeSelector::New();
-        maskedImageTimeSelector->SetInput(this->m_selectedMask);
-        maskedImageTimeSelector->SetTimeNr(0);
-        maskedImageTimeSelector->UpdateLargestPossibleRegion();
-        this->m_selectedMask = maskedImageTimeSelector->GetOutput();
+        MITK_INFO << "Selected mask has multiple labels. Only use first used to mask the model fit.";
       }
+      this->m_selectedMask = mitk::CreateLabelMask(selectedLabelSetMask, selectedLabelSetMask->GetAllLabelValues().front(), true);
+    }
 
-      m_Controls.masklabel->setText((this->m_selectedMaskNode->GetName()).c_str());
+
+    if (this->m_selectedMask.IsNotNull() && this->m_selectedMask->GetTimeSteps() > 1)
+    {
+      MITK_INFO <<
+        "Selected mask has multiple timesteps. Only use first timestep to mask model fit. Mask name: " <<
+      m_Controls.maskNodeSelector->GetSelectedNode()->GetName();
+      this->m_selectedMask = SelectImageByTimeStep(m_selectedMask, 0);
+
+    }
   }
 
   if (m_selectedMask.IsNull())
@@ -368,11 +465,13 @@ void GenericDataFittingView::OnSelectionChanged(berry::IWorkbenchPart::Pointer /
   UpdateGUIControls();
 }
 
+
+
 bool GenericDataFittingView::CheckModelSettings() const
 {
   bool ok = true;
 
-  //check wether any model is set at all. Otherwise exit with false
+  //check whether any model is set at all. Otherwise exit with false
   if (m_selectedModelFactory.IsNotNull())
   {
     bool isGenericFactory = dynamic_cast<mitk::GenericParamModelFactory*>(m_selectedModelFactory.GetPointer()) != nullptr;
@@ -386,6 +485,14 @@ bool GenericDataFittingView::CheckModelSettings() const
   {
     ok = false;
   }
+  if (this->m_Controls.radioButton_StartParameters->isChecked() && !this->m_Controls.initialValuesManager->hasValidInitialValues())
+  {
+    std::string warning = "Warning. Invalid start parameters. At least one parameter has an invalid image setting as source.";
+    MITK_ERROR << warning;
+    m_Controls.infoBox->append(QString("<font color='red'><b>") + QString::fromStdString(warning) + QString("</b></font>"));
+
+    ok = false;
+  };
 
   return ok;
 }
@@ -547,18 +654,26 @@ GenericDataFittingView::GenericDataFittingView() : m_FittingInProgress(false)
   m_FactoryStack.push_back(factory);
   factory = mitk::GenericParamModelFactory::New().GetPointer();
   m_FactoryStack.push_back(factory);
-  factory = mitk::T2DecayModelFactory::New().GetPointer();
+  factory = mitk::ExponentialDecayModelFactory::New().GetPointer();
+  m_FactoryStack.push_back(factory);
+  factory = mitk::ExponentialSaturationModelFactory::New().GetPointer();
+  m_FactoryStack.push_back(factory);
+  factory = mitk::TwoStepLinearModelFactory::New().GetPointer();
+  m_FactoryStack.push_back(factory);
+  factory = mitk::ThreeStepLinearModelFactory::New().GetPointer();
   m_FactoryStack.push_back(factory);
 
-  this->m_IsNotABinaryImagePredicate = mitk::NodePredicateAnd::New(
-                                         mitk::TNodePredicateDataType<mitk::Image>::New(),
-                                         mitk::NodePredicateNot::New(mitk::NodePredicateProperty::New("binary",
-                                             mitk::BoolProperty::New(true))),
-                                         mitk::NodePredicateNot::New(mitk::NodePredicateProperty::New("helper object"))).GetPointer();
-  this->m_IsBinaryImagePredicate = mitk::NodePredicateAnd::New(
-                                     mitk::TNodePredicateDataType<mitk::Image>::New(),
-                                     mitk::NodePredicateProperty::New("binary", mitk::BoolProperty::New(true)),
-                                     mitk::NodePredicateNot::New(mitk::NodePredicateProperty::New("helper object"))).GetPointer();
+
+  mitk::NodePredicateDataType::Pointer isImage = mitk::NodePredicateDataType::New("Image");
+
+  auto isDynamicData = mitk::NodePredicateFunction::New([](const mitk::DataNode* node)
+  {
+    return  (node && node->GetData() && node->GetData()->GetTimeSteps() > 1);
+  });
+
+  auto isNoMask = mitk::NodePredicateNot::New(mitk::GetMultiLabelSegmentationPredicate());
+
+  this->m_isValidTimeSeriesImagePredicate = mitk::NodePredicateAnd::New(isDynamicData, isImage, isNoMask);
 }
 
 void GenericDataFittingView::OnJobFinished()
