@@ -191,7 +191,7 @@ void QmitkMatchPointFrameCorrection::CreateQtPartControl(QWidget* parent)
   this->m_Controls.maskNodeSelector->SetDataStorage(this->GetDataStorage());
   this->m_Controls.maskNodeSelector->SetSelectionIsOptional(true);
 
-  this->m_Controls.imageNodeSelector->SetInvalidInfo("Select dymamic image.");
+  this->m_Controls.imageNodeSelector->SetInvalidInfo("Select dynamic image.");
   this->m_Controls.imageNodeSelector->SetPopUpTitel("Select dynamic image.");
   this->m_Controls.imageNodeSelector->SetPopUpHint("Select a dynamic image (time resolved) that should be frame corrected.");
   this->m_Controls.maskNodeSelector->SetInvalidInfo("Select target mask.");
@@ -258,7 +258,7 @@ void QmitkMatchPointFrameCorrection::CheckInputs()
   if (m_LoadedAlgorithm.IsNull())
   {
     m_Controls.m_lbLoadedAlgorithmName->setText(
-      QStringLiteral("<font color='red'>No algorithm seleted!</font>"));
+      QStringLiteral("<font color='red'>No algorithm selected!</font>"));
   }
   else
   {
@@ -718,7 +718,7 @@ void QmitkMatchPointFrameCorrection::UpdateAlgorithmSelection(berry::ISelection:
       // only the first selection is of interest, the rest will be skipped.
       this->m_SelectedAlgorithmInfo = infoVector[0];
     }
+    this->OnSelectedAlgorithmChanged();
   }
 
-  this->OnSelectedAlgorithmChanged();
 };
