@@ -120,7 +120,7 @@ void QmitkScreenshotMaker::MultichannelScreenshot(mitk::VtkPropRenderer* rendere
     mitk::PixelType chPixelType = image->GetImageDescriptor()->GetChannelTypeById(0);
     if (image->GetDimension() == 4)
     {
-      MITK_INFO << "LOOPING THROUGH FOURTH DIMESNION IS NOT IMPLEMENTED";
+      MITK_INFO << "LOOPING THROUGH FOURTH DIMENSION IS NOT IMPLEMENTED";
     }
     else if (chPixelType.GetNumberOfComponents()>1)
     {
@@ -311,11 +311,7 @@ void QmitkScreenshotMaker::GenerateHR3DAtlasScreenshots(QString fileName, QStrin
   auto* renderer = renderWindowPart->GetQmitkRenderWindow("3d")->GetRenderer()->GetVtkRenderer();
 
   if (nullptr != renderer)
-  {
-    renderWindowPart->EnableDecorations(false);
     this->TakeScreenshot(renderer, this->m_Controls->m_MagFactor->text().toFloat(), fileName, filter);
-    renderWindowPart->EnableDecorations(true);
-  }
 }
 
 vtkCamera* QmitkScreenshotMaker::GetCam()
