@@ -1,18 +1,14 @@
-/*===================================================================
+/*============================================================================
 
 The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
-
-===================================================================*/
+============================================================================*/
 
 #ifndef QmitkTimeSliceAnimationItem_h
 #define QmitkTimeSliceAnimationItem_h
@@ -23,7 +19,7 @@ class QmitkTimeSliceAnimationItem : public QmitkAnimationItem
 {
 public:
   explicit QmitkTimeSliceAnimationItem(int from = 0, int to = 0, bool reverse = false, double duration = 2.0, double delay = 0.0, bool startWithPrevious = false);
-  virtual ~QmitkTimeSliceAnimationItem();
+  ~QmitkTimeSliceAnimationItem() override;
 
   int GetFrom() const;
   void SetFrom(int from);
