@@ -17,7 +17,6 @@ found in the LICENSE file.
 #include "ConcentrationCurveConverterView.h"
 #include "mitkConcentrationCurveGenerator.h"
 #include "mitkNodePredicateDataType.h"
-#include "mitkConvertToConcentrationTurboFlashFunctor.h"
 #include "mitkConvertToConcentrationAbsoluteFunctor.h"
 #include "mitkConvertToConcentrationRelativeFunctor.h"
 #include "itkBinaryFunctorImageFilter.h"
@@ -84,8 +83,9 @@ void ConcentrationCurveConverterView::CreateQtPartControl(QWidget* parent)
     m_Controls.groupBox_T2->hide();
     m_Controls.groupBox3D->hide();
     m_Controls.groupBox4D->hide();
-    m_Controls.groupBoxTurboFlash->hide();
     m_Controls.groupConcentration->hide();
+    m_Controls.groupBox_baselineRangeSelection->hide();
+    m_Controls.groupBox_BaselineRangeSelectionT2->hide();
 
     connect(m_Controls.radioButton_T1, SIGNAL(toggled(bool)),this, SLOT(OnSettingChanged()));
     connect(m_Controls.radioButton_T2, SIGNAL(toggled(bool)),this, SLOT(OnSettingChanged()));
@@ -97,7 +97,6 @@ void ConcentrationCurveConverterView::CreateQtPartControl(QWidget* parent)
   //Concentration
     m_Controls.groupConcentration->hide();
     m_Controls.groupBoxEnhancement->hide();
-    m_Controls.groupBoxTurboFlash->hide();
     m_Controls.groupBox_T1MapviaVFA->hide();
 
     m_Controls.spinBox_baselineStartTimeStep->setValue(0);
@@ -112,11 +111,7 @@ void ConcentrationCurveConverterView::CreateQtPartControl(QWidget* parent)
     m_Controls.spinBox_baselineEndTimeStepT2->setMinimum(0);
     m_Controls.spinBox_baselineStartTimeStepT2->setMinimum(0);
 
-    connect(m_Controls.radioButtonTurboFlash, SIGNAL(toggled(bool)), m_Controls.groupBoxTurboFlash, SLOT(setVisible(bool)));
-    connect(m_Controls.radioButtonTurboFlash, SIGNAL(toggled(bool)), this, SLOT(OnSettingChanged()));
-    connect(m_Controls.relaxationtime, SIGNAL(valueChanged(double)), this, SLOT(OnSettingChanged()));
-    connect(m_Controls.recoverytime, SIGNAL(valueChanged(double)), this, SLOT(OnSettingChanged()));
-    connect(m_Controls.relaxivity, SIGNAL(valueChanged(double)), this, SLOT(OnSettingChanged()));
+
 
     connect(m_Controls.timeSeriesNodeSelector, &QmitkAbstractNodeSelectionWidget::CurrentSelectionChanged, this, &ConcentrationCurveConverterView::OnNodeSelectionChanged);
     connect(m_Controls.image3DNodeSelector, &QmitkAbstractNodeSelectionWidget::CurrentSelectionChanged, this, &ConcentrationCurveConverterView::OnNodeSelectionChanged);
@@ -124,10 +119,13 @@ void ConcentrationCurveConverterView::CreateQtPartControl(QWidget* parent)
     connect(m_Controls.t2TimeSeriesNodeSelector, &QmitkAbstractNodeSelectionWidget::CurrentSelectionChanged, this, &ConcentrationCurveConverterView::OnNodeSelectionChanged);
     connect(m_Controls.PDWImageNodeSelector, &QmitkAbstractNodeSelectionWidget::CurrentSelectionChanged, this, &ConcentrationCurveConverterView::OnSettingChanged);
 
-    connect(m_Controls.radioButton_absoluteEnhancement, SIGNAL(toggled(bool)), this, SLOT(OnSettingChanged()));
-    connect(m_Controls.radioButton_relativeEnchancement, SIGNAL(toggled(bool)), this, SLOT(OnSettingChanged()));
     connect(m_Controls.radioButton_absoluteEnhancement, SIGNAL(toggled(bool)), m_Controls.groupBoxEnhancement, SLOT(setVisible(bool)));
+    connect(m_Controls.radioButton_absoluteEnhancement, SIGNAL(toggled(bool)), m_Controls.groupBox_baselineRangeSelection, SLOT(setVisible(bool)));
+    connect(m_Controls.radioButton_absoluteEnhancement, SIGNAL(toggled(bool)), this, SLOT(OnSettingChanged()));
+
     connect(m_Controls.radioButton_relativeEnchancement, SIGNAL(toggled(bool)), m_Controls.groupBoxEnhancement, SLOT(setVisible(bool)));
+    connect(m_Controls.radioButton_relativeEnchancement, SIGNAL(toggled(bool)), m_Controls.groupBox_baselineRangeSelection, SLOT(setVisible(bool)));
+    connect(m_Controls.radioButton_relativeEnchancement, SIGNAL(toggled(bool)), this, SLOT(OnSettingChanged()));
 
     connect(m_Controls.factorSpinBox, SIGNAL(valueChanged(double)), this, SLOT(OnSettingChanged()));
     connect(m_Controls.spinBox_baselineStartTimeStep, SIGNAL(valueChanged(int)), this, SLOT(OnSettingChanged()));
@@ -136,6 +134,7 @@ void ConcentrationCurveConverterView::CreateQtPartControl(QWidget* parent)
     connect(m_Controls.spinBox_baselineEndTimeStepT2, SIGNAL(valueChanged(int)), this, SLOT(OnSettingChanged()));
 
     connect(m_Controls.radioButtonUsingT1viaVFA, SIGNAL(toggled(bool)), m_Controls.groupBox_T1MapviaVFA, SLOT(setVisible(bool)));
+    connect(m_Controls.radioButtonUsingT1viaVFA, SIGNAL(toggled(bool)), m_Controls.groupBox_baselineRangeSelection, SLOT(setVisible(bool)));
     connect(m_Controls.radioButtonUsingT1viaVFA, SIGNAL(toggled(bool)), this, SLOT(OnSettingChanged()));
     connect(m_Controls.FlipangleSpinBox, SIGNAL(valueChanged(double)), this, SLOT(OnSettingChanged()));
     connect(m_Controls.RelaxivitySpinBox, SIGNAL(valueChanged(double)), this, SLOT(OnSettingChanged()));
@@ -155,6 +154,8 @@ void ConcentrationCurveConverterView::OnSettingChanged()
   bool ok = false;
   m_Controls.groupBox_T1->setVisible(m_Controls.radioButton_T1->isChecked());
   m_Controls.groupBox_T2->setVisible(m_Controls.radioButton_T2->isChecked());
+  m_Controls.groupBox_BaselineRangeSelectionT2->setVisible(m_Controls.radioButton_T2->isChecked());
+
 
   if(m_Controls.radioButton_T1->isChecked())
   {
@@ -164,13 +165,15 @@ void ConcentrationCurveConverterView::OnSettingChanged()
       if(m_Controls.radioButton4D->isChecked())
       {
           m_Controls.groupConcentration->setVisible(true);
+          if (m_Controls.radioButton_absoluteEnhancement->isChecked() || m_Controls.radioButton_relativeEnchancement->isChecked() || m_Controls.radioButtonUsingT1viaVFA->isChecked())
+          m_Controls.groupBox_baselineRangeSelection->setVisible(true);
           ok = m_selectedImage.IsNotNull() && CheckSettings();
       }
       else if(m_Controls.radioButton3D->isChecked())
       {
           m_Controls.groupConcentration->setVisible(true);
+          m_Controls.groupBox_baselineRangeSelection->hide();
           ok = m_selectedImage.IsNotNull() && m_selectedBaselineImage.IsNotNull() && CheckSettings();
-
       }
   }
   else if (m_Controls.radioButton_T2->isChecked())
@@ -192,15 +195,7 @@ bool ConcentrationCurveConverterView::CheckSettings() const
 
   if (m_Controls.radioButton_T1->isChecked())
   {
-    if (this->m_Controls.radioButtonTurboFlash->isChecked())
-    {
-      ok = ok && (m_Controls.recoverytime->value() > 0);
-      ok = ok && (m_Controls.relaxationtime->value() > 0);
-      ok = ok && (m_Controls.relaxivity->value() > 0);
-      ok = ok && (m_Controls.AifRecoverytime->value() > 0);
-      ok = ok && CheckBaselineSelectionSettings();
-    }
-    else if (this->m_Controls.radioButton_absoluteEnhancement->isChecked()
+    if (this->m_Controls.radioButton_absoluteEnhancement->isChecked()
       || this->m_Controls.radioButton_relativeEnchancement->isChecked())
     {
       ok = ok && (m_Controls.factorSpinBox->value() > 0);
@@ -290,26 +285,7 @@ mitk::Image::Pointer ConcentrationCurveConverterView::Convert3DConcentrationImag
 
     mitk::Image::Pointer outputImage;
 
-    if(this->m_Controls.radioButtonTurboFlash->isChecked())
-    {
-        typedef mitk::ConvertToConcentrationTurboFlashFunctor <double, double, double> ConversionFunctorTurboFlashType;
-        typedef itk::BinaryFunctorImageFilter<InputImageType,InputImageType, ConvertedImageType, ConversionFunctorTurboFlashType> FilterTurboFlashType;
-
-        ConversionFunctorTurboFlashType ConversionTurboFlashFunctor;
-        ConversionTurboFlashFunctor.initialize(m_Controls.relaxationtime->value(), m_Controls.relaxivity->value(), m_Controls.recoverytime->value());
-
-        FilterTurboFlashType::Pointer ConversionTurboFlashFilter = FilterTurboFlashType::New();
-
-        ConversionTurboFlashFilter->SetFunctor(ConversionTurboFlashFunctor);
-        ConversionTurboFlashFilter->SetInput1(itkInputImage);
-        ConversionTurboFlashFilter->SetInput2(itkBaselineImage);
-
-        ConversionTurboFlashFilter->Update();
-        outputImage = mitk::ImportItkImage(ConversionTurboFlashFilter->GetOutput())->Clone();
-
-
-    }
-    else if(this->m_Controls.radioButton_absoluteEnhancement->isChecked())
+    if(this->m_Controls.radioButton_absoluteEnhancement->isChecked())
     {
         typedef mitk::ConvertToConcentrationAbsoluteFunctor <double, double, double> ConversionFunctorAbsoluteType;
         typedef itk::BinaryFunctorImageFilter<InputImageType,InputImageType, ConvertedImageType, ConversionFunctorAbsoluteType> FilterAbsoluteType;
@@ -382,7 +358,6 @@ mitk::Image::Pointer ConcentrationCurveConverterView::Convert4DConcentrationImag
     mitk::ConcentrationCurveGenerator::New();
   concentrationGen->SetDynamicImage(inputImage);
 
-  concentrationGen->SetisTurboFlashSequence(m_Controls.radioButtonTurboFlash->isChecked());
   concentrationGen->SetAbsoluteSignalEnhancement(m_Controls.radioButton_absoluteEnhancement->isChecked());
   concentrationGen->SetRelativeSignalEnhancement(m_Controls.radioButton_relativeEnchancement->isChecked());
   concentrationGen->SetUsingT1Map(m_Controls.radioButtonUsingT1viaVFA->isChecked());
@@ -391,24 +366,18 @@ mitk::Image::Pointer ConcentrationCurveConverterView::Convert4DConcentrationImag
 
   concentrationGen->SetisT2weightedImage(false);
 
-  if (m_Controls.radioButtonTurboFlash->isChecked())
+  if (this->m_Controls.radioButtonUsingT1viaVFA->isChecked())
   {
-    concentrationGen->SetRecoveryTime(m_Controls.recoverytime->value());
-    concentrationGen->SetRelaxationTime(m_Controls.relaxationtime->value());
-    concentrationGen->SetRelaxivity(m_Controls.relaxivity->value());
-    concentrationGen->SetBaselineStartTimeStep(m_Controls.spinBox_baselineStartTimeStep->value());
-    concentrationGen->SetBaselineEndTimeStep(m_Controls.spinBox_baselineEndTimeStep->value());
-  }
-  else if (this->m_Controls.radioButtonUsingT1viaVFA->isChecked())
-  {
-    concentrationGen->SetRecoveryTime(m_Controls.TRSpinBox->value());
+    concentrationGen->SetRepetitionTime(m_Controls.TRSpinBox->value());
     concentrationGen->SetRelaxivity(m_Controls.RelaxivitySpinBox->value());
-    concentrationGen->SetT10Image(dynamic_cast<mitk::Image*>(m_Controls.PDWImageNodeSelector->GetSelectedNode()->GetData()));
+    concentrationGen->SetPDWImage(dynamic_cast<mitk::Image*>(m_Controls.PDWImageNodeSelector->GetSelectedNode()->GetData()));
     concentrationGen->SetBaselineStartTimeStep(m_Controls.spinBox_baselineStartTimeStep->value());
     concentrationGen->SetBaselineEndTimeStep(m_Controls.spinBox_baselineEndTimeStep->value());
     //Convert Flipangle from degree to radiant
-      double alpha = m_Controls.FlipangleSpinBox->value()/360*2* boost::math::constants::pi<double>();
-      concentrationGen->SetFlipAngle(alpha);
+    double alpha = m_Controls.FlipangleSpinBox->value()/360*2* boost::math::constants::pi<double>();
+    concentrationGen->SetFlipAngle(alpha);
+    double alphaPDW = m_Controls.FlipanglePDWSpinBox->value() / 360 * 2 * boost::math::constants::pi<double>();
+    concentrationGen->SetFlipAnglePDW(alphaPDW);
   }
 
   else
@@ -431,7 +400,6 @@ mitk::Image::Pointer ConcentrationCurveConverterView::ConvertT2ConcentrationImga
       mitk::ConcentrationCurveGenerator::New();
     concentrationGen->SetDynamicImage(inputImage);
 
-    concentrationGen->SetisTurboFlashSequence(false);
     concentrationGen->SetAbsoluteSignalEnhancement(false);
     concentrationGen->SetRelativeSignalEnhancement(false);
 
