@@ -1,21 +1,17 @@
-/*===================================================================
+/*============================================================================
 
 The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
+============================================================================*/
 
-===================================================================*/
-
-#ifndef QmitkPythonView_H_
-#define QmitkPythonView_H_
+#ifndef QmitkPythonView_h
+#define QmitkPythonView_h
 
 /// Qmitk
 #include <QmitkAbstractView.h>
@@ -43,22 +39,22 @@ public:
   ///
   /// \brief Standard dtor.
   ///
-  virtual ~QmitkPythonView();
+  ~QmitkPythonView() override;
 
 protected:
 
   ///
   /// \brief Create the view here.
   ///
-  virtual void CreateQtPartControl(QWidget* parent);
+  void CreateQtPartControl(QWidget* parent) override;
 
   ///
   /// focus on load image
   ///
-  void SetFocus();
+  void SetFocus() override;
 
 private:
   QmitkPythonViewData* d;
 };
 
-#endif /*QmitkPythonView_H_*/
+#endif
