@@ -80,8 +80,8 @@ void QmitkXnatConnectionPreferencePage::CreateQtControl(QWidget* parent)
   const QIntValidator *portV = new QIntValidator(0, 65535, parent);
   m_Controls.inXnatPort->setValidator(portV);
 
-  const QRegExp hostRx("^(https?)://[^ /](\\S)+$");
-  const QRegExpValidator *hostV = new QRegExpValidator(hostRx, parent);
+  const QRegularExpression hostRx("^(https?)://[^ /](\\S)+$");
+  const QRegularExpressionValidator *hostV = new QRegularExpressionValidator(hostRx, parent);
   m_Controls.inXnatHostAddress->setValidator(hostV);
 
   connect(m_Controls.xnatTestConnectionButton, SIGNAL(clicked()), this, SLOT(TestConnection()));
@@ -288,7 +288,7 @@ void QmitkXnatConnectionPreferencePage::TestConnection()
   catch (const ctkException& e)
   {
     m_Controls.xnatTestConnectionLabel->setStyleSheet("color: red");
-    m_Controls.xnatTestConnectionLabel->setText("Connecting failed:\nInvalid Server Adress\nPossibly due to missing OpenSSL for HTTPS connections");
+    m_Controls.xnatTestConnectionLabel->setText("Connecting failed:\nInvalid Server Address\nPossibly due to missing OpenSSL for HTTPS connections");
     MITK_INFO << e.message().toStdString();
     mitk::org_mitk_gui_qt_xnatinterface_Activator::GetXnatSessionManager()->CloseXnatSession();
   }
