@@ -1,21 +1,17 @@
-/*===================================================================
+/*============================================================================
 
 The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
+============================================================================*/
 
-===================================================================*/
-
-#ifndef QMITKXNATOBJECTEDITORINPUT_H_
-#define QMITKXNATOBJECTEDITORINPUT_H_
+#ifndef QmitkXnatObjectEditorInput_h
+#define QmitkXnatObjectEditorInput_h
 
 #include "berryIEditorInput.h"
 #include "ctkXnatObject.h"
@@ -25,7 +21,7 @@ class QmitkXnatObjectEditorInput : public berry::IEditorInput {
 public:
   berryObjectMacro(QmitkXnatObjectEditorInput);
 
-  QmitkXnatObjectEditorInput(ctkXnatObject* object);
+  explicit QmitkXnatObjectEditorInput(ctkXnatObject* object);
   ~QmitkXnatObjectEditorInput();
 
   /// \brief Returns the kept ctkXnatObject.
@@ -45,4 +41,4 @@ private:
   ctkXnatObject* m_Object;
 };
 
-#endif /*QMITKXNATOBJECTEDITORINPUT_H_*/
+#endif
